<?php
date_default_timezone_set("Asia/Jakarta");

function getIP() {
    $ipaddress = "";
    if (getenv("HTTP_CLIENT_IP"))
        $ipaddress = getenv("HTTP_CLIENT_IP");
    else if(getenv("HTTP_X_FORWARDED_FOR"))
        $ipaddress = getenv("HTTP_X_FORWARDED_FOR");
    else if(getenv("HTTP_X_FORWARDED"))
        $ipaddress = getenv("HTTP_X_FORWARDED");
    else if(getenv("HTTP_FORWARDED_FOR"))
        $ipaddress = getenv("HTTP_FORWARDED_FOR");
    else if(getenv("HTTP_FORWARDED"))
        $ipaddress = getenv("HTTP_FORWARDED");
    else if(getenv("REMOTE_ADDR"))
        $ipaddress = getenv("REMOTE_ADDR");
    else
        $ipaddress = "UNKNOWN";
    return $ipaddress;
}


function ParseUA() {
    $UA = "";
    $UAHeaders = [
        "HTTP_USER_AGENT",
        "HTTP_X_OPERAMINI_PHONE_UA",
        "HTTP_X_DEVICE_USER_AGENT",
        "HTTP_X_ORIGINAL_USER_AGENT",
        "HTTP_X_SKYFIRE_PHONE",
        "HTTP_X_BOLT_PHONE_UA",
        "HTTP_DEVICE_STOCK_UA",
        "HTTP_X_UCBROWSER_DEVICE_UA",
        "HTTP_FROM",
        "HTTP_X_SCANNER"
    ];
    foreach ($UAHeaders as $header){
        if (isset($_SERVER[$header]) && !empty(trim($_SERVER[$header]))) {
            $UA = $_SERVER[$header];
            break;
        }  
    }
    return $UA;
}


function getOS() {
    $oses = array(
        "windows nt 10.0" => "Windows 10",
        "windows nt 6.3" => "Windows 8.1",
        "windows nt 6.2" => "Windows 8",
        "windows nt 6.1" => "Windows 7",
        "windows nt 6.0" => "Windows Vista",
        "windows nt 5.2" => "Windows 2003",
        "windows nt 5.1" => "Windows XP",
        "windows nt 5.0" => "Windows 2000",
        "windows nt 4.0" => "Windows NT 4.0",
        "winnt4.0" => "Windows NT 4.0",
        "winnt 4.0" => "Windows NT",
        "winnt" => "Windows NT",
        "windows 98" => "Windows 98",
        "win98" => "Windows 98",
        "windows 95" => "Windows 95",
        "win95" => "Windows 95",
        "windows phone" => "Windows Phone",
        "windows" => "Unknown Windows OS",
        "android" => "Android",
        "blackberry" => "BlackBerry",
        "os x" => "Mac OS X",
        "ppc mac" => "Power PC Mac",
        "freebsd" => "FreeBSD",
        "ppc" => "Macintosh",
        "linux" => "Linux",
        "debian" => "Debian",
        "sunos" => "Sun Solaris",
        "beos" => "BeOS",
        "apachebench" => "ApacheBench",
        "aix" => "AIX",
        "irix" => "Irix",
        "osf" => "DEC OSF",
        "hp-ux" => "HP-UX",
        "netbsd" => "NetBSD",
        "bsdi" => "BSDi",
        "openbsd" => "OpenBSD",
        "gnu" => "GNU/Linux",
        "unix" => "Unknown Unix OS",
        "symbian" => "Symbian OS",
        "mobileexplorer" => "Mobile Explorer",
        "palmsource" => "Palm",
        "palmscape" => "Palmscape",
        "motorola" => "Motorola",
        "nokia" => "Nokia",
        "palm" => "Palm",
        "iphone" => "Apple iPhone",
        "ipad" => "iPad",
        "ipod" => "Apple iPod Touch",
        "sony" => "Sony Ericsson",
        "ericsson" => "Sony Ericsson",
        "cocoon" => "O2 Cocoon",
        "blazer" => "Treo",
        "lg" => "LG",
        "amoi" => "Amoi",
        "xda" => "XDA",
        "mda" => "MDA",
        "vario" => "Vario",
        "htc" => "HTC",
        "samsung" => "Samsung",
        "sharp" => "Sharp",
        "sie-" => "Siemens",
        "alcatel" => "Alcatel",
        "benq" => "BenQ",
        "ipaq" => "HP iPaq",
        "mot-" => "Motorola",
        "playstation portable" => "PlayStation Portable",
        "playstation 3" => "PlayStation 3",
        "playstation vita" => "PlayStation Vita",
        "hiptop" => "Danger Hiptop",
        "nec-" => "NEC",
        "panasonic" => "Panasonic",
        "philips" => "Philips",
        "sagem" => "Sagem",
        "sanyo" => "Sanyo",
        "spv" => "SPV",
        "zte" => "ZTE",
        "sendo" => "Sendo",
        "nintendo dsi" => "Nintendo DSi",
        "nintendo ds" => "Nintendo DS",
        "nintendo 3ds" => "Nintendo 3DS",
        "wii" => "Nintendo Wii",
        "open web" => "Open Web",
        "openweb" => "OpenWeb",
        "SymbianOS" => "SymbianOS",
        "elaine" => "Palm",
        "series60" => "Symbian S60",
        "windows ce" => "Windows CE",
        "digital paths" => "Digital Paths",
        "avantgo" => "AvantGo",
        "xiino" => "Xiino",
        "novarra" => "Novarra Transcoder",
        "vodafone" => "Vodafone",
        "docomo" => "NTT DoCoMo",
        "o2" => "O2",
        "mobile" => "Generic Mobile",
        "wireless" => "Generic Mobile",
        "j2me" => "Generic Mobile",
        "midp" => "Generic Mobile",
        "cldc" => "Generic Mobile",
        "up.link" => "Generic Mobile",
        "up.browser" => "Generic Mobile",
        "smartphone" => "Generic Mobile",
        "cellphone" => "Generic Mobile"
    );
    foreach ($oses as $os => $preg_pattern) {
        if (preg_match("/" . $preg_pattern . "/", ParseUA())) {
            return $os;
        }
    }
    return "Unknown OS";
}

function getBrowser() {
    $browser_array = array(
        "OPR" => "Opera",
        "Flock" => "Flock",
        "Edge" => "Spartan",
        "Chrome" => "Chrome",
        "Opera.*?Version" => "Opera",
        "Opera" => "Opera",
        "MSIE" => "Internet Explorer",
        "Internet Explorer" => "Internet Explorer",
        "Trident.* rv" => "Internet Explorer",
        "Shiira" => "Shiira",
        "Firefox" => "Firefox",
        "Chimera" => "Chimera",
        "Phoenix" => "Phoenix",
        "Firebird" => "Firebird",
        "Camino" => "Camino",
        "Netscape" => "Netscape",
        "OmniWeb" => "OmniWeb",
        "Safari" => "Safari",
        "Mozilla" => "Mozilla",
        "Konqueror" => "Konqueror",
        "icab" => "iCab",
        "Lynx" => "Lynx",
        "Links" => "Links",
        "hotjava" => "HotJava",
        "amaya" => "Amaya",
        "IBrowse" => "IBrowse",
        "Maxthon" => "Maxthon",
        "Ubuntu" => "Ubuntu Web Browser",
        "obigo" => "Obigo",
        "netfront" => "Netfront Browser",
        "openwave" => "Openwave Browser",
        "mobilexplorer" => "Mobile Explorer",
        "operamini" => "Opera Mini",
        "opera mini" => "Opera Mini",
        "opera mobi" => "Opera Mobile",
        "fennec" => "Firefox Mobile",
    );
    foreach ($browser_array as $regex => $browser) {
        if (preg_match("/" . $regex . "/", ParseUA())) {
            return $browser;
        }
    }
    return "Unknown Browser";
}

function whois()
{
    return @json_decode(file_get_contents("http://ip-api.com/json/" . getIp()), true);
}

function logger($data, $reason)
{
    $today = date('l, d F H H:i:s');
    $visit = whois();
    $fopen = fopen("./bot_logs.txt", "a+") or die("Unable to open file!");
    $body = "🔥 [ BLAZE ANTIBOT ] 🔥" . PHP_EOL;
    $body .= "REASON: {$reason} | CODE: " . uniqid() . PHP_EOL;
    $body .= "BOT: {$data}" . PHP_EOL;
    $body .= "DATE: {$today}" . PHP_EOL;
    $body .= "IP Address: " . getIP() . PHP_EOL;
    $body .= "COUNTRY: {$visit['country']}" . PHP_EOL;
    $body .= "REGION: {$visit['city']}" . PHP_EOL;
    $body .= "ORGANISATION: {$visit['isp']}" . PHP_EOL;
    $body .= "ASN: {$visit['as']}" . PHP_EOL;
    $body .= "HOSTNAME: " . gethostbyaddr(getIP()) . PHP_EOL;
    $body .= "OS: " . getOS() . PHP_EOL;
    $body .= "BROWSER: " . getBrowser() . PHP_EOL;
    $body .= "USER AGENT: ". ParseUA() . PHP_EOL;
    fwrite($fopen, $body);
    fclose($fopen);
}

$hostname = gethostbyaddr(getIP());
$ua = strtolower(ParseUA()); 
$visit = whois();
$asn = $visit["as"]; $isp = $visit["isp"];

$badHosts = array(
    "colocrossing.com",
    "QuerySeekerSpider",
    ":bot",
    "samsung-sgh-e250",
    "R6_CommentReader",
    "pgp key agent",
    "w3mir",
    "roadhouse",
    "linkalarm",
    "jakarta",
    "Feedfetcher-Google",
    "spider",
    "minirank",
    "blog",
    "web wombat",
    "oracle",
    "hku www octopus",
    "scooter",
    "link validator",
    "picosearch",
    "stelkom.net",
    "wget",
    "voyager",
    "informant",
    "EBAY",
    "bingbot",
    "is74.ru",
    "shore.net",
    "xget",
    "surriel.com",
    "omni",
    "Http Crawler",
    "gcreep",
    "lbot",
    "miva",
    "Dr.Web",
    "cyberinfo",
    "orb search",
    "wapproxy",
    "Feedly",
    "apercite",
    "Sogou web spider",
    "silk",
    "search.",
    "titan",
    "digitalcourage.de",
    "weblogmonitor",
    "aruba",
    "untrusted",
    "msnbot",
    "dr.web",
    "xift",
    "nutch",
    "deepindex",
    "vbot",
    "aboutusbot",
    "wavefire",
    "whizbang",
    "yandexbot",
    "grabber",
    "atn",
    "adsbot-google",
    "aplix",
    "multitext",
    "bingpreview",
    "pagepeeker",
    "pogodak",
    "pagebull",
    "gazz",
    "image.kapsi.net",
    "scoutjet",
    "monitis.com",
    "web hopper",
    "imagelock",
    "instagram",
    "acoi",
    "mj12",
    "GrapeshotCrawler",
    "mediapartners",
    "SMXCrawler",
    "scrubby",
    "adaxas",
    "aportworm",
    "griffon",
    "VoilaBot",
    "ShowyouBot",
    "CCBot",
    "internet shinchakubin",
    "anzwers",
    "robbie",
    "openintelligencedata",
    "PaperLiBot",
    "acoonbot",
    "curl",
    "TweetedTimes Bot",
    "cassandra",
    "arachnophilia",
    "blo.",
    "unknown.telecom.gomel.by",
    "hkuwwwoctopus",
    "TweetedTimesBot",
    "cloudflare",
    "phantomjs",
    "calif",
    "ucsd",
    "phishtank",
    "t-h-u-n-d-e-r-s-t-o-n-e",
    "jack",
    "ezresult",
    "mbot",
    "ebot",
    "legs",
    "csci",
    "evliya celebi",
    "UnwindFetchor",
    "poirot",
    "nbot",
    "updated",
    "altavista",
    "webvac",
    "asked",
    "golem",
    "MaxPointCrawler",
    "linkvalidator",
    "rambler",
    "pompos",
    "webzinger",
    "gulliver",
    "helix",
    "webhopper",
    "calyxinstitute",
    "download express",
    "ovh.net",
    "nokia6682",
    "larbin",
    "hosting",
    "p3pwgdsn",
    "appie",
    "webfoot",
    "depspid",
    "webcopy",
    "supersnooper",
    "msn",
    "zippp",
    "pimptrain",
    "geosr",
    "URLAppendBot",
    "dreamhost",
    "mailshell",
    "(bot",
    "nec-meshexplorer",
    "acoon",
    "theophrastus",
    "zipcommander",
    "noyona",
    "Macintosh",
    "netcartawebmapengine",
    "fetchrover",
    "panscient",
    "applebot",
    "TencentTraveler",
    "kdd-explorer",
    "bilbo",
    "cusco",
    "hilfe-veripayed.com",
    "facebook",
    "wanderer",
    "ah-ha.com",
    "salty",
    "weblinker",
    "hotmail!",
    "raven search",
    "ip3000",
    "Mediapartners-Google",
    "packrat",
    "4seohuntbot",
    "outlook",
    "presto",
    "httrack",
    "microsofturlcontrol",
    "cymru.com",
    "BazQuxBot",
    "spyder",
    "e-collector",
    "nomad",
    "feedfetcher",
    "valkyrie",
    "fetcher6-2.go.mail.ru",
    "avg",
    "softlayer",
    "aretha",
    "baboom",
    "Python-urllib",
    "picsearch",
    "wwwster",
    "X11",
    "blaiz",
    "cienciaficcion",
    "titin",
    "externalhit",
    "vultr",
    "netresearchserver",
    "webbandit",
    "Jobboerse Crawler ",
    "w3m2",
    "lighthouse",
    "PulseCrawler",
    "roadrunner",
    "suke",
    "netpilot",
    "searchprocess",
    "googlebot",
    "arale",
    "bot.",
    "findlinks",
    "arks",
    "sitevalet",
    "voyager/",
    "triolan.net",
    "myweb",
    "nationaldirectory",
    "AhrefsBot",
    "compatible",
    "toutatis",
    "trendmicro",
    "paypal",
    "hyper-decontextualizer",
    "mediafox",
    "bannana_bot",
    "mapoftheinternet",
    "spinner",
    "zteopen",
    "crawl",
    "bradley",
    "netcraft",
    "pinpoint",
    "security",
    "bigbrother",
    "patric",
    "webwalk",
    "SPRO-NET-209-19-128",
    "internetshinchakubin",
    "gsa-crawler",
    "motor",
    "charlotte",
    "shark",
    "windows 95",
    "dieblindekuh",
    "labelgrabber",
    "araneo",
    "htmlindex",
    "Kraken",
    "crawlconvera",
    "yeti",
    "jetbot",
    "ditto",
    "dyn.plus.net",
    "webcore",
    "sbider",
    "butterfly",
    "Ezooms",
    "metauri",
    "simtccflow1.etn.com",
    "go-http-client",
    "webcatcher",
    "ananzi",
    "seek",
    "sven",
    "abacho",
    "amzn_assoc",
    "Yahoo! Slurp",
    "urlcheck",
    "steeler/",
    "comrise.ru",
    "zao",
    "hinet.net",
    "lssrocketcrawler",
    "shopwiki",
    "html index",
    "lachesis",
    "havindex",
    "007ac9",
    "iltrovatore",
    "phantom",
    "online-domain-tools",
    "Googlebot",
    "staircaseirony",
    "robozilla",
    "tutorgig",
    "worldlight",
    "NetSeer crawler",
    "delorie",
    "starnet.md",
    "drweb",
    "html_analyzer",
    "sucuri.net",
    "grokkit-crawler",
    "occam",
    "azure",
    "hubater",
    "apache-httpclient",
    "phising",
    "192.comagent",
    "safebrowsing",
    "reverseshorturl",
    "_bot",
    "israeli-search",
    "digger",
    "osis-project",
    "outlook!",
    "200pleasebot",
    "apple.com",
    "urlredirectresolver",
    "pear.",
    "homerweb",
    "atlocal",
    "nzexplorer",
    "abot",
    "spam",
    "webmirror",
    "e-active.nl",
    "Windows XP",
    "webwombat",
    "yahoo",
    "wauuu",
    "ibm_planetwide",
    "iconsurf",
    "indexer",
    "webmonkey",
    "Lighthouse",
    "cfetch",
    "Spinn3r",
    "ybot",
    "kyivstar.net",
    "008",
    "baiduspider",
    "walker",
    "incywincy",
    "camehttps",
    "lycos",
    "heritrix",
    "slurp",
    "yodao",
    "eset",
    "mwd.search",
    "aladin",
    "nokia6682/",
    "biglotron",
    "YoudaoBot",
    "abrave spider",
    "libwww",
    "grapnel",
    "sidewinder",
    "marvin",
    "headless",
    "yanga",
    "robofox",
    "SPRO-NET-207-70-0",
    "webreaper",
    "addthis.com",
    "gralon",
    "preview",
    "fish search",
    "augurfind",
    "asterias",
    "unchaos",
    "quicklook",
    "moose",
    "ia_archiver",
    "hotmail",
    "google",
    "bruuk.sk",
    "muncher",
    "objectssearch",
    "twisted",
    "telegram",
    "SISTRIX Crawler",
    "tarantula",
    "python",
    "voyager-hc",
    "ahrefsbot",
    "aboundexbot",
    "baidu",
    "Butterfly",
    "messagelabs",
    "mattie",
    "trident",
    "avast",
    "muscatferret",
    "webstolperer",
    "woriobot",
    "Exabot",
    "ferret",
    "najdi",
    "sphere",
    "htdig",
    "bot/",
    "virus",
    "minsktelecom.by",
    "architext",
    "Sogouwebspider",
    "tkwww",
    "aspseek",
    "scanurl",
    "arabot",
    "BitDefender",
    "majestic12",
    "PercolateCrawler",
    "netsparker",
    "msn!",
    "mcafee",
    "whowhere",
    "anonymizer",
    "gromit",
    "esther",
    "url check",
    "peregrinator",
    "javabee",
    "combine",
    "mpdedicated.com",
    "geturl",
    "avira",
    "mercator",
    "weblog monitor",
    "seamonkey",
    "sysms.net",
    "safesurfingwidget",
    "jetbrains",
    "amagit.com",
    "churl",
    "grub",
    "cyveillance",
    "page_verifier",
    "xenu",
    "alkaline",
    "netmechanic",
    "web core",
    "icoreservice",
    "progtech.ru",
    "ebiness",
    "ichiro",
    "daumoa",
    "simmany",
    "fishsearch",
    "w3c_validator",
    "R6_FeedFetcher",
    "whatsapp",
    "YandexBot",
    "80legs.com/webcrawler",
    "sitetech-rover",
    "btcentralplus.com",
    "dalvik",
    "rbot",
    "genieknows",
    "Genieo",
    "dwcp",
    "uptimerobot.com",
    "privoxy",
    "torservers",
    "felixide",
    "big brother",
    "duckduck",
    "50.nu",
    "mnogosearch",
    "smartwit",
    "amibot",
    "nederland.zoek",
    "populariconoclast",
    "del.icio.us",
    "PrintfulBot",
    "-bot",
    "tor-exit",
    "senrigan",
    "site valet",
    "plumtreewebaccessor",
    "wwwc",
    "dtaagent",
    "bloodhound",
    "emacs-w3 search engine",
    "as9105.com",
    "funnelweb",
    "knowledge",
    "admantx",
    "downloadexpress",
    "pack rat",
    "snooper",
    "deweb",
    "yahoo!",
    "emacs-w3searchengine",
    "intelliagent",
    "sylera",
    "sl-reverse.com",
    "avant",
    "linkdexbot",
    "gmetrix",
    "teledata-fttx.de",
    "sogou",
    "piranha",
    "crawler",
    "Baiduspider",
    "mantraagent",
    "a6-indexer",
    "echo blinde kuh",
    "sohu",
    "cmc",
    "annotate",
    "collective",
    "poppelsdorf",
    "antbot",
    "merzscope",
    "ebay",
    "jabber",
    "docomo",
    "obot",
    "dmoz",
    "amuri.net",
    "duckduckbot",
    "vagabondo",
    "websnarf",
    "blackwidow",
    "publisher",
    "sift",
    "ahoy",
    "comagent",
    "windows xp",
    "parked.factioninc.com",
    "dbot",
    "wallpaper",
    "mon.itor.us",
    "virustotal",
    "analytics",
    "python-requests",
    "kretrieve",
    "templeton",
    "accoona",
    "kilroy",
    "MJ12bot",
    "yandex",
    "SearchmetricsBot",
    "pegasus",
    "tach black widow",
    "/teoma",
    "bdfetch",
    "java",
    "opendns",
    "bot",
    "newscan-online",
    "moget",
    "fouineur",
    "BomboraBot",
    "parasite",
    "pgpkeyagent",
    "popular iconoclast",
    "cloud",
    "goforit",
    "jumpstation",
    "inspectorweb",
    "sg-scout",
    "wildferret",
    "partnersite",
    "aranha",
    "pycurl",
    "ncsa beta",
    "linkscan",
    "above",
    "websitepulse",
    "ivia",
    "poppi",
    "360spider",
    "infobee",
    "miniature",
    "pbot",
    "ipredator",
    "phpdig",
    "hicoria.com",
    "windows 98",
    "googletranslate",
    "ejupiter",
    "openfind",
    "Yahoo!Slurp",
    "baypup",
    "speedfind",
    ".bot",
    "psycheclone",
    "webwatch",
    "tbot",
    "ask24",
    "hbot",
    "nodemeter.net",
    "zbot",
    "/bot",
    "xirq",
    "Trident",
    "computingsite",
    "evliyacelebi",
    "tlh.ro",
    "webquest",
    "teoma",
    "fireball",
    "twitter",
    "surfnomore",
    "rules",
    "victoria",
    "urlresolver",
    "zao/",
    "nhse",
    "TweetmemeBot",
    "pageboy",
    "snappy",
    "spbot",
    "tachblackwidow",
    "booch",
    "hamahakki",
    "nameprotect",
    "ingrid",
    "magpie",
    "proximic",
    "lockon",
    "cisco",
    "inspector web",
    "vision-search",
    "adressendeutschland",
    "skymob.com",
    "mozilla",
    "ah-ha",
    "sygol",
    "siteexplorer",
    "microsoft url control",
    "atomz",
    "road runner",
    "verticrawl",
    "....",
    "sogou-test-spider",
    "harvest",
    "kbot",
    "nazilla",
    "prcdn.net",
    "versanet.de",
    "fangcrawl",
    "anthill",
    "steeler",
    "acunetix",
    "InAGist",
    "hostinger",
    "ravensearch",
    "msnbot-media",
    "SiteChecker",
    "orange-labs",
    "opentext",
    "getterroboplus",
    "monster",
    "antivirus",
    "ncsabeta",
    "sna-",
    "piltdownman",
    "die blinde kuh",
    "speedtravel",
    "sphider",
    "htmlgobble",
    "CL0NA",
    "felix ide",
    "askaboutoil",
    "phish",
    "yahooSeeker",
    "katipo",
    "merlinkbot",
    "agada",
    "ebingbong",
    "fido",
    "amznkassocbot",
    "netscoop",
    "DomainAppender",
    "wild ferret",
    "metauri.com",
    "linode.com",
    "facebookexternalhit",
    "accelobot",
    "kototoi",
    "roach",
    "glx",
    "inktomisearch.com",
    "site searcher",
    "pioneer",
    "NetSeercrawler",
    "exabot",
    "upcloud.host",
    "Y!J-BRW",
    "shaihulud",
    "udmsearch",
    "Twitterbot",
    "dreampassport",
    "open text",
    "Cliqzbot",
    "boitho",
    "suntek",
    "anzwerscrawl",
    "alexabot",
    "szukacz",
    "volcano",
    "neofonie",
    "twiceler",
    "sbot",
    "marvin/",
    "iron33",
    "t-rex",
    "proxy",
    "NING",
    "bjaaland",
    "NetcraftSurveyAgent",
    "magpie-crawler",
    "orbsearch",
    "semanticdiscovery",
    "sleek",
    "sitesearcher",
    "downnotifier",
    "ccubee",
    "falcon",
    "googlebot.com",
    "translate",
    "clamav",
    "lwp",
    "backrub",
    "zyborg",
    "weblayers",
    "netcarta webmap engine",
    "SISTRIXCrawler",
    "anonymizing-proxy"
);
foreach ($badHosts as $badHost) {
    if (stripos(ParseUA(), $badHost)) {
        logger($badHost, "BOT USERAGENT");
        die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
    }
}
$badISPs = array(
    "GoDaddy.com, LLC",
    "SiteAdvisor",
    "Google Cloud",
    "SC Rusnano",
    "University of",
    "Daniel James Austin",
    "dreamhost",
    "EGIHosting",
    "Yahoo",
    "McAfee",
    "Host",
    "Nobis Technology Group",
    "LinkGrid LLC",
    "softlayer",
    "Universidade Federal do Rio de Janeiro",
    "Twitter",
    "9New Network Inc",
    "TalkTalk",
    "Teksavvy Solutions Inc.",
    "avirasoft",
    "Westnet",
    "Whitelabel IT Solutions Corp",
    "University",
    "this.is.a.tor.node.xmission.com",
    "France Telecom S.A.",
    "Snab-Inform Private Enterprise",
    "Apexis",
    "Hostalia",
    "Bell Canada",
    "tor.piratenpartei-nrw.de",
    "GigeNET",
    "AntiVirus",
    "QualityNetwork",
    "Choopa",
    "UK Dedicated Servers Limited",
    "Internet-Pro",
    "Cisco Systems Inc.",
    "Telegram Messenger Network",
    "British Telecommunications PLC",
    "PSINet Inc.",
    "Host1Plus Cloud Servers",
    "clicktargetdevelopment.com",
    "Iomart Hosting Limited",
    "colocrossing.com",
    "Hosting Solution",
    "Digital Energy Technologies Limited",
    "Facebook",
    "ImOn Communications, LLC",
    "Iomart Hosting Ltd",
    "Blue Coat Systems",
    "Apexis AG",
    "Bitdefender",
    "DedFiberCo",
    "Fortinet",
    "Schulte Consulting LLC",
    "ESET spol. s r.o.",
    "Spectrum",
    "SURFnet",
    "Virtual1 Limited",
    "WhatsApp",
    "noisetor",
    "CloudVPN",
    "Vist On-Line Ltd",
    "Host1Plus",
    "Digital Domain",
    "LukMAN Multimedia Sp. z o.o",
    "Redpill Linpro AS",
    "LogicWeb",
    "Hosteros LLC",
    "PHPNET Hosting Services",
    "Unus Inc.",
    "Sectoor",
    "Quintex Alliance Consulting",
    "Wintek Corporation",
    "ITCOM Shpk",
    "Hostwinds",
    "Versaweb",
    "Apple Inc.",
    "PIPEX-BLOCK1",
    "ExpressVPN",
    "trendmicro",
    "Comodo",
    "HighWinds Network",
    "Kaspersky",
    "Akamai",
    "crawl",
    "The University of Tokyo",
    "Junk Email Filter Inc.",
    "this.is.a.tor.exit-node.net",
    "M-net",
    "MYX Group LLC",
    "TalkTalk Communications Limited",
    "Private Customer",
    "Netprotect SRL",
    "proxy",
    "Total Server Solutions",
    "phishtank.com",
    "SoftLayer",
    "cloudflare",
    "Wowrack.com",
    "Top Level Hosting SRL",
    "CloudFlare",
    "OVH",
    "Internet Security - TC",
    "Static IP Assignment",
    "Glenayre Electronics Inc.",
    "Involta",
    "Level 3 Communications",
    "NewMedia Express",
    "Global Data Networks LLC",
    "Tahoe Internet Exchange (TahoeIX)",
    "london-tor.mooo.com",
    "vultr.com",
    "Linode",
    "Sungard Network Solutions",
    "Udasha",
    "Long Thrive",
    "Claro Dominican Republic",
    "exit-01a.noisetor.net",
    "OVH Hosting Inc.",
    "pacbell.net",
    "crawler",
    "tor-exit",
    "Nine Internet Solutions AG",
    "UPC Romania Bucuresti",
    "healingpathsolutions.com",
    "Microsoft",
    "ovh.net",
    "Microsoft Corporation",
    "VPSmalaysia.com.my",
    "PlusNet Technologies Ltd",
    "RedSwitches Pty",
    "Chelyabinsk-Signal LLC",
    "Liquid Web",
    "QuadraNet",
    "Creative Thought Inc.",
    "Vultr Holdings LLC",
    "Orange Polska Spolka Akcyjna",
    "calyxinstitute",
    "rima-tde.net",
    "Host Sailor Ltd.",
    "GoDaddy",
    "cyveillance",
    "noisetor.net",
    "SoftLayer Technologies",
    "AVAST Software s.r.o.",
    "Fireeye",
    "XO Communications",
    "Eir Broadband",
    "roamsite.com",
    "Time Warner Cable Internet LLC",
    "Flokinet Ltd",
    "Online SAS",
    "B2 Net Solutions",
    "torservers",
    "Virtual Employee Pvt Ltd",
    "LukMAN",
    "cpanel66.proisp.no",
    "NForce Entertainment B.V.",
    "CachedNet",
    "yahoo",
    "Petersburg Internet Network Ltd.",
    "Cisco Systems",
    "Online S.A.S.",
    "Host Europe GmbH",
    "Barracuda Networks",
    "Symantec",
    "Computer Problem Solving",
    "www16.mailshell.com",
    "Lixux OU",
    "static.spro.net",
    "ChinaNet Fujian Province Network",
    "Vertical Telecoms Broadband Networks and Internet Provider",
    "enom",
    "RamNode",
    "Solution Pro",
    "Rackspace",
    "Content Delivery Network Ltd",
    "OJSC Oao Tattelecom",
    "Zayo Bandwidth",
    "sucuri.net",
    "Parrukatu",
    "IPVanish",
    "SunGard Availability Services LP",
    "GANDI SAS",
    "Mozilla",
    "Bitfolk",
    "Art Matrix - Lightlink Inc.",
    "Psychz",
    "NFOrce Entertainment B.V.",
    "Trustwave Holdings Inc",
    "antivirus",
    "Infosphere",
    "ZenLayer",
    "Peak 10",
    "Tehnologii Budushego LLC",
    "Onavo Mobile Ltd",
    "exit0.liskov.tor-relays.net",
    "Amazon Technologies Inc.",
    "Xs4all Internet BV",
    "Palo Alto Networks",
    "Barracuda Networks Inc.",
    "University of Newcastle upon Tyne",
    "A100 ROW",
    "Web Hosting Solutions",
    "HostUS",
    "Instagram",
    "Incapsula Inc",
    "Yahoo! Inc.",
    "Hosting",
    "netcraft",
    "DigitalOcean",
    "Eonix Corporation",
    "ScanSafe Services",
    "Flokinet",
    "ServerMania",
    "LG DACOM",
    "HEG US",
    "Simpli Networks LLC",
    "Blazing SEO",
    "tor-node.com",
    "Internap Network Services Corporation",
    "Digital Ocean",
    "DME Hosting LLC",
    "Complete Internet Access",
    "Voxility",
    "Sony",
    "013 NetVision",
    "trustwave",
    "Baidu",
    "ebbs.healingpathsolutions.com",
    "p3pwgdsn",
    "Oracle",
    "Avira",
    "The Calyx Institute",
    "Team Technologies LLC",
    "Dosarrest",
    "TerraTransit AG",
    "hosttech GmbH",
    "Choopa, LLC",
    "Inter Connects Inc",
    "Public facing services",
    "msnbot",
    "comodo",
    "Mainloop",
    "Madgenius.com",
    "Cubenode System SL",
    "centralnic",
    "Security",
    "Dataline Ltd",
    "Return Path Inc.",
    "Amazon Data Services NoVa",
    "Quasi Networks LTD",
    "M247 LTD Frankfurt Infrastructure",
    "Plusnet",
    "Zscaler",
    "netpilot",
    "PathsConnect",
    "SecuredConnectivity.net",
    "Master Internet",
    "Merit Network",
    "Eircom Customer Assignment",
    "spider.clicktargetdevelopment.com",
    "IQ PL Sp. z o.o.",
    "badware",
    "Global Perfomance",
    "PrivateSystems Networks",
    "tor.tocici.com",
    "London Wires Ltd.",
    "Network and Information Technology Limited",
    "eSecureData",
    "HostDime.com",
    "Fastly",
    "Customer Network",
    "Ventelo Wholesale",
    "tfbnw.net",
    "Server",
    "phishtank",
    "Server Plan S.r.l.",
    "Inktomi Corporation",
    "Scaleway",
    "ColoUp",
    "Nobis Technology Group LLC",
    "Datacamp Limited",
    "VI Na Host Co. Ltd",
    "VNET a.s.",
    "Digiweb ltd",
    "Prescient Software",
    "ebay",
    "Intersoft Internet",
    "ClientID",
    "University of Virginia",
    "paypal",
    "Solar VPS",
    "Psychz Networks",
    "Hetzner Online",
    "phishing",
    "Barracuda",
    "Secure Internet",
    "Private IP Address LAN",
    "Spark New Zealand Trading Ltd",
    "SurfControl",
    "tpnet.pl",
    "JSC ER-Telecom Holding",
    "Internet Customers"
);
foreach ($badISPs as $badISP) {
    if (preg_match("/" . $badISP . "/i", $isp)) {
        logger($badISP, "BOT ISP");
        die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
    }
}

$blocked_words = array("deltainfocom", "dnsserverhosting", "Java/1.6.0_22", "Go-http-client/1.1", "drweb", "Dr.Web", "hostinger", "scanurl", "above", "level3", "level", "involta", "SOLUTIONPRO-NET", "SOLUTION", "SolutionPro", "SPRO-NET-206-80-96", "SPRO-NET-207-70-0", "SPRO-NET-209-19-128", "LVLT-STATIC-4-14-16", "americanexpress", "google", "softlayer", "cyveillance", "phishtank", "dreamhost", "netpilot", "calyxinstitute", "tor-exit", "paypal", "facebook", "ebay", "Baiduspider", "ia_archiver", "R6_FeedFetcher", "NetcraftSurveyAgent", "Sogou web spider", "PrintfulBot", "UnwindFetchor", "urlresolver", "Butterfly", "TweetmemeBot", "PaperLiBot", "MJ12bot", "AhrefsBot", "Exabot", "Ezooms", "YandexBot", "SearchmetricsBot", "picsearch", "TweetedTimes Bot", "QuerySeekerSpider", "ShowyouBot", "woriobot", "merlinkbot", "BazQuxBot", "Kraken", "SISTRIX Crawler", "R6_CommentReader", "magpie-crawler", "GrapeshotCrawler", "PercolateCrawler", "MaxPointCrawler", "R6_FeedFetcher", "NetSeer crawler", "grokkit-crawler", "SMXCrawler", "PulseCrawler", "Y!J-BRW", "datasift", "80legs.com/webcrawler", "Mediapartners-Google", "Spinn3r", "InAGist", "Python-urllib", "python-requests", "NING", "TencentTraveler", "Feedfetcher-Google", "mon.itor.us", "p3pwgdsn", "sucuri.net", "messagelabs", "torservers", "trendmicro", "spbot", "Feedly", "bot", "curl", "spider", "crawler");
foreach ($blocked_words as $word) {
    if (substr_count($hostname, $word) > 0) {
        logger($word, "BOT DETECTED");
        die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
    }
}

$bannedIP = array(
    "1.9.2.13",
    "1.9.2.15",
    "103.205.140.227",
    "103.248.172.42",
    "104.197.5.72",
    "104.223.127.208",
    "104.62.2.60",
    "104.83.233.198",
    "107.178.194.234",
    "107.178.194.64",
    "107.189.10.190",
    "107.189.10.42",
    "108.161.29.60",
    "113.116.51.127",
    "115.238.55.18",
    "119.97.214.138",
    "13.112.251.210",
    "134.209.142.35",
    "136.243.111.17 ",
    "136.243.111.17",
    "138.197.207.*",
    "138.197.207.147",
    "138.201.202.232",
    "143.3.53.161",
    "145.239.156.71",
    "145.239.156.89",
    "150.70.168.35",
    "150.70.188.167",
    "154.127.57.30",
    "159.203.0.156",
    "159.65.210.36",
    "162.224.156.32",
    "162.243.128.197",
    "162.243.187.126",
    "162.243.69.215",
    "163.172.174.24",
    "165.227.0.128",
    "165.227.39.194",
    "165.231.142.36",
    "169.38.85.109",
    "170.250.139.48",
    "173.230.147.44",
    "173.239.230.97",
    "173.239.240.147",
    "177.39.232.144",
    "178.17.170.156",
    "185.104.120.4",
    "185.104.186.168",
    "185.130.184.209",
    "185.217.171.12",
    "185.220.101.26",
    "185.220.70.151",
    "185.229.190.140",
    "185.236.201.148",
    "185.28.20.243",
    "188.166.63.71",
    "192.36.27.7",
    "194.99.105.99",
    "196.251.250.29",
    "196.52.84.81",
    "198.148.78.133",
    "202.143.148.61",
    "204.101.161.159",
    "204.13.201.137",
    "205.251.148.186",
    "208.87.233.140",
    "212.83.139.219",
    "212.83.170.209",
    "212.92.117.5",
    "216.164.117.239",
    "217.16.26.166",
    "217.182.168.178",
    "217.96.188.74",
    "217.96.197.246",
    "219.117.238.170",
    "222.154.252.*",
    "23.21.227.69",
    "23.27.153.247",
    "23.27.154.37",
    "24.23.24.144",
    "2600:1900:2000:38:400::10",
    "27.0.1453.110",
    "27.54.62.91",
    "3.0.04506.648",
    "3.0.4506.2152",
    "3.101.0.4",
    "31.13.191.161",
    "31.168.158.239",
    "34.229.141.32",
    "34.237.113.113",
    "34.66.238.194",
    "34.71.81.227",
    "35.166.160.161",
    "35.202.98.254",
    "35.223.233.20",
    "35.224.124.244",
    "35.243.23.74",
    "35.243.23.83",
    "37.120.213.169",
    "37.187.96.202",
    "39.0.2150.5",
    "4.14.0.0",
    "4.14.64.*",
    "40.94.89.*",
    "41.0.2272.118",
    "43.0.2357.81",
    "44.0.2403.155",
    "46.101.119.24",
    "46.101.94.163",
    "46.248.190.0",
    "46.248.190.1",
    "46.248.190.10",
    "46.248.190.100",
    "46.248.190.101",
    "46.248.190.102",
    "46.248.190.103",
    "46.248.190.104",
    "46.248.190.105",
    "46.248.190.106",
    "46.248.190.107",
    "46.248.190.108",
    "46.248.190.109",
    "46.248.190.11",
    "46.248.190.110",
    "46.248.190.111",
    "46.248.190.112",
    "46.248.190.113",
    "46.248.190.114",
    "46.248.190.115",
    "46.248.190.116",
    "46.248.190.117",
    "46.248.190.118",
    "46.248.190.119",
    "46.248.190.12",
    "46.248.190.120",
    "46.248.190.121",
    "46.248.190.122",
    "46.248.190.123",
    "46.248.190.124",
    "46.248.190.125",
    "46.248.190.126",
    "46.248.190.127",
    "46.248.190.128",
    "46.248.190.129",
    "46.248.190.13",
    "46.248.190.130",
    "46.248.190.131",
    "46.248.190.132",
    "46.248.190.133",
    "46.248.190.134",
    "46.248.190.135",
    "46.248.190.136",
    "46.248.190.137",
    "46.248.190.138",
    "46.248.190.139",
    "46.248.190.14",
    "46.248.190.140",
    "46.248.190.141",
    "46.248.190.142",
    "46.248.190.143",
    "46.248.190.144",
    "46.248.190.145",
    "46.248.190.146",
    "46.248.190.147",
    "46.248.190.148",
    "46.248.190.149",
    "46.248.190.15",
    "46.248.190.150",
    "46.248.190.151",
    "46.248.190.152",
    "46.248.190.153",
    "46.248.190.154",
    "46.248.190.155",
    "46.248.190.156",
    "46.248.190.157",
    "46.248.190.158",
    "46.248.190.159",
    "46.248.190.16",
    "46.248.190.160",
    "46.248.190.161",
    "46.248.190.162",
    "46.248.190.163",
    "46.248.190.164",
    "46.248.190.165",
    "46.248.190.166",
    "46.248.190.167",
    "46.248.190.168",
    "46.248.190.169",
    "46.248.190.17",
    "46.248.190.170",
    "46.248.190.171",
    "46.248.190.172",
    "46.248.190.173",
    "46.248.190.174",
    "46.248.190.175",
    "46.248.190.176",
    "46.248.190.177",
    "46.248.190.178",
    "46.248.190.179",
    "46.248.190.18",
    "46.248.190.180",
    "46.248.190.181",
    "46.248.190.182",
    "46.248.190.183",
    "46.248.190.184",
    "46.248.190.185",
    "46.248.190.186",
    "46.248.190.187",
    "46.248.190.188",
    "46.248.190.189",
    "46.248.190.19",
    "46.248.190.190",
    "46.248.190.191",
    "46.248.190.192",
    "46.248.190.193",
    "46.248.190.194",
    "46.248.190.195",
    "46.248.190.196",
    "46.248.190.197",
    "46.248.190.198",
    "46.248.190.199",
    "46.248.190.2",
    "46.248.190.20",
    "46.248.190.200",
    "46.248.190.201",
    "46.248.190.202",
    "46.248.190.203",
    "46.248.190.204",
    "46.248.190.205",
    "46.248.190.206",
    "46.248.190.207",
    "46.248.190.208",
    "46.248.190.209",
    "46.248.190.21",
    "46.248.190.210",
    "46.248.190.211",
    "46.248.190.212",
    "46.248.190.213",
    "46.248.190.214",
    "46.248.190.215",
    "46.248.190.216",
    "46.248.190.217",
    "46.248.190.218",
    "46.248.190.219",
    "46.248.190.22",
    "46.248.190.220",
    "46.248.190.221",
    "46.248.190.222",
    "46.248.190.223",
    "46.248.190.224",
    "46.248.190.225",
    "46.248.190.226",
    "46.248.190.227",
    "46.248.190.228",
    "46.248.190.229",
    "46.248.190.23",
    "46.248.190.230",
    "46.248.190.231",
    "46.248.190.232",
    "46.248.190.233",
    "46.248.190.234",
    "46.248.190.235",
    "46.248.190.236",
    "46.248.190.237",
    "46.248.190.238",
    "46.248.190.239",
    "46.248.190.24",
    "46.248.190.240",
    "46.248.190.241",
    "46.248.190.242",
    "46.248.190.243",
    "46.248.190.244",
    "46.248.190.245",
    "46.248.190.246",
    "46.248.190.247",
    "46.248.190.248",
    "46.248.190.249",
    "46.248.190.25",
    "46.248.190.250",
    "46.248.190.26",
    "46.248.190.27",
    "46.248.190.28",
    "46.248.190.29",
    "46.248.190.3",
    "46.248.190.30",
    "46.248.190.31",
    "46.248.190.32",
    "46.248.190.33",
    "46.248.190.34",
    "46.248.190.35",
    "46.248.190.36",
    "46.248.190.37",
    "46.248.190.38",
    "46.248.190.39",
    "46.248.190.4",
    "46.248.190.40",
    "46.248.190.41",
    "46.248.190.42",
    "46.248.190.43",
    "46.248.190.44",
    "46.248.190.45",
    "46.248.190.46",
    "46.248.190.47",
    "46.248.190.48",
    "46.248.190.49",
    "46.248.190.5",
    "46.248.190.50",
    "46.248.190.51",
    "46.248.190.52",
    "46.248.190.53",
    "46.248.190.54",
    "46.248.190.55",
    "46.248.190.56",
    "46.248.190.57",
    "46.248.190.58",
    "46.248.190.59",
    "46.248.190.6",
    "46.248.190.60",
    "46.248.190.61",
    "46.248.190.62",
    "46.248.190.63",
    "46.248.190.64",
    "46.248.190.65",
    "46.248.190.66",
    "46.248.190.67",
    "46.248.190.68",
    "46.248.190.69",
    "46.248.190.7",
    "46.248.190.70",
    "46.248.190.71",
    "46.248.190.72",
    "46.248.190.73",
    "46.248.190.74",
    "46.248.190.75",
    "46.248.190.76",
    "46.248.190.77",
    "46.248.190.78",
    "46.248.190.79",
    "46.248.190.8",
    "46.248.190.80",
    "46.248.190.81",
    "46.248.190.82",
    "46.248.190.83",
    "46.248.190.84",
    "46.248.190.85",
    "46.248.190.86",
    "46.248.190.87",
    "46.248.190.88",
    "46.248.190.89",
    "46.248.190.9",
    "46.248.190.90",
    "46.248.190.91",
    "46.248.190.92",
    "46.248.190.93",
    "46.248.190.94",
    "46.248.190.95",
    "46.248.190.96",
    "46.248.190.97",
    "46.248.190.98",
    "46.248.190.99",
    "47.30.133.89",
    "5.189.142.136",
    "5.62.39.18",
    "5.62.41.35",
    "5.62.56.91",
    "50.112.194.65",
    "50.116.2.167",
    "50.16.241.113",
    "50.16.241.114",
    "50.16.241.117",
    "50.16.247.234",
    "51.0.2704.103",
    "51.15.136.98",
    "52.18.11.161",
    "52.192.164.225",
    "52.204.27.85",
    "52.204.97.54",
    "52.27.2.86",
    "52.31.63.97",
    "52.5.190.19",
    "52.5.98.73",
    "52.72.33.140",
    "52.87.10.90",
    "52.91.94.56",
    "53.0.2785.116",
    "54.197.234.188",
    "54.198.55.229",
    "54.207.33.42",
    "54.208.100.253",
    "54.213.103.141",
    "54.228.218.117",
    "54.245.191.79",
    "56.0.2924.87",
    "57.0.2987.98",
    "61.0.3116.0",
    "62.210.13.58",
    "62.24.252.133",
    "62.67.194.35",
    "63.0.3239.132",
    "63.123.238.8",
    "64.0.3282.140",
    "64.0.3282.167",
    "64.110.130.5",
    "65.214.45.143",
    "65.214.45.148",
    "66.0.3358.0",
    "66.0.3359.0",
    "66.235.124.101",
    "66.235.124.192",
    "66.235.124.193",
    "66.235.124.196",
    "66.235.124.7",
    "66.235.124.73",
    "66.235.124.74",
    "66.249.66.1",
    "66.249.91.*",
    "66.249.91.203",
    "67.0.3360.0",
    "67.0.3361.0",
    "68.183.245.118",
    "68.65.53.71",
    "69.164.111.198",
    "69.171.251.118",
    "69.25.58.61",
    "74.211.8.61",
    "74.50.56.239",
    "75.163.12.85",
    "76.19.184.88",
    "77.69.251.230",
    "8.28.16.254",
    "80.104.176.17",
    "80.44.175.165",
    "80.67.172.162",
    "81.0.48.*",
    "81.0.48.138",
    "82.102.18.114",
    "82.102.19.136",
    "82.102.27.124",
    "82.102.27.75",
    "82.102.27.77",
    "82.223.27.82",
    "83.31.41.195",
    "83.31.41.200",
    "83.97.23.38",
    "84.13.191.239",
    "84.17.43.76",
    "84.92.148.184",
    "87.113.78.97",
    "87.113.96.90",
    "87.115.213.2",
    "87.115.231.241",
    "88.99.62.141",
    "89.197.44.226",
    "89.234.157.254",
    "89.238.131.150",
    "89.238.139.12",
    "91.103.66.200",
    "91.231.212.111",
    "92.103.69.158",
    "93.107.26.45",
    "97.85.126.186^66.102.*.*",
    "^1.128.96.181",
    "^1.132.97.75",
    "^1.152.96.223",
    "^1.152.97.32",
    "^1.234.41.*",
    "^1.33.126.*",
    "^100.43.*.*",
    "^100.6.107.*",
    "^101.174.147.73",
    "^103.19.16.*",
    "^103.35.*.*",
    "^103.6.76.*",
    "^103.86.99.*",
    "^104.108.64.175",
    "^104.131.165.123",
    "^104.131.223.*",
    "^104.132.*.*",
    "^104.132.20.*",
    "^104.146.*.*",
    "^104.15.60.*",
    "^104.16.*.*",
    "^104.193.88.*",
    "^104.236.153.*",
    "^104.42.*.*",
    "^105.107.79.*",
    "^106.12.*.*",
    "^106.133.165.*",
    "^107.170.*.*",
    "^107.178.*.*",
    "^107.178.194.*",
    "^107.178.195.*",
    "^107.20.181.*",
    "^108.162.215.*",
    "^108.162.246.*",
    "^108.210.106.*",
    "^109.186.*.*",
    "^110.88.*.*",
    "^111.231.*.*",
    "^111.89.*.*",
    "^115.231.36.*",
    "^119.63.*.*",
    "^12.148.196.*",
    "^12.148.209.*",
    "^124.66.185.*",
    "^128.242.*.*",
    "^128.28.*.*",
    "^128.72.*.*",
    "^128.75.*.*",
    "^13.57.36.*",
    "^131.*.*.*",
    "^131.120.12.*",
    "^131.212.*.*",
    "^131.253.*.*",
    "^133.11.204.*",
    "^134.119.*.*",
    "^134.170.2.199",
    "^138.122.*.*",
    "^139.59.*.*",
    "^14.101.178.*",
    "^141.101.104.*",
    "^141.185.209.*",
    "^144.217.82.*",
    "^147.75.210.*",
    "^148.163.128.*",
    "^149.20.*.*",
    "^149.20.54.*",
    "^157.*.*.*",
    "^157.201.10.*",
    "^157.39.109.*",
    "^157.54.*.*",
    "^157.55.39.*",
    "^158.108.*.*",
    "^158.69.216.*",
    "^162.158.*.*",
    "^162.158.7.*",
    "^162.158.72.*",
    "^162.158.95.*",
    "^162.244.*.*",
    "^163.195.178.*",
    "^167.24.*.*",
    "^168.188.*.*",
    "^169.207.238.*",
    "^17.198.249.*",
    "^172.217.*.*",
    "^173.11.97.*",
    "^173.14.18.*",
    "^173.192.*.*",
    "^173.194.*.*",
    "^173.194.112.*",
    "^173.194.116.102",
    "^173.194.116.149",
    "^173.205.33.*",
    "^173.224.160.*",
    "^173.224.161.*",
    "^173.224.162.*",
    "^173.224.163.*",
    "^173.224.164.*",
    "^173.224.165.*",
    "^173.224.166.*",
    "^173.224.167.*",
    "^173.239.*.*",
    "^173.244.36.*",
    "^173.245.55.*",
    "^173.252.*.*",
    "^173.252.86.*",
    "^174.255.*.*",
    "^175.135.172.*",
    "^176.195.231.*",
    "^178.43.117.*",
    "^178.62.113.173",
    "^180.29.89.*",
    "^181.229.*.*",
    "^182.75.120.*",
    "^182.75.120.10",
    "^184.165.*.*",
    "^184.173.*.*",
    "^185.145.156.*",
    "^185.2.138.*",
    "^185.20.4.*",
    "^185.20.5.*",
    "^185.220.101.*",
    "^185.28.20.*",
    "^185.28.20.243",
    "^185.41.162.*",
    "^185.75.*.*",
    "^185.75.141.32",
    "^186.6.*.*",
    "^188.165.83.*",
    "^188.166.*.*",
    "^188.207.200.*",
    "^188.244.39.*",
    "^190.82.81.*",
    "^191.98.136.*",
    "^192.115.134.*",
    "^192.118.48.*",
    "^192.232.213.*",
    "^193.128.*.*",
    "^193.220.178.*",
    "^193.221.113.53",
    "^193.226.*.*",
    "^193.253.199.*",
    "^193.47.80.*",
    "^194.153.113.*",
    "^194.52.68.*",
    "^194.72.238.*",
    "^194.90.*.*",
    "^195.128.227.*",
    "^195.211.*.*",
    "^195.211.23.*",
    "^196.23.168.*",
    "^198.186.190.*",
    "^198.186.191.*",
    "^198.186.192.*",
    "^198.186.193.*",
    "^198.25.*.*",
    "^198.41.243.*",
    "^198.54.*.*",
    "^198.60.236.*",
    "^198.68.61.*",
    "^199.3.10.*",
    "^199.30.228.*",
    "^199.59.150.*",
    "^202.*.*.*",
    "^202.108.252.*",
    "^202.160.*.*",
    "^203.188.221.*",
    "^203.215.181.*",
    "^204.*.*.*",
    "^204.101.161.159",
    "^204.119.24.*",
    "^204.14.48.*",
    "^204.251.90.*",
    "^204.85.191.*",
    "^205.201.132.*",
    "^206.207.*.*",
    "^206.207.80.*",
    "^206.253.226.*",
    "^206.28.72.*",
    "^206.80.*.*",
    "^207.*.*.*",
    "^207.126.144.*",
    "^207.46.*.*",
    "^207.46.8.167",
    "^207.46.8.199",
    "^207.68.*.*",
    "^207.70.*.*",
    "^207.70.60.*",
    "^207.80.*.*",
    "^208.101.*.*",
    "^208.43.225.*",
    "^208.65.144.*",
    "^208.76.45.53",
    "^208.84.*.*",
    "^208.87.233.*",
    "^208.91.115.*",
    "^209.*",
    "^209.135.212.*",
    "^209.185.108.*",
    "^209.185.253.*",
    "^209.19.*.*",
    "^209.19.185.*",
    "^209.19.186.231",
    "^209.191.*.*",
    "^209.66.70.*",
    "^209.73.228.*",
    "^209.85.*.*",
    "^209.85.128.*",
    "^210.55.200.*",
    "^212.113.37.*",
    "^212.143.*.*",
    "^212.150.*.*",
    "^212.235.*.*",
    "^212.29.192.*",
    "^212.29.224.*",
    "^212.50.193.*",
    "^212.8.79.*",
    "^213.*.*.*",
    "^213.100.*.*",
    "^216.10.193.*",
    "^216.162.209.*",
    "^216.239.*.*",
    "^216.239.32.*",
    "^216.252.*.*",
    "^216.252.167.*",
    "^216.33.229.163",
    "^216.58.*.*",
    "^216.58.211.37",
    "^217.132.*.*",
    "^217.16.26.*",
    "^217.16.26.166",
    "^217.74.103.*",
    "^217.96.*.*",
    "^219.*.*.*",
    "^219.117.238.170",
    "^222.154.252.*",
    "^23.27.152.*",
    "^24.172.*.*",
    "^35.153.86.*",
    "^35.172.115.*",
    "^36.74.236.*",
    "^36.83.56.*",
    "^37.128.131.171",
    "^37.140.188.*",
    "^38.100.*.*",
    "^38.105.*.*",
    "^38.144.36.*",
    "^38.74.138.*",
    "^4.14.0.0",
    "^4.14.64.*",
    "^4.14.64.*.*",
    "^40.107.*.*",
    "^40.121.198.*",
    "^40.85.158.*",
    "^41.208.72.*",
    "^42.112.8.*",
    "^46.101.119.*",
    "^46.101.249.238",
    "^46.101.43.*",
    "^46.116.*.* ",
    "^46.116.*.*",
    "^46.244.*.*",
    "^46.4.120.*",
    "^49.104.10.*",
    "^5.189.*.*",
    "^50.107.*.*",
    "^50.7.*.*",
    "^50.97.*.*",
    "^51.15.*.*",
    "^52.31.147.*",
    "^52.90.*.*",
    "^54.164.*.*",
    "^54.176.*.*",
    "^54.228.218.*",
    "^54.228.218.117",
    "^61.21.221.*",
    "^62.116.207.*",
    "^62.141.65.*",
    "^62.149.225.67",
    "^62.90.*.*",
    "^62.99.77.*",
    "^63.*.*.*",
    "^64.*.*.*",
    "^64.106.213.*",
    "^64.124.14.*",
    "^64.18.*.*",
    "^64.233.*.*",
    "^64.233.160.*",
    "^64.233.173.*",
    "^64.233.191.*",
    "^64.233.191.255*",
    "^64.235.*.*",
    "^64.235.153.*",
    "^64.235.154.*",
    "^64.27.2.*",
    "^64.37.103.*",
    "^64.4.*.*",
    "^64.62.136.*",
    "^64.62.175.*",
    "^64.68.*.*",
    "^64.68.90.*",
    "^64.68.90.*^81.161.59.*",
    "^64.71.*.*",
    "^64.71.193.*",
    "^64.71.204.*",
    "^64.71.205.*",
    "^64.71.206.*",
    "^64.74.*.*",
    "^64.74.215.*",
    "^65.*.*.*",
    "^65.208.151.*",
    "^65.52.*.*",
    "^65.54.188.110",
    "^65.54.188.126",
    "^65.54.188.94",
    "^65.55.206.154",
    "^65.55.33.119",
    "^65.55.33.135",
    "^65.55.37.104",
    "^65.55.37.120",
    "^65.55.37.72",
    "^65.55.37.88",
    "^65.55.85.12",
    "^65.55.92.136",
    "^65.55.92.152",
    "^65.55.92.168",
    "^65.55.92.184",
    "^66.102.*.*",
    "^66.102.6.*",
    "^66.102.8.*",
    "^66.135.200.*",
    "^66.150.14.*",
    "^66.196.*.*",
    "^66.205.64.*",
    "^66.207.120.*",
    "^66.211.160.86*",
    "^66.211.169.3",
    "^66.211.169.66",
    "^66.214.*.*",
    "^66.221.*.*",
    "^66.228.*.*",
    "^66.249.*.*",
    "^67.15.*.*",
    "^67.195.*.*",
    "^67.209.128.*",
    "^68.*.*.*",
    "^68.14.83.*",
    "^68.142.*.*",
    "^68.65.53.71",
    "^69.164.*.*",
    "^69.164.111.*",
    "^69.164.145.*",
    "^69.61.12.*",
    "^69.65.*.*",
    "^72.13.86.*",
    "^72.14.*.*",
    "^72.14.192.*",
    "^72.14.199.*",
    "^72.30.*.*",
    "^72.49.133.*",
    "^72.52.96.*",
    "^72.94.249.*",
    "^74.125.*.*",
    "^74.125.133.*",
    "^74.6.*.*",
    "^78.148.13.*",
    "^79.79.147.162",
    "^79.79.148.223",
    "^8.12.*.*",
    "^8.23.224.*",
    "^8.6.48.*",
    "^81.161.59.*",
    "^82.166.*.*",
    "^83.31.*.*",
    "^83.31.118.*",
    "^83.31.69.*",
    "^83.71.*.*",
    "^84.51.153.*",
    "^84.93.84.*",
    "^85.250.*.*",
    "^85.64.*.*",
    "^85.9.7.*",
    "^86.132.235.*",
    "^87.106.251.*",
    "^87.115.213.*",
    "^89.108.102.*",
    "^89.138.*.*",
    "^89.163.159.214",
    "^89.234.*.*",
    "^91.103.66.*",
    "^91.231.*.*",
    "^91.231.212.*",
    "^92.103.69.*",
    "^92.189.25.*",
    "^92.23.56.*",
    "^93.119.*.*",
    "^93.172.*.*",
    "^93.54.82.*",
    "^94.26.*.*",
    "^95.108.194.*",
    "^95.45.252.*",
    "^95.76.156.*",
    "^95.85.*.*",
    "^98.136.*.*", '1.9.2.13', '1.9.2.15', '1.128.96.181', '1.132.97.75', '1.152.96.223', '1.152.97.32', '2.57.122.25', '2.57.169.39', '3.21.190.175', '3.231.57.131', '3.239.251.167', '4.14.0.0', '5.62.39.18', '5.62.41.35', '5.62.56.91', '5.101.137.195', '5.101.174.196', '5.181.234.188', '5.226.142.232', '15.236.18.4', '18.117.82.207', '23.21.227.69', '23.27.153.247', '23.27.154.37', '23.202.231.167', '23.217.138.108', '24.23.24.144', '27.0.1453.110', '27.54.62.91', '31.168.158.239', '34.204.239.194', '34.222.143.168', '34.237.113.113', '35.84.132.147', '37.19.196.223', '37.128.131.171', '37.187.96.202', '37.252.238.50', '38.108.182.5', '38.145.80.113', '39.0.2150.5', '40.114.51.187', '43.0.2357.81', '44.0.2403.155', '45.33.89.168', '45.55.4.49', '45.55.4.51', '45.55.76.116', '45.72.48.130', '45.146.164.110', '46.101.35.65', '46.101.80.156', '46.101.94.163', '46.101.249.238', '46.134.7.80', '47.30.133.89', '50.16.241.113', '50.16.241.114', '50.16.241.117', '50.16.247.234', '50.112.194.65', '50.116.2.167', '51.0.2704.103', '51.15.191.81', '51.89.194.75', '51.89.217.2', '51.89.217.115', '51.89.228.201', '51.89.235.201', '51.103.26.168', '52.5.98.73', '52.5.190.19', '52.16.137.212', '52.17.89.34', '52.17.122.199', '52.18.11.161', '52.18.84.133', '52.18.243.153', '52.19.73.31', '52.19.95.184', '52.19.96.28', '52.19.107.105', '52.19.223.183', '52.27.2.86', '52.27.133.197', '52.30.18.87', '52.30.171.229', '52.31.63.97', '52.31.95.244', '52.31.138.216', '52.31.206.114', '52.51.31.125', '52.53.157.84', '52.72.33.140', '52.87.10.90', '52.91.94.56', '52.192.164.225', '52.204.97.54', '52.250.30.131', '53.0.2785.116', '54.38.210.133', '54.72.98.149', '54.154.176.190', '54.197.234.188', '54.208.100.253', '54.213.103.141', '54.217.117.101', '54.221.27.173', '54.228.218.117', '54.245.191.79', '56.0.2924.87', '57.0.2987.98', '61.0.3116.0', '62.24.252.133', '62.67.194.35', '62.149.225.67', '62.210.13.58', '63.0.3239.132', '63.123.238.8', '64.0.3282.140', '64.0.3282.167', '64.62.197.152', '64.137.22.213', '64.227.39.49', '64.227.43.95', '65.54.188.94', '65.54.188.110', '65.54.188.126', '65.55.33.119', '65.55.33.135', '65.55.37.72', '65.55.37.88', '65.55.37.104', '65.55.37.120', '65.55.85.12', '65.55.92.136', '65.55.92.152', '65.55.92.168', '65.55.92.184', '65.55.206.154', '65.154.226.100', '65.154.226.165', '65.155.30.101', '65.214.45.143', '65.214.45.148', '66.0.3358.0', '66.0.3359.0', '66.102.6.10', '66.211.169.3', '66.211.169.66', '66.235.124.7', '66.235.124.73', '66.235.124.74', '66.235.124.101', '66.235.124.192', '66.235.124.193', '66.235.124.196', '66.249.66.1', '66.249.91.203', '67.0.3360.0', '67.0.3361.0', '68.65.53.71', '68.183.38.243', '68.183.40.47', '68.183.41.202', '68.183.241.134', '68.183.245.118', '69.25.58.56', '69.164.111.198', '74.120.14.39', '75.126.243.167', '75.163.12.85', '76.19.184.88', '77.69.251.230', '77.247.110.194', '79.79.147.162', '79.79.148.223', '79.185.91.53', '80.44.18.224', '80.104.176.17', '81.0.48.138', '82.102.27.75', '82.102.27.77', '82.112.184.223', '82.223.27.82', '83.41.123.192', '84.13.191.239', '84.17.35.232', '84.92.148.184', '86.106.87.228', '86.188.235.233', '86.188.235.235', '87.113.96.90', '87.115.213.2', '88.99.62.141', '89.36.26.183', '89.163.159.214', '89.234.157.254', '91.231.212.111', '92.103.69.158', '96.248.52.19', '97.85.126.186', '99.80.179.158', '99.86.159.17', '99.86.159.25', '99.86.159.53', '99.86.159.115', '101.174.147.73', '103.248.172.42', '104.62.2.60', '104.83.233.198', '104.108.64.175', '104.131.57.83', '104.131.165.123', '104.131.211.8', '104.152.222.37', '104.152.222.45', '104.209.191.112', '104.244.72.115', '104.248.172.31', '105.112.37.85', '107.152.233.69', '107.173.59.173', '107.178.194.64', '108.161.29.60', '115.238.55.18', '119.97.214.138', '122.155.174.74', '128.1.248.42', '128.14.133.58', '128.14.141.34', '128.14.209.162', '128.199.184.47', '129.88.46.51', '134.170.2.199', '138.68.157.33', '138.68.167.164', '138.197.207.147', '139.99.252.94', '145.239.156.71', '145.239.156.89', '145.239.206.161', '146.185.135.132', '146.185.179.135', '147.147.220.127', '150.70.168.35', '150.70.188.167', '150.136.105.132', '154.3.44.202', '154.16.122.18', '154.127.57.30', '157.230.194.216', '157.230.210.133', '157.245.40.134', '157.245.43.122', '158.222.8.6', '159.65.210.36', '159.89.154.136', '159.89.220.57', '159.203.0.156', '161.35.41.76', '161.35.89.84', '161.35.89.180', '161.35.89.202', '161.35.121.7', '161.35.161.175', '161.97.151.211', '162.142.125.40', '162.221.192.26', '162.224.156.32', '162.243.69.215', '162.243.88.97', '162.243.128.197', '162.243.187.126', '163.172.174.24', '165.22.30.11', '165.227.0.128', '165.227.39.194', '165.232.96.172', '167.71.13.196', '167.88.60.234', '167.88.60.254', '167.99.192.69', '167.172.48.243', '167.248.133.37', '168.151.106.211', '168.151.162.215', '170.250.139.48', '171.13.14.44', '173.194.116.102', '173.194.116.149', '173.230.147.44', '173.239.230.97', '173.239.240.147', '174.138.115.170', '177.39.232.144', '178.17.170.156', '178.33.144.176', '178.62.113.173', '178.128.140.117', '178.128.194.144', '178.238.11.64', '178.238.11.119', '180.149.125.175', '181.214.32.196', '181.214.58.235', '181.214.145.163', '181.214.180.214', '181.215.27.41', '181.215.79.103', '181.215.93.11', '181.215.147.13', '182.75.120.10', '184.170.246.173', '185.17.27.109', '185.28.20.243', '185.75.141.32', '185.104.120.4', '185.104.186.168', '185.130.184.200', '185.169.233.84', '185.169.255.131', '185.216.74.42', '185.220.101.26', '185.226.144.12', '185.229.190.140', '188.166.63.71', '191.96.116.221', '192.36.27.7', '192.81.220.62', '192.241.193.223', '192.241.202.166', '192.241.219.51', '193.27.12.164', '193.118.53.202', '193.118.53.210', '193.176.30.76', '193.221.113.53', '193.226.177.45', '194.36.110.198', '195.239.51.49', '196.52.84.81', '198.50.163.54', '198.211.109.153', '198.240.89.162', '198.240.101.144', '202.143.148.61', '204.13.201.137', '204.101.161.159', '205.169.39.138', '205.169.39.183', '206.189.17.148', '206.189.18.205', '206.189.26.4', '206.189.127.212', '206.189.255.141', '207.46.8.167', '207.46.8.199', '207.154.228.159', '207.154.229.251', '207.154.255.200', '208.76.45.53', '208.80.194.27', '208.80.194.31', '208.87.233.140', '208.87.234.140', '209.19.186.231', '209.97.136.148', '209.97.188.243', '212.83.139.219', '212.83.170.209', '212.92.117.5', '216.19.220.109', '216.33.229.163', '216.58.211.37', '216.131.76.16', '216.163.176.191', '216.164.117.239', '216.218.206.69', '217.16.26.166', '217.96.188.74', '217.96.197.246', '219.117.238.170', '^1.33.126.*', '^1.234.41.*', '^2.57.*.*', '^3.21.*.*', '^3.231.*.*', '^3.239.*.*', '^4.14.64.*', '^5.189.*.*', '^8.6.48.*', '^8.12.*.*', '^8.23.224.*', '^10.8.0.*', '^12.148.196.*', '^12.148.209.*', '^13.32.219.*', '^13.57.36.*', '^13.224.193.*', '^14.101.178.*', '^15.236.*.*', '^17.198.249.*', '^18.117.*.*', '^23.27.152.*', '^23.251.*.*', '^24.172.*.*', '^34.141.*.*', '^34.204.*.*', '^34.222.*.*', '^35.84.*.*', '^35.153.86.*', '^35.172.115.*', '^36.74.236.*', '^36.83.56.*', '^37.140.188.*', '^38.74.138.*', '^38.100.*.*', '^38.105.*.*', '^38.108.*.*', '^38.144.36.*', '^40.85.158.*', '^40.107.*.*', '^40.114.*.*', '^40.121.198.*', '^41.208.72.*', '^42.112.8.*', '^45.33.*.*', '^45.55.2.*', '^45.72.*.*', '^45.79.*.*', '^45.146.*.*', '^46.4.120.*', '^46.101.43.*', '^46.101.119.*', '^46.116.*.*', '^46.244.*.*', '^49.104.10.*', '^50.7.*.*', '^50.97.*.*', '^50.107.*.*', '^51.15.*.*', '^51.103.*.*', '^51.141.*.*', '^52.27.*.*', '^52.31.147.*', '^52.53.*.*', '^52.90.*.*', '^54.164.*.*', '^54.176.*.*', '^54.221.*.*', '^54.228.218.*', '^61.21.221.*', '^62.90.*.*', '^62.99.77.*', '^62.116.207.*', '^62.141.65.*', '^64.4.*.*', '^64.18.*.*', '^64.27.2.*', '^64.37.103.*', '^64.62.136.*', '^64.62.175.*', '^64.62.*.*', '^64.68.90.*', '^64.68.*.*', '^64.71.193.*', '^64.71.204.*', '^64.71.205.*', '^64.71.206.*', '^64.71.*.*', '^64.74.215.*', '^64.74.*.*', '^64.106.213.*', '^64.124.14.*', '^64.137.*.*', '^64.233.160.*', '^64.233.173.*', '^64.233.191.255*', '^64.233.191.*', '^64.233.*.*', '^64.235.153.*', '^64.235.154.*', '^64.235.*.*', '^65.52.*.*', '^65.154.*.*', '^65.208.151.*', '^66.102.6.*', '^66.102.8.*', '^66.102.*.*', '^66.135.200.*', '^66.150.14.*', '^66.196.*.*', '^66.205.64.*', '^66.207.120.*', '^66.211.160.86*', '^66.211.168.*', '^66.211.169.*', '^66.211.170.*', '^66.211.171.*', '^66.214.*.*', '^66.221.*.*', '^66.228.*.*', '^66.249.91.*', '^66.249.*.*', '^67.15.*.*', '^67.195.*.*', '^67.209.128.*', '^68.14.83.*', '^68.142.*.*', '^69.61.12.*', '^69.65.*.*', '^69.164.111.*', '^69.164.145.*', '^69.164.*.*', '^71.6.*.*', '^72.13.86.*', '^72.14.192.*', '^72.14.199.*', '^72.14.*.*', '^72.30.*.*', '^72.49.133.*', '^72.52.96.*', '^72.94.249.*', '^74.6\..*.*', '^74.120.*.*', '^74.125.133.*', '^74.125.*.*', '^77.247.*.*', '^78.148.13.*', '^81.0.48.*', '^81.161.59.*', '^82.102.*.*', '^82.166.*.*', '^83.31.69.*', '^83.31.118.*', '^83.31.*.*', '^83.41.*.*', '^83.71.*.*', '^84.51.153.*', '^84.93.84.*', '^85.9.7.*', '^85.64.*.*', '^85.250.*.*', '^86.132.235.*', '^87.106.251.*', '^87.115.213.*', '^89.108.102.*', '^89.138.*.*', '^89.187.*.*', '^89.234.*.*', '^91.103.66.*', '^91.231.212.*', '^91.231.*.*', '^92.23.56.*', '^92.103.69.*', '^92.189.25.*', '^93.54.82.*', '^93.119.*.*', '^93.172.*.*', '^94.26.*.*', '^95.45.252.*', '^95.76.156.*', '^95.85.*.*', '^95.108.194.*', '^98.136.*.*', '^100.6.107.*', '^100.43.*.*', '^103.6.76.*', '^103.19.16.*', '^103.35.*.*', '^103.86.99.*', '^104.15.60.*', '^104.42.*.*', '^104.131.223.*', '^104.132.20.*', '^104.132.*.*', '^104.140.*.*', '^104.236.153.*', '^105.107.79.*', '^106.12.*.*', '^106.133.165.*', '^107.20.181.*', '^107.170.*.*', '^107.178.194.*', '^107.178.195.*', '^107.178.*.*', '^108.162.215.*', '^108.162.246.*', '^108.210.106.*', '^109.186.*.*', '^110.88.*.*', '^111.89.*.*', '^111.231.*.*', '^115.231.36.*', '^119.63.*.*', '^124.66.185.*', '^128.1.*.*', '^128.14.*.*', '^128.28.*.*', '^128.72.*.*', '^128.75.*.*', '^128.199.154.*', '^128.242.*.*', '^131.120.12.*', '^131.212.*.*', '^131.253.*.*', '^133.11.204.*', '^134.119.*.*', '^134.122.*.*', '^134.209.*.*', '^136.144.*.*', '^138.122.*.*', '^138.197.207.*', '^139.59.*.*', '^141.101.104.*', '^141.185.209.*', '^143.204.90.*', '^143.204.209.*', '^144.86.*.*', '^144.217.82.*', '^146.112.*.*', '^147.75.210.*', '^148.163.128.*', '^149.20.54.*', '^149.20.*.*', '^149.154.*.*', '^157.39.109.*', '^157.54.*.*', '^157.55.39.*', '^157.201.10.*', '^157.230.*.*', '^157.240.*.*', '^158.69.216.*', '^158.108.*.*', '^159.65.*.*', '^161.35.*.*', '^161.97.*.*', '^162.142.*.*', '^162.158.7.*', '^162.158.72.*', '^162.158.95.*', '^162.158.*.*', '^162.221.*.*', '^162.244.*.*', '^163.195.178.*', '^167.24.*.*', '^167.71.*.*', '^167.99.*.*', '^167.248.*.*', '^168.151.*.*', '^168.188.*.*', '^169.207.238.*', '^172.105.*.*', '^172.217.*.*', '^173.11.97.*', '^173.14.18.*', '^173.192.*.*', '^173.194.112.*', '^173.194.*.*', '^173.205.33.*', '^173.224.160.*', '^173.224.161.*', '^173.224.162.*', '^173.224.163.*', '^173.224.164.*', '^173.224.165.*', '^173.224.166.*', '^173.224.167.*', '^173.239.*.*', '^173.244.36.*', '^173.245.55.*', '^173.252.86.*', '^173.252.*.*', '^174.255.*.*', '^175.135.172.*', '^176.195.231.*', '^178.43.117.*', '^178.62.*.*', '^178.128.*.*', '^180.29.89.*', '^180.149.*.*', '^181.214.*.*', '^181.215.*.*', '^181.229.*.*', '^182.75.120.*', '^183.136.*.*', '^184.105.*.*', '^184.165.*.*', '^184.173.*.*', '^185.2.138.*', '^185.20.4.*', '^185.20.5.*', '^185.28.20.*', '^185.41.162.*', '^185.75.*.*', '^185.145.156.*', '^185.173.*.*', '^185.220.101.*', '^186.6.*.*', '^188.165.83.*', '^188.166.*.*', '^188.207.200.*', '^188.241.156.*', '^188.244.39.*', '^190.82.81.*', '^191.98.136.*', '^192.35.*.*', '^192.115.134.*', '^192.118.48.*', '^192.232.213.*', '^192.241.*.*', '^193.47.80.*', '^193.118.*.*', '^193.128.*.*', '^193.220.178.*', '^193.226.*.*', '^193.253.199.*', '^194.52.68.*', '^194.72.238.*', '^194.90.*.*', '^194.153.113.*', '^195.128.227.*', '^195.154.*.*', '^195.211.23.*', '^195.211.*.*', '^196.23.168.*', '^198.25.*.*', '^198.41.243.*', '^198.54.*.*', '^198.60.236.*', '^198.68.61.*', '^198.186.190.*', '^198.186.191.*', '^198.186.192.*', '^198.186.193.*', '^198.240.*.*', '^199.3.10.*', '^199.30.228.*', '^199.59.150.*', '^202.*.*.*', '^203.188.221.*', '^203.215.181.*', '^204.14.48.*', '^204.85.191.*', '^204.119.24.*', '^204.251.90.*', '^205.201.132.*', '^205.213.*.*', '^206.28.72.*', '^206.80.*.*', '^206.207.80.*', '^206.207.*.*', '^206.253.226.*', '^207.46.*.*', '^207.68.*.*', '^207.70.*.*', '^207.80.*.*', '^207.126.144.*', '^208.43.225.*', '^208.65.144.*', '^208.84.*.*', '^208.87.233.*', '^208.91.115.*', '^208.101.*.*', '^209.19.185.*', '^209.19.*.*', '^209.66.70.*', '^209.73.228.*', '^209.85.128.*', '^209.85.*.*', '^209.135.212.*', '^209.185.108.*', '^209.185.253.*', '^209.191.*.*', '^210.55.200.*', '^212.8.79.*', '^212.29.192.*', '^212.29.224.*', '^212.50.193.*', '^212.102.*.*', '^212.113.37.*', '^212.143.*.*', '^212.150.*.*', '^212.235.*.*', '^213.32.*.*', '^213.100.*.*', '^213.*.*.*', '^216.10.193.*', '^216.58.*.*', '^216.162.209.*', '^216.218.*.*', '^216.239.*.*', '^216.252.*.*', '^217.16.26.*', '^217.74.103.*', '^217.96.*.*', '^217.132.*.*', '^219.*.*.*', '^222.154.252.*', '^252.138.*.*', '^2a02:fe80:1010:.+:.+:.+:.+:.+', '^2a00:1450:.+:.+:.+:.+:.+:.+'
);
if (in_array(getIp(), $bannedIP)) {
    logger(getIp(), "BOT IP");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
} else {
    foreach ($bannedIP as $ipsss) {
        if (preg_match("/" . $ipsss . "/", getIp())) {
            logger($ipsss, "BOT IP");
            die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
        }
    }
}

$botUA=array(
    'YLT',
    '^b0t$',
    '^bluefish ',
    '^Calypso v',
    '^Corax',
    '^COMODO DCV',
    '^DangDang',
    '^DavClnt',
    '^DHSH',
    '^FDM ',
    '^git',
    '^Goose',
    '^Grabber',
    '^HTTPClient',
    '^Java',
    '^Jeode',
    '^Jetty',
    '^Mail',
    '^Mget',
    '^Microsoft URL Control',
    '^NG\/[0-9\.]',
    '^NING',
    '^Nuclei',
    '^PHP',
    '^RMA',
    '^Ruby|Ruby\/[0-9]',
    '^Swurl ',
    '^VSE\/[0-9]',
    '^WordPress\.com',
    '^XRL\/[0-9]',
    '^ZmEu',
    '008',
    '13TABS',
    '192\.comAgent',
    '2GDPR',
    '2ip\.ru',
    '404enemy',
    '7Siters',
    '80legs',
    'a\.pr-cy\.ru',
    'a3logics\.in',
    'A6-Indexer',
    'Abonti',
    'Aboundex',
    'aboutthedomain',
    'Accoona-AI-Agent',
    'acebookexternalhit',
    'acoon',
    'acrylicapps\.com\/pulp',
    'Acunetix',
    'AdAuth',
    'adbeat',
    'AddThis',
    'ADmantX',
    'AdminLabs',
    'adressendeutschland',
    'adreview',
    'adscanner',
    'Adstxtaggregator',
    'adstxt-worker',
    'adstxt\.com',
    'AffiliateLabz',
    'agentslug',
    'AHC',
    'aihit',
    'aiohttp',
    'Airmail',
    'akka-http',
    'akula',
    'alertra',
    'alexa site audit',
    'Alibaba\.Security\.Heimdall',
    'Alligator',
    'allloadin',
    'AllSubmitter',
    'alyze\.info',
    'amagit',
    '^Amazon Simple Notification Service Agent$',
    'Anarchie',
    'AndroidDownloadManager',
    'Anemone',
    'AngleSharp',
    'annotate_google',
    'Anthill',
    'Ant\.com',
    'Anturis Agent',
    'AnyEvent-HTTP',
    'Apache Droid',
    'Apache OpenOffice',
    'Apache-HttpAsyncClient',
    'Apache-HttpClient',
    'ApacheBench',
    'Apexoo',
    'apimon\.de',
    'APIs-Google',
    'AportWorm',
    'AppBeat',
    'AppEngine-Google',
    'AppleSyndication',
    'Aprc\/[0-9]',
    'Arachmo',
    'arachnode',
    'Arachnophilia',
    'aria2',
    'Arukereso',
    'asafaweb',
    'Asana',
    'AskQuickly',
    'Ask Jeeves',
    'ASPSeek',
    'Asterias',
    'Astute',
    'asynchttp',
    'Attach',
    'attohttpc',
    'autocite',
    'AutomaticWPTester',
    'Autonomy',
    'axios',
    'AWS Security Scanner',
    'B-l-i-t-z-B-O-T',
    'Backlink-Ceck',
    'backlink-check',
    'BacklinkHttpStatus',
    'BackStreet',
    'BackupLand',
    'BackWeb',
    'Bad-Neighborhood',
    'Badass',
    'baidu\.com',
    'Bandit',
    'basicstate',
    'BatchFTP',
    'Battleztar Bazinga',
    'baypup',
    'BazQux',
    'BBBike',
    'BCKLINKS',
    'BDFetch',
    'BegunAdvertising',
    'Bewica-security-scan',
    'Bidtellect',
    'BigBozz',
    'Bigfoot',
    'biglotron',
    'BingLocalSearch',
    'BingPreview',
    'binlar',
    'biNu image cacher',
    'Bitacle',
    'biz_Directory',
    'BKCTwitterUnshortener',
    'Black Hole',
    'Blackboard Safeassign',
    'BlackWidow',
    'BlockNote\.Net',
    'BlogBridge',
    'Bloglines',
    'Bloglovin',
    'BlogPulseLive',
    'BlogSearch',
    'Blogtrottr',
    'BlowFish',
    'boitho\.com-dc',
    'Boost\.Beast',
    'BPImageWalker',
    'Braintree-Webhooks',
    'Branch Metrics API',
    'Branch-Passthrough',
    'Brandprotect',
    'BrandVerity',
    'Brandwatch',
    'Brodie',
    'Browsershots',
    'BUbiNG',
    'Buck',
    'Buddy',
    'BuiltWith',
    'Bullseye',
    'BunnySlippers',
    'Burf Search',
    'Butterfly',
    'BuzzSumo',
    'CAAM\/[0-9]',
    'CakePHP',
    'Calculon',
    'Canary%20Mail',
    'CaretNail',
    'catexplorador',
    'CC Metadata Scaper',
    'Cegbfeieh',
    'censys',
    'centuryb.o.t9[at]gmail.com',
    'Cerberian Drtrs',
    'CERT\.at-Statistics-Survey',
    'cf-facebook',
    'cg-eye',
    'changedetection',
    'ChangesMeter',
    'Charlotte',
    'CheckHost',
    'checkprivacy',
    'CherryPicker',
    'ChinaClaw',
    'Chirp',
    'chkme\.com',
    'Chlooe',
    'Chromaxa',
    'CirrusExplorer',
    'CISPA Vulnerability Notification',
    'Citoid',
    'CJNetworkQuality',
    'Clarsentia',
    'clips\.ua\.ac\.be',
    'Cloud mapping',
    'CloudEndure',
    'CloudFlare-AlwaysOnline',
    'Cloudflare-Healthchecks',
    'Cloudinary',
    'cmcm\.com',
    'coccoc',
    'cognitiveseo',
    'colly -',
    'CommaFeed',
    'Commons-HttpClient',
    'commonscan',
    'contactbigdatafr',
    'contentkingapp',
    'Contextual Code Sites Explorer',
    'convera',
    'CookieReports',
    'copyright sheriff',
    'CopyRightCheck',
    'Copyscape',
    'cortex',
    'Cosmos4j\.feedback',
    'Covario-IDS',
    'Craw',
    'Crescent',
    'Crowsnest',
    'Criteo',
    'CSHttp',
    'CSSCheck',
    'Cula',
    'curb',
    'Curious George',
    'curl',
    'cuwhois',
    'cybo\.com',
    'DAP\/NetHTTP',
    'DareBoost',
    'DatabaseDriverMysqli',
    'DataCha0s',
    'Datafeedwatch',
    'Datanyze',
    'DataparkSearch',
    'dataprovider',
    'DataXu',
    'Daum(oa)?[ \/][0-9]',
    'dBpoweramp',
    'ddline',
    'deeris',
    'delve\.ai',
    'Demon',
    'DeuSu',
    'developers\.google\.com\/\+\/web\/snippet',
    'Devil',
    'Digg',
    'Digincore',
    'DigitalPebble',
    'Dirbuster',
    'Discourse Forum Onebox',
    'Disqus',
    'Dispatch',
    'DittoSpyder',
    'dlvr',
    'DMBrowser',
    'DNSPod-reporting',
    'docoloc',
    'Dolphin http client',
    'DomainAppender',
    'DomainLabz',
    'Domains Project',
    'Donuts Content Explorer',
    'dotMailer content retrieval',
    'dotSemantic',
    'downforeveryoneorjustme',
    'Download Wonder',
    'downnotifier',
    'DowntimeDetector',
    'Drip',
    'drupact',
    'Drupal \(\+http:\/\/drupal\.org\/\)',
    'DTS Agent',
    'dubaiindex',
    'DuplexWeb-Google',
    'DynatraceSynthetic',
    'EARTHCOM',
    'Easy-Thumb',
    'EasyDL',
    'Ebingbong',
    'ec2linkfinder',
    'eCairn-Grabber',
    'eCatch',
    'ECCP',
    'eContext',
    'Ecxi',
    'EirGrabber',
    'ElectricMonk',
    'elefent',
    'EMail Exractor',
    'EMail Wolf',
    'EmailWolf',
    'Embarcadero',
    'Embed PHP Library',
    'Embedly',
    'endo',
    'europarchive\.org',
    'evc-batch',
    'EventMachine HttpClient',
    'Everwall Link Expander',
    'Evidon',
    'Evrinid',
    'ExactSearch',
    'ExaleadCloudview',
    'Excel',
    'exif',
    'ExoRank',
    'Exploratodo',
    'Express WebPictures',
    'Extreme Picture Finder',
    'EyeNetIE',
    'ezooms',
    'facebookexternalhit',
    'facebookexternalua',
    'facebookplatform',
    'fairshare',
    'Faraday v',
    'fasthttp',
    'Faveeo',
    'Favicon downloader',
    'faviconkit',
    'faviconarchive',
    'FavOrg',
    'Feed Wrangler',
    'Feedable',
    'Feedbin',
    'FeedBooster',
    'FeedBucket',
    'FeedBunch',
    'FeedBurner',
    'feeder',
    'Feedly',
    'Feedshow',
    'FeedshowOnline',
    'Feedspot',
    'FeedViewer',
    'Feedwind',
    'FeedZcollector',
    'feeltiptop',
    'Fetch API',
    'Fetch\/[0-9]',
    'Fever\/[0-9]',
    'FHscan',
    'Fiery%20Feeds',
    'Filestack',
    'Fimap',
    'findlink',
    'findthatfile',
    'FlashGet',
    'FlipboardBrowserProxy',
    'FlipboardProxy',
    'FlipboardRSS',
    'Flock',
    'Florienzh',
    'fluffy',
    'Flunky',
    'flynxapp',
    'forensiq',
    'FoundSeoTool',
    'http:\/\/www.neomo.de',
    'Francis [Bot]',
    'free thumbnails',
    'Freeuploader',
    'FreshRSS',
    'Funnelback',
    'Fuzz Faster U Fool',
    'G-i-g-a-b-o-t',
    'g00g1e\.net',
    'ganarvisitas',
    'gdnplus\.com',
    'geek-tools',
    'Genieo',
    'GentleSource',
    'GetCode',
    'Getintent',
    'GetLinkInfo',
    'getprismatic',
    'GetRight',
    'getroot',
    'GetURLInfo',
    'GetWeb',
    'Geziyor',
    'Ghost Inspector',
    'GigablastOpenSource',
    'GIS-LABS',
    'github-camo',
    'GitHub-Hookshot',
    'github\.com',
    'Goldfire Server',
    'Go [\d\.]* package http',
    'Go http package',
    'Go-Ahead-Got-It',
    'Go-http-client',
    'Go!Zilla',
    'gobyus',
    'Gofeed',
    'gofetch',
    'GomezAgent',
    'gooblog',
    'Goodzer',
    '^Google$',
    'Google AppsViewer',
    'Google Desktop',
    'Google favicon',
    'Google Keyword Suggestion',
    'Google Keyword Tool',
    'Google Page Speed Insights',
    'Google-Podcast',
    'Google PP Default',
    'Google Search Console',
    'Google Web Preview',
    'Google-Ads-Creatives-Assistant',
    'Google-Ads-Overview',
    'Google-Adwords',
    'Google-Apps-Script',
    'Google-Calendar-Importer',
    'Google-HotelAdsVerifier',
    'Google-HTTP-Java-Client',
    'Google-Publisher-Plugin',
    'Google-Read-Aloud',
    'Google-SearchByImage',
    'Google-Site-Verification',
    'Google-speakr',
    'Google-Structured-Data-Testing-Tool',
    'Google-Youtube-Links',
    'google-xrawler',
    'GoogleDocs',
    'GoogleHC',
    'GoogleProducer',
    'GoogleSites',
    'Google-Transparency-Report',
    'Gookey',
    'GoSpotCheck',
    'gosquared-thumbnailer',
    'Gotit',
    'GoZilla',
    'grabify',
    'GrabNet',
    'Grafula',
    'Grammarly',
    'GrapeFX',
    'GreatNews',
    'Gregarius',
    'GRequests',
    'grokkit',
    'grouphigh',
    'grub-client',
    'gSOAP',
    'GT::WWW',
    'GTmetrix',
    'GuzzleHttp',
    'gvfs',
    'HAA(A)?RTLAND http client',
    'Haansoft',
    'hackney',
    'Hadi Agent',
    'HappyApps-WebCheck',
    'Hatena',
    'Havij',
    'HaxerMen',
    'HeadlessChrome',
    'HEADMasterSEO',
    'HeartRails_Capture',
    'help@dataminr\.com',
    'heritrix',
    'Hexometer',
    'historious',
    'hkedcity',
    'hledejLevne\.cz',
    'Hloader',
    'HMView',
    'Holmes',
    'HonesoSearchEngine',
    'HootSuite Image proxy',
    'Hootsuite-WebFeed',
    'hosterstats',
    'HostTracker',
    'ht:\/\/check',
    'htdig',
    'HTMLparser',
    'htmlyse',
    'HTTP Banner Detection',
    'HTTP_Compression_Test',
    'http_request2',
    'http_requester',
    'http-get',
    'HTTP-Header-Abfrage',
    'http-kit',
    'http-request',
    'HTTP-Tiny',
    'HTTP::Lite',
    'http\.rb',
    'http_get',
    'HttpComponents',
    'httphr',
    'HTTPMon',
    'HTTPie',
    'httpRequest',
    'httpscheck',
    'httpssites_power',
    'httpunit',
    'HttpUrlConnection',
    'httrack',
    'huaweisymantec',
    'HubSpot ',
    'HubSpot-Link-Resolver',
    'Humanlinks',
    'i2kconnect',
    'Iblog',
    'ichiro',
    'Id-search',
    'IdeelaborPlagiaat',
    'IDG Twitter Links Resolver',
    'IDwhois',
    'Iframely',
    'igdeSpyder',
    'iGooglePortal',
    'IlTrovatore',
    'Image Fetch',
    'Image Sucker',
    'ImageEngine',
    'ImageVisu',
    'Imagga',
    'imagineeasy',
    'imgsizer',
    'InAGist',
    'inbound\.li parser',
    'InDesign%20CC',
    'Indy Library',
    'InetURL',
    'infegy',
    'infohelfer',
    'InfoTekies',
    'InfoWizards Reciprocal Link',
    'inpwrd\.com',
    'instabid',
    'Instapaper',
    'Integrity',
    'integromedb',
    'Intelliseek',
    'InterGET',
    'internet_archive',
    'Internet Ninja',
    'InternetSeer',
    'internetVista monitor',
    'internetwache',
    'intraVnews',
    'IODC',
    'IOI',
    'iplabel',
    'ips-agent',
    'IPS\/[0-9]',
    'IPWorks HTTP\/S Component',
    'iqdb',
    'Iria',
    'Irokez',
    'isitup\.org',
    'iskanie',
    'isUp\.li',
    'iThemes Sync',
    'IZaBEE',
    'iZSearch',
    'JAHHO',
    'janforman',
    'Jaunt',
    'Java.*outbrain',
    'javelin\.io',
    'Jbrofuzz',
    'Jersey',
    'JetCar',
    'Jigsaw',
    'Jobboerse',
    'JobFeed discovery',
    'Jobg8 URL Monitor',
    'jobo',
    'Jobrapido',
    'Jobsearch1\.5',
    'JoinVision Generic',
    'JolokiaPwn',
    'Joomla',
    'Jorgee',
    'JS-Kit',
    'JustView',
    'Kaspersky Lab CFR link resolver',
    'Kelny',
    'Kerrigan',
    'KeyCDN',
    'Keyword Density',
    'Keywords Research',
    'khttp',
    'KickFire',
    'KimonoLabs',
    'Kml-Google',
    'knows\.is',
    'KOCMOHABT',
    'kouio',
    'kubectl',
    'kube-probe',
    'kulturarw3',
    'KumKie',
    'L\.webis',
    'Larbin',
    'Lavf',
    'LeechFTP',
    'LeechGet',
    'letsencrypt',
    'Lftp',
    'LibVLC',
    'LibWeb',
    'Libwhisker',
    'libwww',
    'Licorne',
    'Liferea',
    'Lightspeedsystems',
    'Lighthouse',
    'Likse',
    'limber\.io',
    'Link Valet',
    'link_thumbnailer',
    'LinkAnalyser',
    'LinkAlarm',
    'linkCheck',
    'linkdex',
    'LinkExaminer',
    'linkfluence',
    'linkpeek',
    'LinkScan',
    'LinksManager',
    'LinkPreview',
    'LinkTiger',
    'LinkWalker',
    'Lipperhey',
    'Litemage_walker',
    'livedoor ScreenShot',
    'LoadImpactRload',
    'localsearch-web',
    'LongURL API',
    'longurl-r-package',
    'looid\.com',
    'looksystems\.net',
    'ltx71',
    'lua-resty-http',
    'Lush Http Client',
    'lwp-request',
    'lwp-trivial',
    'LWP::Simple',
    'lycos',
    'LYT\.SR',
    'mabontland',
    'MacOutlook',
    'Mag-Net',
    'MagpieRSS',
    'Mail\.Ru',
    'MailChimp',
    'Majestic12',
    'makecontact',
    'Mandrill',
    'MapperCmd',
    'marketinggrader',
    'MarkMonitor',
    'MarkWatch',
    'Mass Downloader',
    'masscan',
    'Mata Hari',
    'mattermost',
    'Mediametric',
    'Mediapartners-Google',
    'mediawords',
    'MegaIndex\.ru',
    'MeltwaterNews',
    'Melvil Rawi',
    'MemGator',
    'Metaspinner',
    'MetaURI',
    'MFC_Tear_Sample',
    'Microsearch',
    'Microsoft\.Data\.Mashup',
    'Microsoft Office',
    'Microsoft Outlook',
    'Microsoft Windows Network Diagnostics',
    'Microsoft-WebDAV-MiniRedir',
    'Microsoft Data Access',
    'MIDown tool',
    'MIIxpc',
    'Mindjet',
    'Miniature\.io',
    'Miniflux',
    'Mister PiX',
    'mixdata dot com',
    'mixed-content-scan',
    'mixnode',
    'Mnogosearch',
    'mogimogi',
    'Mojeek',
    'Mojolicious \(Perl\)',
    'Monit',
    'monitis',
    'Monitority',
    'montastic',
    'MonTools',
    'Moreover',
    'Morfeus Fucking Scanner',
    'Morning Paper',
    'MovableType',
    'mowser',
    'Mr\.4x3 Powered',
    'Mrcgiguy',
    'MS Web Services Client Protocol',
    'MSFrontPage',
    'mShots',
    'MuckRack',
    'muhstik-scan',
    'MVAClient',
    'MxToolbox',
    'myseosnapshot',
    'nagios',
    'Najdi\.si',
    'Name Intelligence',
    'NameFo\.com',
    'Nameprotect',
    'nationalarchives',
    'Navroad',
    'NearSite',
    'Needle',
    'Nessus',
    'Net Vampire',
    'NetAnts',
    'NETCRAFT',
    'NetLyzer',
    'NetMechanic',
    'NetNewsWire',
    'Netpursual',
    'netresearch',
    'NetShelter ContentScan',
    'Netsparker',
    'NetTrack',
    'Netvibes',
    'NetZIP',
    'Neustar WPM',
    'NeutrinoAPI',
    'NewRelicPinger',
    'NewsBlur .*Finder',
    'NewsGator',
    'newsme',
    'newspaper',
    'NetSystemsResearch',
    'Nexgate Ruby Client',
    'nghttp2',
    'NG-Search',
    'Nibbler',
    'NICErsPRO',
    'Nikto',
    'nineconnections',
    'NLNZ_IAHarvester',
    'Nmap Scripting Engine',
    'node-superagent',
    'node-urllib',
    'node\.io',
    'Nodemeter',
    'NodePing',
    'nominet\.org\.uk',
    'nominet\.uk',
    'Norton-Safeweb',
    'Notifixious',
    'notifyninja',
    'NotionEmbedder',
    'nuhk',
    'nutch',
    'Nuzzel',
    'nWormFeedFinder',
    'nyawc',
    'Nymesis',
    'NYU',
    'Observatory',
    'Ocelli',
    'Octopus',
    'oegp',
    'Offline Explorer',
    'Offline Navigator',
    'OgScrper',
    'okhttp',
    'omgili',
    'OMSC',
    'Online Domain Tools',
    'OpenCalaisSemanticProxy',
    'Openfind',
    'OpenLinkProfiler',
    'Openstat',
    'OpenVAS',
    'OPPO A33',
    'Optimizer',
    'Open Source RSS',
    'Orbiter',
    'OrgProbe',
    'orion-semantics',
    'Outlook-Express',
    'Outlook-iOS',
    'ow\.ly',
    'Owler',
    'Owlin',
    'ownCloud News',
    'OxfordCloudService',
    'Page Valet',
    'page_verifier',
    'page scorer',
    'page2rss',
    'PageFreezer',
    'PageGrabber',
    'PagePeeker',
    'PageScorer',
    'Pagespeed',
    'Panopta',
    'panscient',
    'Papa Foto',
    'parsijoo',
    'Pavuk',
    'PayPal IPN',
    'pcBrowser',
    'Pcore-HTTP',
    'PDF24 URL To PDF',
    'Pearltrees',
    'PECL::HTTP',
    'peerindex',
    'Peew',
    'PeoplePal',
    'Perlu -',
    'PhantomJS Screenshoter',
    'PhantomJS',
    'Photon',
    'phpservermon',
    'php-requests',
    'Pi-Monster',
    'Picscout',
    'Picsearch',
    'PictureFinder',
    'Pimonster',
    'ping\.blo\.gs',
    'Pingability',
    'PingAdmin\.Ru',
    'Pingdom',
    'Pingoscope',
    'PingSpot',
    'pinterest\.com',
    'Pixray',
    'Pizilla',
    'Plagger',
    'Pleroma ',
    'Ploetz \+ Zeller',
    'Plukkie',
    'plumanalytics',
    'PocketImageCache',
    'PocketParser',
    'Pockey',
    'PodcastAddict',
    'POE-Component-Client-HTTP',
    'Polymail',
    'Pompos',
    'Porkbun',
    'Port Monitor',
    'postano',
    'PostmanRuntime',
    'postplanner\.com',
    'PostPost',
    'postrank',
    'PowerPoint',
    'Prebid',
    'Prerender',
    'Priceonomics Analysis Engine',
    'PrintFriendly',
    'PritTorrent',
    'Prlog',
    'probethenet',
    'Project ?25499',
    'Project-Resonance',
    'prospectb2b',
    'Protopage',
    'ProWebWalker',
    'proximic',
    'PRTG Network Monitor',
    'pshtt,
     https scanning',
    'PTST ',
    'PTST\/[0-9]+',
    'Pump',
    'python-httpx',
    'Python-httplib2',
    'python-requests',
    'Python-urllib',
    'Qirina Hurdler',
    'QQDownload',
    'QrafterPro',
    'Qseero',
    'Qualidator',
    'QueryN Metasearch',
    'queuedriver',
    'QuiteRSS',
    'Quora Link Preview',
    'Qwantify',
    'Radian6',
    'Railgun',
    'RankActive',
    'RankFlex',
    'RankSonicSiteAuditor',
    'Re-re Studio',
    'ReactorNetty',
    'Readability',
    'RealDownload',
    'RealPlayer%20Downloader',
    'RebelMouse',
    'Recorder',
    'RecurPost',
    'redback',
    'ReederForMac',
    'Reeder',
    'ReGet',
    'RepoMonkey',
    'request\.js',
    'reqwest',
    'ResponseCodeTest',
    'RestSharp',
    'Riddler',
    'Rival IQ',
    'Robosourcer',
    'Robozilla',
    'ROI Hunter',
    'RPT-HTTPClient',
    'RSSOwl',
    'RSSMix',
    'RyowlEngine',
    'safe-agent-scanner',
    'SalesIntelligent',
    'Saleslift',
    'Sendsay\.Ru',
    'SauceNAO',
    'SBIder',
    'sc-downloader',
    'scalaj-http',
    'Scamadviser-Frontend',
    'scan\.lol',
    'ScanAlert',
    'Scoop',
    'scooter',
    'ScoutJet',
    'ScopeContentAG-HTTP-Client',
    'ScoutURLMonitor',
    'ScrapeBox Page Scanner',
    'Scrapy',
    'Screaming',
    'ScreenShotService',
    'Scrubby',
    'Scrutiny',
    'search\.thunderstone',
    'Search37',
    'searchenginepromotionhelp',
    'Searchestate',
    'SearchExpress',
    'SearchSight',
    'SearchWP',
    'Seeker',
    'semanticdiscovery',
    'semanticjuice',
    'Semiocast HTTP client',
    'Semrush',
    'sentry',
    'SEO Browser',
    'Seo Servis',
    'seo-nastroj\.cz',
    'seo4ajax',
    'Seobility',
    'SEOCentro',
    'SeoCheck',
    'SEOkicks',
    'SEOlizer',
    'Seomoz',
    'SEOprofiler',
    'SEOsearch',
    'seoscanners',
    'seositecheckup',
    'SEOstats',
    'servernfo',
    'sexsearcher',
    'Seznam',
    'Shelob',
    'Shodan',
    'Shoppimon',
    'ShopWiki',
    'shortURL lengthener',
    'ShortLinkTranslate',
    'shrinktheweb',
    'Sideqik',
    'Siege',
    'SimplePie',
    'SimplyFast',
    'Siphon',
    'SISTRIX',
    'Site-Shot',
    'Site Sucker',
    'Site24x7',
    'SiteBar',
    'Sitebeam',
    'Sitebulb',
    'SiteCondor',
    'SiteExplorer',
    'SiteGuardian',
    'Siteimprove',
    'SiteIndexed',
    'Sitemap(s)? Generator',
    'SitemapGenerator',
    'SiteMonitor',
    'Siteshooter B0t',
    'SiteSnagger',
    'SiteSucker',
    'SiteTruth',
    'Sitevigil',
    'sitexy\.com',
    'SkypeUriPreview',
    'Slack',
    'slider\.com',
    'sli-systems\.com',
    'slurp',
    'SlySearch',
    'SmartDownload',
    'SMRF URL Expander',
    'SMUrlExpander',
    'Snake',
    'Snappy',
    'SnapSearch',
    'Snarfer',
    'SniffRSS',
    'sniptracker',
    'Snoopy',
    'SnowHaze Search',
    'sogou web',
    'SortSite',
    'Sottopop',
    'sovereign\.ai',
    'SpaceBison',
    'SpamExperts',
    'Spammen',
    'Spanner',
    'spaziodati',
    'SPDYCheck',
    'Specificfeeds',
    'speedy',
    'SPEng',
    'Spinn3r',
    'spray-can',
    'Sprinklr ',
    'spyonweb',
    'sqlmap',
    'Sqlworm',
    'Sqworm',
    'SSL Labs',
    'ssl-tools',
    'StackRambler',
    'Statastico',
    'Statically-Screenshot',
    'StatusCake',
    'Steeler',
    'Stratagems Kumo',
    'Stripe',
    'Stroke\.cz',
    'StudioFACA',
    'StumbleUpon',
    'suchen',
    'Sucuri',
    'summify',
    'SuperHTTP',
    'Surphace Scout',
    'Suzuran',
    'swcd ',
    'Symfony BrowserKit',
    'Symfony2 BrowserKit',
    'Syndirella',
    'SynHttpClient-Built',
    'Sysomos',
    'sysscan',
    'Szukacz',
    'T0PHackTeam',
    'tAkeOut',
    'Tarantula',
    'Taringa UGC',
    'TarmotGezgin',
    'tchelebi\.io',
    'techiaith\.cymru',
    'Teleport',
    'Telesoft',
    'Telesphoreo',
    'Telesphorep',
    'Tenon\.io',
    'teoma',
    'terrainformatica',
    'Test Certificate Info',
    'testuri',
    'Tetrahedron',
    'TextRazor Downloader',
    'The Drop Reaper',
    'The Expert HTML Source Viewer',
    'The Knowledge AI',
    'The Intraformant',
    'theinternetrules',
    'TheNomad',
    'Thinklab',
    'Thumbshots',
    'ThumbSniper',
    'Thumbor',
    'timewe\.net',
    'TinEye',
    'Tiny Tiny RSS',
    'TLSProbe',
    'Toata',
    'topster',
    'touche\.com',
    'Traackr\.com',
    'tracemyfile',
    'Trackuity',
    'TrapitAgent',
    'Trendiction',
    'Trendsmap',
    'trendspottr',
    'truwoGPS',
    'TryJsoup',
    'TulipChain',
    'Turingos',
    'Turnitin',
    'tweetedtimes',
    'Tweetminster',
    'Tweezler',
    'twibble',
    'Twice',
    'Twikle',
    'Twingly',
    'Twisted PageGetter',
    'Typhoeus',
    'ubermetrics-technologies',
    'uclassify',
    'UdmSearch',
    'unchaos',
    'unirest-java',
    'ultimate_sitemap_parser',
    'UniversalFeedParser',
    'Unshorten\.It',
    'Untiny',
    'UnwindFetchor',
    'updated',
    'updown\.io daemon',
    'Upflow',
    'Uptimia',
    'Urlcheckr',
    'URL Verifier',
    'URLitor',
    'urlresolver',
    'Urlstat',
    'URLTester',
    'UrlTrends Ranking Updater',
    'URLy Warning',
    'URLy\.Warning',
    'Vacuum',
    'Vagabondo',
    'VB Project',
    'vBSEO',
    'VCI',
    'via ggpht\.com GoogleImageProxy',
    'Virusdie',
    'visionutils',
    'vkShare',
    'VoidEYE',
    'Voil',
    'voltron',
    'voyager',
    'VSAgent',
    'VSB-TUO',
    'Vulnbusters Meter',
    'VYU2',
    'w3af\.org',
    'W3C_Unicorn',
    'W3C-checklink',
    'W3C-mobileOK',
    'WAC-OFU',
    'Wallpapers\/[0-9]+',
    'WallpapersHD',
    'WakeletLinkExpander',
    'wangling',
    'Wappalyzer',
    'WatchMouse',
    'WbSrch',
    'WDT\.io',
    'web-capture\.net',
    'Web-sniffer',
    'Web Auto',
    'Web Collage',
    'Web Enhancer',
    'Web Fetch',
    'Web Fuck',
    'Web Pix',
    'Web Sauger',
    'Web spyder',
    'Web Sucker',
    'Webalta',
    'Webauskunft',
    'WebAuto',
    'WebCapture',
    'WebClient',
    'webcollage',
    'WebCookies',
    'WebCopier',
    'WebCorp',
    'WebDataStats',
    'WebDoc',
    'WebEnhancer',
    'WebFetch',
    'WebFuck',
    'WebGazer',
    'WebGo IS',
    'WebImageCollector',
    'WebImages',
    'WebIndex',
    'webkit2png',
    'WebLeacher',
    'webmastercoffee',
    'webmon ',
    'WebPix',
    'WebReaper',
    'WebSauger',
    'webscreenie',
    'Webshag',
    'Webshot',
    'Website Quester',
    'websitepulse agent',
    'WebsiteQuester',
    'Websnapr',
    'WebSniffer',
    'Webster',
    'WebStripper',
    'WebSucker',
    'Webthumb',
    'WebThumbnail',
    'WebWhacker',
    'WebZIP',
    'WeLikeLinks',
    'WEPA',
    'WeSEE',
    'wf84',
    'Wfuzz',
    'wget',
    'WhatCMS',
    'WhatsApp',
    'WhatsMyIP',
    'WhatWeb',
    'WhereGoes\?',
    'Whibse',
    'WhoAPI',
    'WhoRunsCoinHive',
    'Whynder Magnet',
    'WinHTTP',
    'WinHttp-Autoproxy-Service',
    'Windows-RSS-Platform',
    'WinPodder',
    'wkhtmlto',
    'wmtips',
    'Woko',
    'Wolfram HTTPClient',
    'woorankreview',
    'Word',
    'WordPress',
    'worldping-api',
    'WordupinfoSearch',
    'wotbox',
    'WP Engine Install Performance API',
    'WP Rocket',
    'wpif',
    'wprecon\.com survey',
    'WPScan',
    'wscheck',
    'Wtrace',
    'WWW-Collector-E',
    'WWW-Mechanize',
    'WWW::Document',
    'WWW::Mechanize',
    'www\.monitor\.us',
    'WWWOFFLE',
    'x09Mozilla',
    'x22Mozilla',
    'XaxisSemanticsClassifier',
    'XenForo',
    'Xenu Link Sleuth',
    'XING-contenttabreceiver',
    'xpymep([0-9]?)\.exe',
    'Y!J-(ASR|BSC)',
    'Y\!J-BRW',
    'Yaanb',
    'yacy',
    'Yahoo Link Preview',
    'YahooCacheSystem',
    'YahooMailProxy',
    'YahooYSMcm',
    'YandeG',
    'Yandex(?!Search)',
    'yanga',
    'yeti',
    'Yo-yo',
    'Yoleo Consumer',
    'yomins\.com',
    'yoogliFetchAgent',
    'YottaaMonitor',
    'Your-Website-Sucks',
    'yourls\.org',
    'YoYs\.net',
    'YP\.PL',
    'Zabbix',
    'Zade',
    'Zao',
    'Zauba',
    'Zemanta Aggregator',
    'Zend_Http_Client',
    'Zend\\\\Http\\\\Client',
    'Zermelo',
    'Zeus ',
    'zgrab',
    'ZnajdzFoto',
    'ZnHTTP',
    'Zombie\.js',
    'Zoom\.Mac',
    'ZoteroTranslationServer',
    'ZyBorg',////YOCHI ANTIBOTS starting below
    'contaboserver',
    'shadowserver',
    'scanner',
    'censys',
    'leakix',
    'onyphe',
    'linode',
    'stretchoid',
    'rima-tde',
    'python',
    'github',
    'delete',
    'lifesites',
    'paloalto',
    'QIHU',
    'rederatural',
    'quadmetrics',
    'netsystemsresearch',
    'googleusercontent',
    'intrinsec',
    'scan',
    'NING',
    "(bot",
    "-bot",
    "....",
    ".bot",
    "/bot",
    "/teoma",
    "007ac9",
    "008",
    "008\/",
    "13TABS",
    "192.comagent",
    "192\.comAgent",
    "200pleasebot",
    "2ip\.ru",
    "360spider",
    "404enemy",
    "4seohuntbot",
    "50.nu",
    "7Siters",
    "80legs",
    "80legs.com/webcrawler",
    ":bot",
    "a3logics\.in",
    "a6-indexer",
    "A6-Indexer",
    "abacho",
    "Abonti",
    "abot",
    "Aboundex",
    "aboundexbot",
    "aboutthedomain",
    "aboutusbot",
    "above",
    "abrave spider",
    "accelobot",
    "accoona",
    "Accoona-AI-Agent",
    "acoi",
    "acoon",
    "acoonbot",
    "acrylicapps\.com\/pulp",
    "Acunetix",
    "acunetix",
    "AdAuth\/",
    "adaxas",
    "adbeat",
    "AddThis",
    "addthis.com",
    "admantx",
    "ADmantX",
    "AdminLabs",
    "adressendeutschland",
    "adsbot",
    "adsbot-google",
    "adscanner",
    "adstxt-worker",
    "Adstxtaggregator",
    "adstxt\.com",
    "agada",
    "agentslug",
    "agusescan",
    "ah-ha.com",
    "AHC",
    "ahoy",
    "AhrefsBot",
    "ahrefsbot",
    "aihit",
    "aiohttp\/",
    "Airmail",
    "akka-http\/",
    "akula\/",
    "aladin",
    "alertra",
    "alexa site audit",
    "alexabot",
    "Alibaba\.Security\.Heimdall",
    "alkaline",
    "Alligator",
    "allloadin",
    "AllSubmitter",
    "altavista",
    "alyze\.info",
    "amagit",
    "amagit.com",
    "amibot",
    "amznkassocbot",
    "amzn_assoc",
    "analytics",
    "ananzi",
    "Anarchie",
    "AndroidDownloadManager",
    "Anemone",
    "AngleSharp",
    "annotate",
    "annotate_google",
    "anonymizer",
    "antbot",
    "anthill",
    "antivirus",
    "Antivirus",
    "Anturis Agent",
    "Ant\.com",
    "AnyEvent-HTTP\/",
    "anzwers",
    "anzwerscrawl",
    "Apache Droid",
    "Apache OpenOffice",
    "Apache-HttpAsyncClient",
    "Apache-HttpClient",
    "apache-httpclient",
    "ApacheBench",
    "apercite",
    "Apexoo",
    "APIs-Google",
    "aplix",
    "aportworm",
    "AportWorm\/",
    "AppBeat\/",
    "AppEngine-Google",
    "appie",
    "applebot",
    "AppleSyndication",
    "AppStoreScraperZ",
    "Aprc\/[0-9]",
    "arabot",
    "Arachmo",
    "arachnode",
    "Arachnophilia",
    "arachnophilia",
    "arale",
    "araneo",
    "aranha",
    "architext",
    "aretha",
    "aria2",
    "arks",
    "Arukereso",
    "asafaweb",
    "Ask Jeeves",
    "ask24",
    "askaboutoil",
    "asked",
    "AskQuickly",
    "aspseek",
    "ASPSeek",
    "Asterias",
    "asterias",
    "Astute",
    "asynchttp",
    "atlocal",
    "atn",
    "atomz",
    "Attach",
    "augurfind",
    "autocite",
    "AutomaticWPTester",
    "Autonomy",
    "avant",
    "avast",
    "avg",
    "avira",
    "AWS Security Scanner",
    "axios\/",
    "a\.pr-cy\.ru",
    "B-l-i-t-z-B-O-T",
    "baboom",
    "Backlink-Ceck",
    "backlink-check",
    "BacklinkHttpStatus",
    "backrub",
    "BackStreet",
    "BackWeb",
    "Bad-Neighborhood",
    "Badass",
    "baidu",
    "baiduspider",
    "Baiduspider",
    "baidu\.com",
    "Bandit",
    "bannana_bot",
    "basicstate",
    "BatchFTP",
    "Battleztar Bazinga",
    "baypup",
    "baypup\/",
    "BazQux",
    "BazQuxBot",
    "BBBike",
    "BCKLINKS",
    "BDFetch",
    "bdfetch",
    "BegunAdvertising",
    "Bidtellect",
    "big brother",
    "BigBozz",
    "bigbrother",
    "Bigfoot",
    "biglotron",
    "bilbo",
    "bingbot",
    "BingLocalSearch",
    "BingPreview",
    "bingpreview",
    "binlar",
    "biNu image cacher",
    "Bitacle",
    "bitdefender",
    "biz_Directory",
    "bjaaland",
    "Black Hole",
    "Blackboard Safeassign",
    "blackwidow",
    "BlackWidow",
    "blaiz",
    "blo.",
    "BlockNote\.Net",
    "blog",
    "Bloglines",
    "Bloglovin",
    "BlogPulseLive",
    "BlogSearch",
    "Blogtrottr",
    "bloodhound",
    "BlowFish",
    "boitho",
    "boitho\.com-dc",
    "BomboraBot",
    "booch",
    "bot",
    "bot.",
    "bot/",
    "BPImageWalker",
    "bradley",
    "Braintree-Webhooks",
    "Branch Metrics API",
    "Branch-Passthrough",
    "Brandprotect",
    "BrandVerity",
    "Brandwatch",
    "Brodie\/",
    "Browsershots",
    "BUbiNG",
    "Buck\/",
    "Buddy",
    "BuiltWith",
    "Bullseye",
    "BunnySlippers",
    "Burf Search",
    "butterfly",
    "Butterfly",
    "Butterfly\/",
    "BuzzSumo",
    "CAAM\/[0-9]",
    "cache.google.com",
    "CakePHP",
    "Calculon",
    "calif",
    "calyxinstitute",
    "camehttps",
    "Canary%20Mail",
    "CaretNail",
    "cassandra",
    "catexplorador",
    "CC Metadata Scaper",
    "CCBot",
    "ccubee",
    "Cegbfeieh",
    "censys",
    "Cerberian Drtrs",
    "CERT\.at-Statistics-Survey",
    "cfetch",
    "cg-eye",
    "changeAGENT",
    "ChangesMeter",
    "Charlotte",
    "charlotte",
    "CheckHost",
    "checkprivacy",
    "CherryPicker",
    "ChinaClaw",
    "Chirp\/",
    "chkme\.com",
    "Chlooe",
    "Chromaxa",
    "churl",
    "cienciaficcion",
    "CirrusExplorer",
    "CISPA Vulnerability Notification",
    "Citoid",
    "CJNetworkQuality",
    "CL0NA",
    "Clarsentia",
    "clips\.ua\.ac\.be",
    "Cliqzbot",
    "Cloud mapping",
    "CloudEndure",
    "CloudFlare-AlwaysOnline",
    "Cloudinary",
    "cmc",
    "cmcm\.com",
    "coccoc",
    "cognitiveseo",
    "collective",
    "colly -",
    "comagent",
    "combine",
    "CommaFeed",
    "Commons-HttpClient",
    "commonscan",
    "compatible",
    "computingsite",
    "contactbigdatafr",
    "contentkingapp",
    "convera",
    "CookieReports",
    "copyright sheriff",
    "CopyRightCheck",
    "Copyscape",
    "cortex\/",
    "Cosmos4j\.feedback",
    "Covario-IDS",
    "crawl",
    "crawlconvera",
    "crawler",
    "Craw\/",
    "Crescent",
    "Criteo",
    "Crowsnest",
    "csci",
    "CSHttp",
    "CSSCheck",
    "curb",
    "Curious George",
    "curl",
    "cusco",
    "cuwhois\/",
    "cybo\.com",
    "cyveillance",
    "dalvik",
    "DAP\/NetHTTP",
    "DareBoost",
    "DatabaseDriverMysqli",
    "DataCha0s",
    "Datafeedwatch",
    "Datanyze",
    "DataparkSearch",
    "dataprovider",
    "DataXu",
    "Daum(oa)?[ \/][0-9]",
    "daumoa",
    "dbot",
    "dBpoweramp",
    "ddline",
    "deepindex",
    "deeris",
    "del.icio.us",
    "delorie",
    "Demon",
    "depspid",
    "DeuSu",
    "developers\.google\.com\/\+\/web\/snippet\/",
    "Devil",
    "deweb",
    "die blinde kuh",
    "dieblindekuh",
    "Digg",
    "digger",
    "Digincore",
    "DigitalPebble",
    "Dirbuster",
    "Discourse Forum Onebox",
    "Dispatch\/",
    "Disqus\/",
    "ditto",
    "DittoSpyder",
    "dlvr",
    "DMBrowser",
    "dmoz",
    "DNSPod-reporting",
    "docoloc",
    "docomo",
    "DoCoMo/2.0 N905i",
    "Dolphin http client",
    "DomainAppender",
    "Donuts Content Explorer",
    "dotMailer content retrieval",
    "dotSemantic",
    "downforeveryoneorjustme",
    "download express",
    "Download Wonder",
    "downloadexpress",
    "downnotifier",
    "DowntimeDetector",
    "dr.web",
    "Dr.Web",
    "dreamhost",
    "dreampassport",
    "Drip",
    "drupact",
    "Drupal \(\+http:\/\/drupal\.org\/\)",
    "drweb",
    "dtaagent",
    "DTS Agent",
    "dubaiindex",
    "duckduckbot",
    "DuplexWeb-Google",
    "dwcp",
    "e-collector",
    "EARTHCOM",
    "Easy-Thumb",
    "EasyDL",
    "EBAY",
    "ebay",
    "ebiness",
    "ebingbong",
    "Ebingbong",
    "ebot",
    "ec2linkfinder",
    "eCairn-Grabber",
    "eCatch",
    "ECCP",
    "echo blinde kuh",
    "eContext\/",
    "Ecxi",
    "EirGrabber",
    "ejupiter",
    "ElectricMonk",
    "elefent",
    "emacs-w3 search engine",
    "emacs-w3searchengine",
    "EMail Exractor",
    "EMail Wolf",
    "EmailWolf",
    "Embarcadero",
    "Embed PHP Library",
    "Embedly",
    "endo\/",
    "esther",
    "europarchive\.org",
    "evc-batch",
    "EventMachine HttpClient",
    "Everwall Link Expander",
    "Evidon",
    "evliya celebi",
    "evliyacelebi",
    "Evrinid",
    "Exabot",
    "exabot",
    "ExactSearch",
    "ExaleadCloudview",
    "Excel\/",
    "exif",
    "Exploratodo",
    "Express WebPictures",
    "externalhit",
    "Extreme Picture Finder",
    "EyeNetIE",
    "ezooms",
    "Ezooms",
    "ezresult",
    "facebook",
    "facebookexternalhit",
    "facebookexternalua",
    "facebookplatform",
    "facebot",
    "fairshare",
    "falcon",
    "fangcrawl",
    "Faraday v",
    "fasthttp",
    "Faveeo",
    "Favicon downloader",
    "favicon",
    "faviconarchive",
    "faviconkit",
    "FavOrg",
    "Feed Wrangler",
    "Feedable\/",
    "Feedbin",
    "FeedBooster",
    "FeedBucket",
    "FeedBunch\/",
    "FeedBurner",
    "feeder",
    "feedfetcher",
    "Feedfetcher",
    "Feedfetcher-Google",
    "Feedly",
    "FeedshowOnline",
    "Feedspot",
    "Feedwind\/",
    "FeedZcollector",
    "feeltiptop",
    "felix ide",
    "felixide",
    "ferret",
    "Fetch API",
    "fetchrover",
    "Fetch\/[0-9]",
    "Fever\/[0-9]",
    "FHscan",
    "fido",
    "Fimap",
    "findlink",
    "findlinks",
    "findthatfile",
    "fireball",
    "firebird",
    "fish search",
    "fishsearch",
    "FlashGet",
    "FlipboardBrowserProxy",
    "FlipboardProxy",
    "FlipboardRSS",
    "Flock\/",
    "fluffy",
    "Flunky",
    "flynxapp",
    "FM Scene",
    "forensiq",
    "forticlient",
    "forticlient.com",
    "fortiguard",
    "fortiguard.com",
    "Fortinet",
    "fouineur",
    "FoundSeoTool",
    "free thumbnails",
    "FreeBSD",
    "Freeuploader",
    "Funnelback",
    "funnelweb",
    "G-i-g-a-b-o-t",
    "g00g1e\.net",
    "ganarvisitas",
    "gazz",
    "gcreep",
    "geek-tools",
    "genieknows",
    "Genieo",
    "GentleSource",
    "GetCode",
    "Getintent",
    "GetLinkInfo",
    "getprismatic",
    "GetRight",
    "getroot",
    "getterroboplus",
    "geturl",
    "GetURLInfo\/",
    "GetWeb",
    "Geziyor",
    "Ghost Inspector",
    "GigablastOpenSource",
    "GIS-LABS",
    "github",
    "github-camo",
    "github\.com",
    "glx",
    "Go http package",
    "Go [\d\.]* package http",
    "Go!Zilla",
    "Go-Ahead-Got-It",
    "go-http-client",
    "Go-http-client",
    "go-http-client/1.1",
    "gobyus",
    "gofetch",
    "goforit",
    "golem",
    "GomezAgent",
    "gooblog",
    "Goodzer\/",
    "Google AppsViewer",
    "Google Desktop",
    "Google favicon",
    "Google Keyword Suggestion",
    "Google Keyword Tool",
    "Google Page Speed Insights",
    "Google PP Default",
    "Google Search Console",
    "Google Web Preview",
    "Google",
    "google",
    "Google-Adwords",
    "Google-Apps-Script",
    "Google-Calendar-Importer",
    "Google-HotelAdsVerifier",
    "Google-HTTP-Java-Client",
    "Google-Publisher-Plugin",
    "Google-Read-Aloud",
    "Google-SearchByImage",
    "Google-Site-Verification",
    "Google-Structured-Data-Testing-Tool",
    "Google-Transparency-Report",
    "google-xrawler",
    "Google-Youtube-Links",
    "Googlebot",
    "googlebot",
    "GoogleDocs",
    "GoogleHC\/",
    "GoogleProducer",
    "GoogleSites",
    "googletranslate",
    "Gookey",
    "GoScraper",
    "GoSpotCheck",
    "gosquared-thumbnailer",
    "Gotit",
    "GoZilla",
    "grabber",
    "grabify",
    "GrabNet",
    "Grafula",
    "gralon",
    "Grammarly",
    "GrapeFX",
    "GrapeshotCrawler",
    "grapnel",
    "GreatNews",
    "Gregarius",
    "GRequests",
    "griffon",
    "grokkit",
    "grokkit-crawler",
    "gromit",
    "grouphigh",
    "grub",
    "grub-client",
    "gsa-crawler",
    "gSOAP\/",
    "GT::WWW",
    "GTmetrix",
    "gulliver",
    "GuzzleHttp",
    "gvfs\/",
    "HAA(A)?RTLAND http client",
    "Haansoft",
    "hackney\/",
    "Hadi Agent",
    "hamahakki",
    "HappyApps-WebCheck",
    "harvest",
    "Hatena",
    "Havij",
    "havindex",
    "HaxerMen",
    "hbot",
    "headless",
    "HeadlessChrome",
    "HEADMasterSEO",
    "HeartRails_Capture",
    "helix",
    "help@dataminr\.com",
    "heritrix",
    "historious",
    "hkedcity",
    "hku www octopus",
    "hkuwwwoctopus",
    "hledejLevne\.cz",
    "Hloader",
    "HMView",
    "Holmes",
    "homerweb",
    "HonesoSearchEngine",
    "HootSuite Image proxy",
    "Hootsuite-WebFeed",
    "hosterstats",
    "hostinger",
    "HostTracker",
    "hotmail!",
    "hotmail",
    "ht:\/\/check",
    "htdig",
    "html index",
    "htmlgobble",
    "htmlindex",
    "HTMLparser",
    "htmlyse",
    "html_analyzer",
    "HTTP Banner AGENT",
    "Http Crawler",
    "http-get",
    "HTTP-Header-Abfrage",
    "http-kit",
    "http-request\/",
    "HTTP-Tiny",
    "HTTP::Lite",
    "http:\/\/www.neomo.de\/",
    "HttpComponents",
    "httphr",
    "HTTPie",
    "HTTPMon",
    "httpRequest",
    "httpscheck",
    "httpssites_power",
    "httpunit",
    "HttpUrlConnection",
    "http\.rb\/",
    "HTTP_Compression_Test",
    "http_get",
    "http_request2",
    "http_requester",
    "httrack",
    "huaweisymantec",
    "hubater",
    "HubSpot ",
    "Humanlinks",
    "hyper-decontextualizer",
    "i2kconnect\/",
    "ia_archiver",
    "Iblog",
    "ibm_planetwide",
    "ichiro",
    "iconsurf",
    "icoreservice",
    "Id-search",
    "IdeelaborPlagiaat",
    "IDG Twitter Links Resolver",
    "IDwhois\/",
    "Iframely",
    "igdeSpyder",
    "iltrovatore",
    "IlTrovatore",
    "Image Fetch",
    "Image Sucker",
    "image.kapsi.net",
    "ImageEngine\/",
    "imagelock",
    "ImageVisu\/",
    "Imagga",
    "imagineeasy",
    "imgsizer",
    "InAGist",
    "inbound\.li parser",
    "incywincy",
    "InDesign%20CC",
    "indexer",
    "Indy Library",
    "InetURL",
    "infegy",
    "infobee",
    "infohelfer",
    "informant",
    "InfoTekies",
    "InfoWizards Reciprocal Link",
    "ingrid",
    "inktomisearch.com",
    "inpwrd\.com",
    "insights",
    "inspector web",
    "inspectorweb",
    "instabid",
    "instagram",
    "Instapaper",
    "Integrity",
    "integromedb",
    "intelliagent",
    "Intelliseek",
    "InterGET",
    "Internet Ninja",
    "internet shinchakubin",
    "InternetSeer",
    "internetshinchakubin",
    "internetVista monitor",
    "internetwache",
    "internet_archive",
    "intraVnews",
    "IODC",
    "IOI",
    "ip3000",
    "iplabel",
    "ips-agent",
    "IPS\/[0-9]",
    "IPWorks HTTP\/S Component",
    "iqdb\/",
    "Iria",
    "Irokez",
    "iron33",
    "isitup\.org",
    "iskanie",
    "israeli-search",
    "isUp\.li",
    "iThemes Sync\/",
    "ivia",
    "IZaBEE",
    "iZSearch",
    "jabber",
    "jack",
    "JAHHO",
    "jakarta",
    "janforman",
    "Jaunt\/",
    "java",
    "javabee",
    "Jbrofuzz",
    "Jersey\/",
    "jetbot",
    "jetbrains",
    "JetCar",
    "Jigsaw",
    "Jobboerse Crawler ",
    "Jobboerse",
    "JobFeed discovery",
    "Jobg8 URL Monitor",
    "jobo",
    "Jobrapido",
    "Jobsearch1\.5",
    "JoinVision Generic",
    "JolokiaPwn",
    "Joomla",
    "Jorgee",
    "JS-Kit",
    "jumpstation",
    "JustView",
    "Kaspersky Lab CFR link resolver",
    "kaspersky",
    "katipo",
    "kbot",
    "kdd-explorer",
    "Kelny\/",
    "Kerrigan\/",
    "KeyCDN",
    "Keyword Density",
    "Keywords Research",
    "khttp\/",
    "KickFire",
    "kilroy",
    "KimonoLabs\/",
    "Kml-Google",
    "knowledge",
    "knows\.is",
    "KOCMOHABT",
    "kototoi",
    "kouio",
    "Kraken",
    "kretrieve",
    "kube-probe",
    "kubectl",
    "kulturarw3",
    "KumKie",
    "labelgrabber",
    "lachesis",
    "larbin",
    "Larbin",
    "Lavf\/",
    "lbot",
    "LeechFTP",
    "LeechGet",
    "legs",
    "letsencrypt",
    "Lftp",
    "LibVLC",
    "LibWeb",
    "Libwhisker",
    "libwww",
    "Licorne",
    "Liferea\/",
    "Lighthouse",
    "lighthouse",
    "Lightspeedsystems",
    "Likse",
    "Link Valet",
    "link validator",
    "linkalarm",
    "LinkAlarm\/",
    "linkCheck",
    "linkdex",
    "linkdexbot",
    "LinkExaminer",
    "linkfluence",
    "linkpeek",
    "LinkPreviewGenerator",
    "linkscan",
    "LinkScan",
    "LinksManager",
    "LinkTiger",
    "linkvalidator",
    "LinkWalker",
    "link_thumbnailer",
    "Lipperhey",
    "Litemage_walker",
    "livedoor ScreenShot",
    "LoadImpactRload",
    "localsearch-web",
    "lockon",
    "LongURL API",
    "looid\.com",
    "looksystems\.net",
    "lssrocketcrawler",
    "ltx71",
    "lua-resty-http",
    "lwp",
    "lwp-request",
    "lwp-trivial",
    "LWP::Simple",
    "lycos",
    "LYT\.SR",
    "L\.webis",
    "mabontland",
    "Macintosh",
    "Mag-Net",
    "magpie",
    "magpie-crawler",
    "MagpieRSS",
    "MailChimp",
    "Mail\.Ru",
    "Majestic12",
    "majestic12",
    "makecontact\/",
    "Mandrill",
    "mantraagent",
    "mapoftheinternet",
    "MapperCmd",
    "marketinggrader",
    "MarkMonitor",
    "MarkWatch",
    "marvin/",
    "Mass Downloader",
    "masscan\/",
    "Mata Hari",
    "mattie",
    "MaxPointCrawler",
    "mbot",
    "mediafox",
    "Mediametric",
    "mediapartners",
    "Mediapartners-Google",
    "mediawords",
    "MegaIndex\.ru",
    "MeltwaterNews",
    "Melvil Rawi",
    "MemGator",
    "mercator",
    "merlinkbot",
    "merzscope",
    "messagelabs",
    "Metaspinner",
    "MetaURI",
    "metauri.com",
    "MFC_Tear_Sample",
    "Microsearch",
    "Microsoft Data Access",
    "Microsoft Office ",
    "Microsoft Outlook",
    "microsoft url control",
    "Microsoft Windows Network Diagnostics",
    "Microsoft-WebDAV-MiniRedir",
    "microsofturlcontrol",
    "MIDown tool",
    "MIIxpc",
    "Mindjet",
    "Miniature\.io",
    "Miniflux",
    "minirank",
    "Mister PiX",
    "miva",
    "mixdata dot com",
    "mixed-content-scan",
    "Mixmax-LinkPreview",
    "mixnode",
    "mj12",
    "MJ12bot",
    "mnogosearch",
    "Mnogosearch",
    "moget",
    "mogimogi",
    "Mojeek",
    "Mojolicious \(Perl\)",
    "mon.itor.us",
    "monitis",
    "Monitority\/",
    "Monit\/",
    "monster",
    "montastic",
    "MonTools",
    "moose",
    "Moreover",
    "Morfeus Fucking Scanner",
    "Morning Paper",
    "motor",
    "MovableType",
    "mowser",
    "mozilla",
    "Mrcgiguy",
    "MS Web Services Client Protocol",
    "MSFrontPage",
    "mShots",
    "msn!",
    "msn",
    "MSNBot",
    "msnbot",
    "msnbot-media",
    "MuckRack\/",
    "muhstik-scan",
    "multitext",
    "muncher",
    "muscatferret",
    "MVAClient",
    "mwd.search",
    "MxToolbox\/",
    "myweb",
    "nagios",
    "najdi",
    "Najdi\.si",
    "Name Intelligence",
    "nameprotect",
    "Nameprotect",
    "nationaldirectory",
    "Navroad",
    "nazilla",
    "nbot",
    "ncsa beta",
    "ncsabeta",
    "NearSite",
    "nec-meshexplorer",
    "nederland.zoek",
    "Needle",
    "neofonie",
    "Nessus",
    "Net Vampire",
    "NetAnts",
    "netcarta webmap engine",
    "netcartawebmapengine",
    "Netcraft Survey Agent",
    "NETCRAFT",
    "netcraft",
    "NetcraftSurveyAgent",
    "NetLyzer",
    "netmechanic",
    "NetMechanic",
    "NetNewsWire",
    "netpilot",
    "Netpursual",
    "netresearch",
    "netresearchserver",
    "netscoop",
    "NetSeer crawler",
    "NetSeercrawler",
    "NetShelter ContentScan",
    "netsparker",
    "Netsparker",
    "NetSystemsResearch",
    "NetTrack",
    "Netvibes",
    "NetZIP",
    "Neustar WPM",
    "NeutrinoAPI",
    "NewRelicPinger",
    "NewsBlur .*Finder",
    "newscan-online",
    "NewsGator",
    "newsme",
    "newspaper\/",
    "Nexgate Ruby Client",
    "NG-Search",
    "nhse",
    "Nibbler",
    "NICErsPRO",
    "Nikto",
    "nineconnections",
    "NING",
    "NLNZ_IAHarvester",
    "Nmap Scripting Engine",
    "node",
    "node-superagent",
    "node-urllib",
    "Nodemeter",
    "NodePing",
    "node\.io",
    "nokia6682/",
    "nomad",
    "nominet\.org\.uk",
    "nominet\.uk",
    "Norton-Safeweb",
    "Notifixious",
    "notifyninja",
    "NotionEmbedder",
    "noyona",
    "nuhk",
    "nutch",
    "Nuzzel",
    "nWormFeedFinder",
    "nyawc\/",
    "Nymesis",
    "NYU",
    "nzexplorer",
    "objectssearch",
    "obot",
    "occam",
    "Ocelli\/",
    "Octopus",
    "oegp",
    "Offline Explorer",
    "Offline Navigator",
    "og-scraper",
    "OgScrper",
    "okhttp",
    "okhttp/2.5.0",
    "omgili",
    "omni",
    "OMSC",
    "Online Domain Tools",
    "open text",
    "OpenCalaisSemanticProxy",
    "Openfind",
    "openfind",
    "openintelligencedata",
    "OpenLinkProfiler",
    "Openstat\/",
    "opentext",
    "OpenVAS",
    "OPPO A33",
    "Optimizer",
    "orb search",
    "Orbiter",
    "orbsearch",
    "OrgProbe\/",
    "orion-semantics",
    "osis-project",
    "outlook!",
    "outlook",
    "Outlook-Express",
    "Outlook-iOS",
    "Owler",
    "ownCloud News",
    "ow\.ly",
    "OxfordCloudService",
    "p3pwgdsn",
    "pack rat",
    "packrat",
    "page scorer",
    "Page Valet",
    "page2rss",
    "pageboy",
    "pagebull",
    "PageGrabber",
    "PagePeeker",
    "PageScorer",
    "Pagespeed\/",
    "page_verifier",
    "Panopta",
    "panscient",
    "Papa Foto",
    "PaperLiBot",
    "parasite",
    "parsijoo",
    "partnersite",
    "patric",
    "Pavuk",
    "PayPal IPN",
    "paypal",
    "pbot",
    "pcBrowser",
    "Pcore-HTTP",
    "pear.",
    "Pearltrees",
    "PECL::HTTP",
    "peerindex",
    "Peew",
    "pegasus",
    "PeoplePal",
    "PercolateCrawler",
    "peregrinator",
    "Perlu -",
    "pgp key agent",
    "pgpkeyagent",
    "phantom",
    "PhantomJS Screenshoter",
    "PhantomJS",
    "phantomjs",
    "PhantomJS\/",
    "phish",
    "phishtank",
    "Photon\/",
    "phpdig",
    "phpservermon",
    "Pi-Monster",
    "picosearch",
    "Picscout",
    "picsearch",
    "Picsearch",
    "PictureFinder",
    "piltdownman",
    "Pimonster",
    "pimptrain",
    "Pingability",
    "PingAdmin\.Ru",
    "Pingdom",
    "Pingoscope",
    "PingSpot",
    "ping\.blo\.gs",
    "pinpoint",
    "pinterest\.com",
    "pioneer",
    "pipes",
    "piranha",
    "Pixray",
    "Pizilla",
    "Plagger\/",
    "Ploetz \+ Zeller",
    "Plukkie",
    "plumanalytics",
    "plumtreewebaccessor",
    "PocketImageCache",
    "PocketParser",
    "Pockey",
    "POE-Component-Client-HTTP",
    "pogodak",
    "poirot",
    "Polymail\/",
    "Pompos",
    "pompos",
    "poppelsdorf",
    "poppi",
    "popular iconoclast",
    "populariconoclast",
    "Porkbun",
    "Port Monitor",
    "postano",
    "PostmanRuntime",
    "PostPost",
    "postrank",
    "PowerPoint\/",
    "presto",
    "preview",
    "Prevx",
    "Priceonomics Analysis Engine",
    "PrintFriendly",
    "PrintfulBot",
    "PritTorrent",
    "privoxy",
    "Prlog",
    "probethenet",
    "Project 25499",
    "prospectb2b",
    "Protopage",
    "ProWebWalker",
    "proximic",
    "proxy",
    "PRTG Network Monitor",
    "pshtt, https scanning",
    "psycheclone",
    "PTST ",
    "PTST\/[0-9]+",
    "publisher",
    "PulseCrawler",
    "Pulsepoint XT3 web scraper",
    "Pump",
    "pycurl",
    "python",
    "Python-httplib2",
    "python-requests",
    "Python-urllib",
    "Qirina Hurdler",
    "QQDownload",
    "QrafterPro",
    "Qseero",
    "Qualidator",
    "QueryN Metasearch",
    "QuerySeekerSpider",
    "queuedriver",
    "quicklook",
    "Quora Link Preview",
    "Qwantify",
    "R6_CommentReader",
    "R6_FeedFetcher",
    "Radian6",
    "rambler",
    "Rambler",
    "RankActive",
    "RankFlex",
    "RankSonicSiteAuditor",
    "raven search",
    "ravensearch",
    "rbot",
    "Re-re Studio",
    "ReactorNetty",
    "Readability",
    "RealDownload",
    "RealPlayer%20Downloader",
    "RebelMouse",
    "Recorder",
    "RecurPost\/",
    "redback\/",
    "ReederForMac",
    "Reeder\/",
    "ReGet",
    "RepoMonkey",
    "request\.js",
    "reqwest\/",
    "ResponseCodeTest",
    "RestSharp",
    "reverseshorturl",
    "Riddler",
    "Rival IQ",
    "roach",
    "road runner",
    "roadhouse",
    "roadrunner",
    "robbie",
    "robofox",
    "Robosourcer",
    "Robozilla",
    "robozilla",
    "ROI Hunter",
    "RPT-HTTPClient",
    "RSSOwl",
    "ruby",
    "rules",
    "safe-agent-scanner",
    "safebrowsing",
    "safesurfingwidget",
    "SalesIntelligent",
    "Saleslift",
    "salty",
    "samsung-sgh-e250",
    "SAMSUNG-SGH-E250",
    "SauceNAO",
    "sbider",
    "SBIder",
    "sbot",
    "scalaj-http",
    "ScanAlert",
    "scanurl",
    "scan\.lol",
    "scmguard",
    "Scoop",
    "scooter",
    "ScoutJet",
    "scoutjet",
    "ScoutURLMonitor",
    "ScrapeBox Page Scanner",
    "Scrapy",
    "Screaming",
    "ScreenShotService",
    "scrubby",
    "Scrubby",
    "Scrutiny\/",
    "seamonkey",
    "search.",
    "Search37",
    "searchenginepromotionhelp",
    "Searchestate",
    "SearchExpress",
    "SearchmetricsBot",
    "searchprocess",
    "SearchSight",
    "search\.thunderstone",
    "seek",
    "Seeker",
    "semanticdiscovery",
    "semanticjuice",
    "Semiocast HTTP client",
    "Semrush",
    "Sendsay\.Ru",
    "senrigan",
    "sentry\/",
    "SEO Browser",
    "Seo Servis",
    "seo-nastroj\.cz",
    "seo4ajax",
    "Seobility",
    "SEOCentro",
    "SeoCheck",
    "SEOkicks",
    "Seomoz",
    "SEOprofiler",
    "seoscanners",
    "SEOsearch",
    "seositecheckup",
    "SEOstats",
    "servernfo",
    "sexsearcher",
    "Seznam",
    "sg-scout",
    "shaihulud",
    "shark",
    "Shelob",
    "Shodan",
    "Shoppimon",
    "ShopWiki",
    "shopwiki",
    "ShortLinkTranslate",
    "ShowyouBot",
    "shrinktheweb",
    "Sideqik",
    "sidewinder",
    "sift",
    "SiftScience",
    "silk",
    "simmany",
    "simplepie",
    "SimplePie",
    "SimpleScraper",
    "SimplyFast",
    "Siphon",
    "SISTRIX Crawler",
    "SISTRIX",
    "SISTRIXCrawler",
    "site searcher",
    "Site Sucker",
    "site valet",
    "Site-Shot\/",
    "Site24x7",
    "SiteBar",
    "Sitebeam",
    "Sitebulb\/",
    "SiteCondor",
    "SiteExplorer",
    "siteexplorer",
    "SiteGuardian",
    "Siteimprove",
    "SiteIndexed",
    "SiteLockSpider",
    "Sitemap(s)? Generator",
    "SitemapGenerator",
    "SiteMonitor",
    "sitesearcher",
    "Siteshooter B0t",
    "SiteSnagger",
    "SiteSucker",
    "sitetech-rover",
    "SiteTruth",
    "sitevalet",
    "Sitevigil",
    "sitexy\.com",
    "skymob.com",
    "SkypeUriPreview",
    "Slack\/",
    "sleek",
    "slider\.com",
    "Slurp",
    "slurp",
    "SlySearch",
    "SmartDownload",
    "smartwit",
    "SMRF URL Expander",
    "SMUrlExpander",
    "SMXCrawler",
    "sna-",
    "Snake",
    "snappy",
    "Snappy",
    "SnapSearch",
    "Snarfer\/",
    "SniffRSS",
    "sniptracker",
    "snooper",
    "Snoopy",
    "SnowHaze Search",
    "softlayer",
    "Sogou web spider",
    "sogou web",
    "sogou",
    "sogou-test-spider",
    "Sogouwebspider",
    "sohu",
    "sophos",
    "SortSite",
    "Sottopop",
    "sovereign\.ai",
    "SpaceBison",
    "spam",
    "SpamExperts",
    "Spammen",
    "Spanner",
    "spaziodati",
    "spbot",
    "SPDYCheck",
    "Specificfeeds",
    "speedfind",
    "speedy",
    "SPEng",
    "sphere",
    "sphider",
    "spider",
    "Spinn3r",
    "spinner",
    "spray-can",
    "Sprinklr ",
    "spyder",
    "spyonweb",
    "sqlmap",
    "Sqlworm",
    "Sqworm",
    "SSL Labs",
    "ssl-tools",
    "StackRambler",
    "Statastico\/",
    "StatusCake",
    "Steeler",
    "steeler/",
    "Stratagems Kumo",
    "Stroke\.cz",
    "StudioFACA",
    "StumbleUpon",
    "suchen",
    "Sucuri",
    "sucuri.net",
    "suke",
    "summify",
    "suntek",
    "SuperHTTP",
    "supersnooper",
    "surfnomore",
    "Surphace Scout",
    "Suzuran",
    "sven",
    "SwiteScraper",
    "sygol",
    "sylera",
    "Symfony BrowserKit",
    "Symfony2 BrowserKit",
    "SynHttpClient-Built",
    "Sysomos",
    "sysscan",
    "Szukacz",
    "szukacz",
    "t-h-u-n-d-e-r-s-t-o-n-e",
    "t-rex",
    "T0PHackTeam",
    "tach black widow",
    "tachblackwidow",
    "tAkeOut",
    "tarantula",
    "Tarantula\/",
    "Taringa UGC",
    "TarmotGezgin",
    "tbot",
    "telegram",
    "Teleport",
    "Telesoft",
    "Telesphoreo",
    "Telesphorep",
    "templeton",
    "TencentTraveler",
    "Tenon\.io",
    "teoma",
    "terrainformatica",
    "Test Certificate Info",
    "testuri",
    "Tetrahedron",
    "TextRazor Downloader",
    "The Drop Reaper",
    "The Expert HTML Source Viewer",
    "The Intraformant",
    "The Knowledge AI",
    "theinternetrules",
    "TheNomad",
    "theophrastus",
    "Thinklab",
    "Thumbor",
    "Thumbshots",
    "ThumbSniper",
    "timewe\.net",
    "TinEye",
    "Tiny Tiny RSS",
    "titan",
    "titin",
    "tkwww",
    "TLSProbe\/",
    "Toata",
    "topster",
    "tor-exit",
    "torservers",
    "touche\.com",
    "toutatis",
    "Traackr\.com",
    "tracemyfile",
    "Trackuity",
    "translate",
    "TrapitAgent",
    "Trendiction",
    "trendmicro",
    "Trendsmap",
    "trendspottr",
    "Trident",
    "trident",
    "truwoGPS",
    "TryJsoup",
    "TulipChain",
    "Turingos",
    "Turnitin",
    "tutorgig",
    "TweetedTimes Bot",
    "tweetedtimes",
    "TweetedTimesBot",
    "TweetmemeBot",
    "Tweetminster",
    "Tweezler\/",
    "twibble",
    "Twice",
    "twiceler",
    "Twikle",
    "Twingly",
    "Twisted PageGetter",
    "twisted",
    "Twitterbot",
    "Typhoeus",
    "ubermetrics-technologies",
    "ubuntu",
    "uclassify",
    "ucsd",
    "udmsearch",
    "UdmSearch",
    "unchaos",
    "unirest-java",
    "UniversalFeedParser",
    "Unshorten\.It",
    "Untiny",
    "untrusted",
    "UnwindFetchor",
    "updated",
    "updown\.io daemon",
    "Upflow",
    "UptimeRobot",
    "Uptimia",
    "url check",
    "URL Verifier",
    "URLAppendBot",
    "urlcheck",
    "Urlcheckr",
    "URLitor",
    "urlredirectresolver",
    "urlresolver",
    "urlscan",
    "Urlstat",
    "URLTester",
    "UrlTrends Ranking Updater",
    "URLy Warning",
    "URLy\.Warning",
    "Vacuum",
    "vagabondo",
    "Vagabondo",
    "valkyrie",
    "VB Project",
    "vbot",
    "vBSEO",
    "VCI",
    "verticrawl",
    "via ggpht\.com GoogleImageProxy",
    "victoria",
    "VidibleScraper",
    "virus",
    "Virusdie",
    "virustotal",
    "vision-search",
    "visionutils",
    "vkShare",
    "VoidEYE",
    "Voil",
    "VoilaBot",
    "volcano",
    "voltron",
    "voyager-hc",
    "voyager/",
    "voyager\/",
    "VSAgent\/",
    "VSB-TUO\/",
    "Vulnbusters Meter",
    "VYU2",
    "w3af\.org",
    "W3C-checklink",
    "W3C-mobileOK",
    "W3C_Unicorn",
    "w3c_validator",
    "w3m2",
    "w3mir",
    "WAC-OFU",
    "walker",
    "wallpaper",
    "WallpapersHD",
    "Wallpapers\/[0-9]+",
    "wanderer",
    "wangling",
    "Wappalyzer",
    "wapproxy",
    "WatchMouse",
    "wauuu",
    "wavefire",
    "WbSrch\/",
    "WDT\.io",
    "Web Auto",
    "Web Collage",
    "web core",
    "Web Enhancer",
    "Web Fetch",
    "Web Fuck",
    "web hopper",
    "Web Pix",
    "Web Sauger",
    "Web spyder",
    "Web Sucker",
    "web wombat",
    "web-capture\.net",
    "Web-sniffer",
    "Webalta",
    "Webauskunft",
    "WebAuto",
    "webbandit",
    "WebCapture",
    "webcatcher",
    "WebClient\/",
    "webcollage",
    "WebCookies",
    "WebCopier",
    "webcopy",
    "webcore",
    "WebCorp",
    "WebDataStats",
    "WebDoc",
    "WebEnhancer",
    "WebFetch",
    "webfoot",
    "WebFuck",
    "WebGazer",
    "WebGo IS",
    "webhopper",
    "WebImageCollector",
    "WebImages",
    "WebIndex",
    "webkit2png",
    "weblayers",
    "WebLeacher",
    "weblight",
    "weblinker",
    "weblog monitor",
    "weblogmonitor",
    "webmastercoffee",
    "webmirror",
    "webmon ",
    "webmonkey",
    "WebPix",
    "webquest",
    "webreaper",
    "WebReaper",
    "WebSauger",
    "webscreenie",
    "Webshag",
    "Webshot",
    "Website Quester",
    "websitepulse agent",
    "websitepulse",
    "WebsiteQuester",
    "Websnapr",
    "websnarf",
    "WebSniffer",
    "Webster",
    "webstolperer",
    "WebStripper",
    "WebSucker",
    "WebThumbnail",
    "Webthumb\/",
    "webvac",
    "webwalk",
    "webwatch",
    "WebWhacker",
    "webwombat",
    "webzinger",
    "WebZIP",
    "WeLikeLinks",
    "WEPA",
    "WeSEE",
    "wf84",
    "Wfuzz\/",
    "wget",
    "whatsapp",
    "WhatsApp",
    "WhatsMyIP",
    "WhatWeb",
    "WhereGoes\?",
    "Whibse",
    "whizbang",
    "WhoRunsCoinHive",
    "whowhere",
    "Whynder Magnet",
    "wild ferret",
    "wildferret",
    "windows 95",
    "windows 98",
    "Windows XP",
    "windows xp",
    "Windows-RSS-Platform",
    "WindowsPowerShell",
    "WinPodder",
    "wkhtmlto",
    "wmtips",
    "Woko",
    "woorankreview",
    "WordPress\/",
    "WordupinfoSearch",
    "Word\/",
    "woriobot",
    "worldlight",
    "worldping-api",
    "wotbox",
    "WP Engine Install Performance API",
    "wpif",
    "wprecon\.com survey",
    "WPScan",
    "wscheck",
    "Wtrace",
    "WWW-Collector-E",
    "WWW-Mechanize",
    "WWW::Document",
    "WWW::Mechanize",
    "wwwc",
    "WWWOFFLE",
    "wwwster",
    "www\.monitor\.us",
    "x09Mozilla",
    "X11",
    "x22Mozilla",
    "XaxisSemanticsClassifier",
    "Xenu Link Sleuth",
    "xenu",
    "xget",
    "xift",
    "XING-contenttabreceiver",
    "xirq",
    "xpymep([0-9]?)\.exe",
    "Y!J-(ASR|BSC)",
    "Y!J-BRW",
    "Yaanb",
    "yacy",
    "Yahoo Link Preview",
    "Yahoo! Slurp",
    "yahoo!",
    "Yahoo!Slurp",
    "yahoo",
    "YahooCacheSystem",
    "YahooSeeker",
    "yahooSeeker",
    "YahooYSMcm",
    "YandeG",
    "yandex",
    "Yandex",
    "Yandex(?!Search)",
    "yandexbot",
    "yandexBot",
    "YandexBot",
    "yanga",
    "ybot",
    "yeti",
    "Yo-yo",
    "yodao",
    "Yoleo Consumer",
    "yoogliFetchAgent",
    "YottaaMonitor",
    "YoudaoBot",
    "Your-Website-Sucks",
    "yourls\.org",
    "YoYs\.net",
    "YP\.PL",
    "Y\!J-BRW",
    "Zabbix",
    "Zade",
    "Zao",
    "zao/",
    "Zauba",
    "zbot",
    "Zemanta Aggregator",
    "Zend\\Http\\Client",
    "Zend_Http_Client",
    "Zermelo",
    "Zeus ",
    "zgrab",
    "zipcommander",
    "zippp",
    "ZnajdzFoto",
    "ZnHTTP",
    "zteopen",
    "zyborg",
    "^Amazon Simple Notification Service Agent$",
    "^COMODO DCV",
    "^DangDang",
    "^DavClnt",
    "^FDM ",
    "^git\/",
    "^Goose\/",
    "^Grabber",
    "^HTTPClient\/",
    "^Java\/",
    "^Jeode\/",
    "^Jetty\/",
    "^Mail\/",
    "^Mget",
    "^Microsoft URL Control",
    "^NG\/[0-9\.]",
    "^NING\/",
    "^PHP\/[0-9]",
    "^RMA\/",
    "^Ruby|Ruby\/[0-9]",
    "^VSE\/[0-9]",
    "^WordPress\.com",
    "^XRL\/[0-9]",
    "^ZmEu",
    "_bot", '007ac9', '7siters', '013 netvision', '50.nu', '192agent', 'a6-indexer', 'a100 row', 'abacho', 'abonti', 'above', 'accoona', 'acoi', 'acoon', 'acunetix', 'adaxas', 'addthis', 'admantx', 'adressendeutschland', 'agada', 'ah-ha', 'ahc/2.1', 'ahoy', 'aiohttp', 'akamai', 'aladin', 'alexa site audit', 'alkaline', 'altavista', 'amagit', 'amazon', 'americanexpress', 'amuri', 'amzn_assoc', 'analytics', 'ananzi', 'annotate', 'anonymizer', 'anthill', 'anzwers', 'aol', 'apache-httpclient', 'apachebench', 'apercite', 'apexis', 'aplix', 'aportworm', 'app.hypefactors', 'appie', 'apple inc', 'arachni', 'arachnophilia', 'arale', 'araneo', 'aranha', 'architext', 'aretha', 'arks', 'aruba', 'as9105', 'ask24', 'ask jeeves', 'askaboutoil', 'asked', 'aspseek', 'asterias', 'astutesrm', 'atlocal', 'atn', 'atomz', 'augurfind', 'autoshun', 'avant', 'avast', 'avg', 'avira', 'avirasoft', 'awario', 'axios', 'azure', 'b2 net solutions', 'baboom', 'backlink-check.de', 'backrub', 'badware', 'baidu', 'barkrowler', 'barracuda', 'baypup', 'bazqux reader', 'bdfetch', 'big brother', 'bigbrother', 'biglotron', 'bilbo', 'bingpreview', 'bitdefender', 'bitfolk', 'bjaaland', 'blackboard', 'blackwidow', 'blaiz', 'blazing seo', 'blo.', 'blog', 'bloodhound', 'blue coat systems', 'boardreader', 'boardreader blog indexer', 'boitho', 'booch', 'bot', 'bradley', 'brandverity', 'british telecommunications plc', 'browsershots', 'bruuk.sk', 'btcentralplus', 'btwebclient', 'bubing', 'buck', 'buck/2.2', 'bullguard aps', 'butterfly', 'cachednet', 'calif', 'calyxinstitute', 'camehttps', 'cassandra', 'castro 2', 'catchpoint', 'catexplorador', 'ccubee', 'cdn77', 'census', 'censys', 'centralnic', 'cfetch', 'cfnetwork', 'charlotte', 'chelyabinsk-signal llc', 'chinanet fujian province network', 'choopa', 'churl', 'cienciaficcion', 'cisco', 'cl0na', 'clamav', 'claro dominican republic', 'clicktargetdevelopment', 'clientid', 'cloud', 'cmc', 'cmu', 'collectd', 'collective', 'colocrossing', 'coloup', 'comagent', 'combine', 'commafeed', 'comodo', 'compatible', 'complete internet access', 'computer problem solving', 'computingsite', 'comrise.ru', 'contaboserver', 'content delivery network ltd', 'cpanel', 'crawl', 'crime', 'crossdomain', 'cs.daum', 'csci', 'cubenode system sl', 'curl', 'cusco', 'customer network', 'cyberinfo', 'cymru', 'cyveillance', 'dalvik', 'daniel james austin', 'datacamp', 'datadog agent', 'dataline ltd', 'datanyze', 'datapacket', 'dataprovider', 'daum', 'daumoa', 'dedfiberco', 'deepindex', 'del.icio.us', 'delete', 'delorie', 'depspid', 'deweb', 'die blinde kuh', 'dieblindekuh', 'digger', 'digital domain', 'digital energy technologies limited', 'digital ocean', 'digitalcourage.de', 'digitalocean', 'digiweb ltd', 'dir a/s', 'ditto', 'dlvr.it', 'dmoz', 'docomo', 'domainappender', 'domainsproject', 'dosarrest', 'download express', 'downloadexpress', 'downnotifier', 'dr.web', 'dreampassport', 'drweb', 'dtaagent', 'duckduck', 'dwcp', 'dyn.plus.net', 'e-active.nl', 'e-collector', 'ebay', 'ebbs.healingpathsolutions', 'ebiness', 'ebingbong', 'ecairn-grabber', 'echo blinde kuh', 'eir broadband', 'eircom customer assignment', 'ejupiter', 'email', 'emailwolf', 'embedly', 'emsisoft', 'enom', 'eonix corporation', 'esecuredata', 'eset', 'esther', 'evc-batch', 'evliya celebi', 'evliyacelebi', 'exit-01a.noisetor.net', 'expanse', 'expressvpn', 'externalhit', 'ez publish link validator', 'ezooms', 'ezresult', 'facebook', 'falcon', 'fastly', 'favicon', 'feed wrangler', 'feedbin', 'feedburner', 'feedfetcher', 'feedly', 'feedspot', 'felix ide', 'felixide', 'ferret', 'fetcher6-2.go.mail.ru', 'fetchrover', 'fever', 'fido', 'findlinks', 'fireball', 'firebird', 'fireeye', 'flipboard', 'flokinet', 'fm scene', 'fortiguard', 'fortinet', 'fouineur', 'foundee', 'france telecom s.a.', 'freebsd', 'freshrss', 'funnelweb', 'gandi sas', 'gazz', 'gcreep', 'genieknows', 'genieo', 'geosr', 'getstream.io/winds', 'getterroboplus', 'geturl', 'gigablast', 'gigablastopensource/1.0', 'gigenet', 'github', 'global data networks llc', 'global perfomance', 'glutenfreepleasure', 'glx', 'gmail', 'go-http-clientgodaddy', 'godaddy, llc', 'goforit', 'golem', 'goo', 'google', 'grabber', 'gralon', 'grapeshot', 'grapnel', 'griffon', 'gromit', 'group', 'grouphigh', 'grub', 'gstatic', 'gulliver', 'hamahakki', 'harvest', 'havindex', 'headless', 'healingpathsolutions', 'heg us', 'helix', 'heritrix', 'heureka feed', 'hicoria', 'highwinds network', 'hilfe-veripayed', 'hinet', 'hku www octopus', 'hkuwwwoctopus', 'homerweb', 'host', 'hotmail', 'htdig', 'html index', 'html_analyzer', 'htmlgobble', 'htmlindex', 'http_request2', 'httpmon', 'httrack', 'hubater', 'hubpages', 'hubspot', 'hyper-decontextualizer', 'ia_archiver', 'ibm_planetwide', 'ibwww-perl', 'ichiro', 'iconsurf', 'icoreservice', 'idg/it', 'iis site analysis', 'iltrovatore', 'image.kapsi', 'imagelock', 'imon communications, llc', 'inagist', 'incywincy', 'indexer', 'infobee', 'informant', 'infosphere', 'ingrid', 'inktomi', 'inoreader', 'insights', 'inspector web', 'inspectorweb', 'instagram', 'intelliagent', 'internap network services corporation', 'internet customers', 'internet shinchakubin', 'internet-pro', 'internetdefence', 'internetshinchakubin', 'intersoft internet', 'intrinsec', 'involta', 'ip3000', 'ipredator', 'ips agent', 'ips-agent', 'ipvanish', 'iq pl sp. z o.o.', 'iron33', 'is74.ru', 'itcom shpk', 'ivia', 'jabber', 'jack', 'jakarta', 'java', 'jetbrains', 'jetslide', 'joshua peter mcquistan', 'jsc er-telecom holding', 'jumpstation', 'kaspersky', 'katipo', 'kdd-explorer', 'kilroy', 'knowledge', 'kototoi', 'kouio', 'kraken', 'kretrieve', 'kyivstar', 'labelgrabber', 'lachesis', 'larbin', 'lcc', 'leak', 'legs', "let's encrypt validation", 'level', 'level3', 'level 3', 'lg dacom', 'libwww', 'lifesites', 'lighthouse', 'link validator', 'linkalarm', 'linkdex', 'linkfluence', 'linkgrid llc', 'linkvalidator', 'linode', 'liquid web', 'lixux ou', 'lockon', 'logicweb', 'london wires ltd.', 'london-tor.mooo', 'long thrive', 'ltx71', 'lukman', 'lvlt-static-4-14-16', 'lwp', 'lycos', 'm247 ltd frankfurt infrastructure', 'm-net', 'madgenius', 'magpie', 'magpierss', 'mailshell', 'mainloop', 'majestic12', 'mantraagent', 'mapoftheinternet', 'marvin', 'master internet', 'mattie', 'mcafee', 'mediafox', 'mediapartners', 'megaindex', 'mercator', 'merit network', 'merzscope', 'messagelabs', 'messenger', 'metadataparser', 'metainspector', 'metauri', 'microsoft', 'millersmiles', 'miniature', 'minirank', 'minsktelecom.by', 'miva', 'mj12', 'moget', 'mon.itor.us', 'monitis', 'monitor.us', 'moose', 'moreover', 'mpdedicated', 'msn', 'multitext', 'muncher', 'munin', 'muscatferret', 'myweb', 'mywot', 'myx group llc', 'nagios check_http', 'najdi', 'nameprotect', 'nationaldirectory', 'nazilla', 'nbertaupete95', 'ncsa beta', 'ncsabeta', 'nec-meshexplorer', 'nederland.zoek', 'neofonie', 'net4sec', 'netcarta webmap engine', 'netcartawebmapengine', 'netcraft', 'netestate', 'netflix', 'netlyzer fastprobe', 'netmechanic', 'netnewswire', 'netpilot', 'netprotect srl', 'netscoop', 'netsparker', 'netvibes', 'newmedia express', 'newsblur', 'newsgator', 'newspaper', 'nforce entertainment b.v.', 'nhse', 'nine internet', 'ning', 'nmap', 'nobis ', 'node', 'noisetor', 'nokia6682', 'nomad', 'noyona', 'nutch', 'nuzzel', 'nwstack', 'nzexplorer', 'occam', 'octopus', 'ojsc oao tattelecom', 'okhttp', 'omgili', 'omni', 'onavo mobile ltd', 'onyphe', 'open text', 'opendns', 'openfind', 'openintelligencedata', 'openlinkprofiler', 'opensourcerss', 'opentext', 'oracle', 'orange polska spolka akcyjna', 'orange-labs', 'osis-project', 'outbrain', 'outlook', 'ovh', 'p3pwgdsn', 'pacbell', 'pack rat', 'packrat', 'page_verifier', 'pageboy', 'pagebull', 'pagepeeker', 'paloalto', 'panscient', 'parasite', 'parked.factioninc', 'parrukatu', 'partnersite', 'pathsconnect', 'patric', 'paypal', 'pcore-http', 'peak 10', 'pear.', 'pegasus', 'peregrinator', 'petersburg internet network ltd.', 'pgp key agent', 'pgpkeyagent', 'phantom', 'phish', 'php server monitor', 'php-curl-class', 'phpdig', 'piltdownman', 'pimptrain', 'pingdom', 'pinpoint', 'pinterest', 'pioneer', 'pipes', 'pipex-block1', 'piranha', 'plumtreewebaccessor', 'plusnet', 'plusnet technologies ltd', 'pocketparser', 'pogodak', 'poirot', 'pompos', 'poppelsdorf', 'poppi', 'popular iconoclast', 'populariconoclast', 'prcdn.net', 'prescient software', 'presto', 'preview', 'prevx', 'prittorrent', 'private customer', 'private ip address lan', 'privatesystems networks', 'privoxy', 'probe', 'profound', 'progtech.ru', 'proximic', 'proxy', 'psinet', 'psycheclone', 'psychz', 'public facing services', 'publisher', 'pycurl', 'python', 'qihu', 'quadmetrics', 'quadranet', 'qualitynetwork', 'quasi networks ltd', 'quicklook', 'quintex alliance consulting', 'quora link preview', 'qwantify', 'r6_commentreader', 'r6_feedfetcher', 'rackspace', 'rainmeter', 'rambler', 'ramnode', 'rederatural', 'redpill linpro as', 'redswitches pty', 'reverseshorturl', 'riddler', 'rima-tde', 'roach', 'road runner', 'roadhouse', 'roadrunner', 'roamsite', 'robbie', 'robofox', 'robozilla', 'roi hunter', 'ruby', 'rules', 'safebrowsing', 'safesurfingwidget', 'salty', 's.a.s', 'sbider', 'sc rusnano', 'scalaj-http', 'scaleway', 'scam', 'scan', 'schmorp.de', 'schulte consulting llc', 'scmguard', 'scooter', 'scoutjet', 'scrapy', 'scrubby', 'seamonkey', 'search', 'sectoor', 'securedconnectivity', 'secureinternet', 'secureserver', 'security', 'seek', 'semantic', 'semrush', 'senrigan', 'seokicks', 'server', 'seznam', 'sg-scout', 'shadowserver', "shai'hulud", 'shark', 'shopalike', 'shopify partner', 'shopwiki', 'shore', 'sidewinder', 'sift', 'silk', 'silverreader', 'simmany', 'simplepie', 'simpli networks llc', 'simtccflow1.etn', 'sistrix optimizer', 'site24x7 website monitoring', 'site valet', 'siteadvisor', 'sitecheck', 'siteexplorer', 'siteimprove', 'sitesucker', 'sitetech-rover', 'sitevalet', 'sixy.ch', 'skymob', 'skype uri preview', 'sl-reverse', 'sleek', 'sleuth', 'slurp', 'smartwit', 'sna-',
    'snab-inform private enterprise', 'snapchat', 'snappy', 'snooper', 'softlayer', 'sogou', 'sohu', 'solar vps', 'solution', 'sonicwall', 'sophos', 'spam', 'spark new zealand trading ltd', 'sparkler', 'speedfind', 'speedtravel', 'speedy', 'sphere', 'sphider', 'spider', 'spinn3r', 'spinner', 'spotify', 'spro-net', 'spyder', 'sqlmap', 'ssl labs', 'staircaseirony', 'stanford', 'starnet.md', 'startpagina linkchecker', 'static ip assignment', 'statuscake', 'steeler', 'stelkom', 'stretchoid', 'sucuri', 'suke', 'sungard', 'suntek', 'supersnooper', 'surfcontrol', 'surfnet', 'surfnomore', 'surriel', 'sven', 'sygol', 'sylera', 'symantec', 'synprobe', 'sysms', 'sysomos', 'szukacz', 't-h-u-n-d-e-r-s-t-o-n-e', 't-rex', 'tach black widow', 'tachblackwidow', 'tahoe internet exchange (tahoeix)', 'talktalk', 'tarantula', 'tarmot gezgin', 'team technologies llc', 'techinfo@ubermetrics-technologies', 'tehnologii budushego llc', 'teledata-fttx.de', 'telegram', 'templeton', 'tencenttraveler', 'teoma', 'terratransit', 'terrykyleseoagency', 'tfbnw', 'the calyx institute', 'theknowledgeai', 'theoldreader', 'theophrastus', 'time warner cable internet llc', 'tiny tiny rss', 'tinytinyrss', 'titan', 'titin', 'tkwww', 'tlh.ro', 'tlsprobe', 'tor-exit', 'tor-relays', 'tor.node', 'tor.piratenpartei-nrw.de', 'torservers', 'total server solutions', 'toutatis', 'tpnet.pl', 'traackr', 'tracemyfile', 'translate', 'trendiction', 'trendmicro', 'trendsmapresolver', 'trident', 'triolan', 'trustwave', 'tutorgig', 'twiceler', 'twingly recon', 'twisted', 'twitter', 'ubermetrics', 'ubuntu', 'ucsd', 'udasha', 'uk dedicated servers limited', 'ukrnet', 'unchaos', 'universalfeedparser', 'universidade federal do rio de janeiro', 'university', 'unknown', 'unn', 'untrusted', 'unwindfetchor', 'upc romania bucuresti', 'updated', 'updown_tester', 'url check', 'url.thum.io', 'urlcheck', 'urlredirectresolver', 'urlresolver', 'vagabondo', 'valkyrie', 'ventelo wholesale', 'versanet.de', 'versaweb', 'vertical telecoms', 'victoria', 'virtual1 limited', 'virtual employee pvt ltd', 'virus', 'vist on-line ltd', 'vk share button', 'vnet a.s.', 'volcano', 'voxility', 'voyager', 'vpsmalaysia', 'vultr', 'w3c', 'w3m2', 'w3mir', 'walker', 'wallpaper', 'wanderer', 'wappalyzer', 'wapproxy', 'wauuu', 'wavefire', 'web core', 'web hopper', 'web wombat', 'webbandit', 'webcatcher', 'webcopy', 'webcore', 'webdatastats', 'webfoot', 'webhopper', 'weblayers', 'weblight', 'weblinker', 'weblog monitor', 'weblogmonitor', 'webmirror', 'webmonkey', 'weborama', 'webpagetest', 'webquest', 'webreaper', 'websecurityguard', 'websitepulse', 'websnarf', 'webstolperer', 'webthumbnail', 'webvac', 'webwalk', 'webwatch', 'webwombat', 'webzinger', 'westnet', 'wget', 'whatsapp', 'whitelabel it solutions corp', 'whizbang', 'whowhere', 'wikido', 'wikipedia', 'wild ferret', 'wildferret', 'windows95', 'windows98', 'windows 95', 'windows 98', 'windows xp', 'windowspowershell', 'windscribe', 'wintek corporation', 'woorank', 'wordpress', 'wordpressmshots', 'worldlight', 'wotbox', 'wowrack', 'www.fortinet', 'wwwc', 'wwwroot', 'wwwster', 'x11', 'xenu', 'xget', 'xift', 'xirq', 'xo communications', 'xs4all internet bv', 'y!j-brw', 'yacy', 'yahoo', 'yak/1.0', 'yandex', 'yanga', 'yeti', 'yodao', 'yottaa site monitor', 'yourls', 'zao', 'zayo', 'ze list', 'zenlayer', 'zgrab', 'zipcommander', 'zippp', 'zscaler', 'zteopen', 'zyborg', 'census');

$useragent = ParseUA();
foreach ($botUA as $botsua) {
    if (stripos($useragent, $botsua)) {
        logger($botsua." ==> ".$useragent, "BOT USERAGENT");
        die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
    }
}


$bannedREF = array(
        '000free.us',
		'000webhost.com',
        '007angels.com',
        '00author.com',
        '00go.com',
        '00it.com',
        '00webcams.com',
        '01apple.com',
        '03e.info',
        '03p.info',
        '08800.top',
        '0912701309f8ce.com',
        '0c47f8422d3f.com',
        '0daymusic.org',
        '0lovespells0.blogspot.com',
        '0n-line.tv',
        '1-99seo.com',
        '1-free-share-buttons.com',
        '1000n1.ru',
        '1001watch.com.ua',
        '100dollars-seo.com',
        '100searchengines.com',
        '101billion.com',
        '101flag.ru',
        '101lesbian.xyz',
        '101raccoon.ru',
        '108shot.com',
        '10bet.com',
        '11235813.webzdarma.cz',
        '11pikachu.ru',
        '123any.com',
        '123cha.com',
        '123kuma.com',
        '123locker.com',
        '12bet.com',
        '12masterov.com',
        '12u.info',
        '1314dh.com',
        '13tabs.com',
        '14b.info',
        '1688.com',
        '178evakuator178.ru',
        '1adult.com',
        '1bet.com',
        '1flag.co.za',
        '1hwy.com',
        '1j7740kd.website',
        '1kdailyprofit.me',
        '1kinobig.ru',
        '1millionusd.xyz',
        '1pamm.ru',
        '1qingdao.com',
        '1stat.ru',
        '1webmaster.ml',
        '2000k.ru',
        '2015god.org',
        '2020iscoming.info',
        '202ch.com',
        '20pascals.nl',
        '214jaluwobapef.cf',
        '21h2o.com',
        '2345.com',
        '23kw.ru',
        '24-ak.ru',
        '24videos.tv',
        '24x7-server-support.site',
        '256bit.by',
        '2728fb936f0.com',
        '273-fz.ru',
        '28n2gl3wfyb0.ru',
        '2ads.co.uk',
        '2drittel.de',
        '2girls1cup-free.com',
        '2itech.ru',
        '2kata.ru',
        '2nt.ru',
        '2pxg8bcf.top',
        '2rich4bitches.com',
        '2x2fan.ru',
        '3-letter-domains.net',
        '300richmond.co.nz',
        '34.gs',
        '3dracergames.com',
        '3rbseyes.com',
        '3th.co.in',
        '3w24.com',
        '3weekdiet.com',
        '3xforum.ro',
        '40cg.com',
        '45en.ru',
        '4inn.ru',
        '4istoshop.com',
        '4k-player.pl',
        '4kplayer.pl',
        '4pp13.com',
        '4rent.ru',
        '4replicawatch.net',
        '4ur.click',
        '4ureyesonly.com',
        '4webmasters.com',
        '4webmasters.org',
        '5-steps-to-start-business.com',
        '5000-cotydzien.com',
        '51.la',
        '51unlim.ru',
        '55wmz.ru',
        '57883.net',
        '5elementov.ru',
        '5forex.ru',
        '5i2.net',
        '5kstore.com',
        '5tey7463.weebly.com',
        '5u.com',
        '5ws.dating-app.ru',
        '6128786.com',
        '66cpwgln.space',
        '6hopping.com',
        '72-news.com',
        '76brighton.co.uk',
        '777-club.ru',
        '7a2rnuey1tw9ar.ru',
        '7fon.ru',
        '7makemoneyonline.com',
        '7minuteworkout.com',
        '7search.com',
        '7wind.ru',
        '7xc4n.com',
        '7yue.org',
        '7zap.com',
        '83net.jp',
        '8558l.jobs.net',
        '883zy.com',
        '888.com',
        '8gold.com',
        '8jn.dating-app.ru',
        '8kisses.eu',
        '8lufu.com',
        '8si.ru',
        '8xv8.com',
        '91abcw.com',
        '98oi.ru',
        '991mostfm.co.id',
        '999webdesign.com',
        '9icmzvn6.website',
        '9med.net',
        'a.frcls.fr',
        'a.pr-cy.ru',
        'a14download.com',
        'a1security.com.ua',
        'a96527gi.beget.tech',
        'aa08daf7e13b6345e09e92f771507fa5f4.com',
        'aa14ab57a3339c4064bd9ae6fad7495b5f.com',
        'aa625d84f1587749c1ab011d6f269f7d64.com',
        'aa81bf391151884adfa3dd677e41f94be1.com',
        'aa8780bb28a1de4eb5bff33c28a218a930.com',
        'aa8b68101d388c446389283820863176e7.com',
        'aa9bd78f328a6a41279d0fad0a88df1901.com',
        'aa9d046aab36af4ff182f097f840430d51.com',
        'aaa38852e886ac4af1a3cff9b47cab6272.com',
        'aab94f698f36684c5a852a2ef272e031bb.com',
        'aac500b7a15b2646968f6bd8c6305869d7.com',
        'aac52006ec82a24e08b665f4db2b5013f7.com',
        'aad1f4acb0a373420d9b0c4202d38d94fa.com',
        'aadroid.net',
        'aanapa.ru',
        'aarbur.com',
        'aaronabel.com',
        'aasoldes.fr',
        'abbanreddy.com',
        'abcdefh.xyz',
        'abcdeg.xyz',
        'abcguru.xyz',
        'abclauncher.com',
        'abctoppictures.net',
        'abiente.ru',
        'above.com',
        'abovetherivernc.com',
        'absolute-s.ru',
        'absolutelyanalog.com',
        'absugars.com',
        'abtasty.com',
        'abusora.com',
        'abwa.tk',
        'academia-nsk.org',
        'academiacsmendoza.org',
        'acads.net',
        'acc.eu.org',
        'accessoires-mode.in',
        'acgs.tk',
        'acheterviagrafr24.com',
        'acortarurl.es',
        'actices.com',
        'actionnooz.com',
        'activecampaign.dreamhosters.com',
        'activepr.ru',
        'actulite.com',
        'acunetix-referrer.com',
        'ad-words.ru',
        'adamoads.com',
        'adanih.com',
        'adbetclickin.pink',
        'adcash.com',
        'adclickservice.com',
        'adclickthru.net',
        'adconscious.com',
        'add-add.men',
        'addbin.men',
        'addblueoff.com.ua',
        'addray.pro',
        'addtoadd.men',
        'adelly.bg',
        'adexprts.com',
        'adf.ly',
        'adhome.biz',
        'adidas.frwebs.fr',
        'adimmix.com',
        'adinterax.com',
        'adktrailmap.com',
        'adloads.com',
        'adloads.net',
        'adman.gr',
        'adman.se',
        'admanaerofoil.com',
        'admatic.com.tr',
        'admeasures.com',
        'adminshop.com',
        'admitad.com',
        'adnotbad.com',
        'adobereader-free.ru',
        'adpremium.org',
        'adprotect.net',
        'adrenalin-stk.ru',
        'ads-cool.pro',
        'ads-seo.men',
        'ads.gold',
        'ads.tremorhub.com',
        'adserver-e7.com',
        'adservme.com',
        'adsfresh.men',
        'adsland.men',
        'adsloads.com',
        'adsref.men',
        'adssafeprotected.com',
        'adtech.de',
        'adtech.fr',
        'adtech.us',
        'adtiger.tk',
        'adtology.com',
        'adult-shop.com.ua',
        'adult3dgames.com',
        'adultactioncam.com',
        'adultfriendfinder.com',
        'adultfullhd.com',
        'adultgalls.com',
        'adultmeetonline.info',
        'adultnet.in',
        'adultwebhosting.info',
        'advancedcleaner.com',
        'advancedsoftwaresupport.com',
        'adventureparkcostarica.com',
        'adverster.com',
        'advertex.info',
        'advertisingtag.net',
        'adviceforum.info',
        'advocatemsk.ru',
        'advokat-grodno.by',
        'advokateg.ru',
        'advokateg.xyz',
        'adzerg.com',
        'adzpower.com',
        'aero2.ru',
        'aerogo.com',
        'affiliate-fr.com',
        'affordablewebsitesandmobileapps.com',
        'affrh2015.com',
        'afftrack001.com',
        'afmuseum.com',
        'afora.ru',
        'afslankpillen2017nl.eu',
        'agadelha.com.br',
        'agahinameh.com',
        'agapovdg.ru',
        'agardomains.com',
        'agecheckadult.com',
        'aghanyna.com',
        'agreda.pluto.ro',
        'agroeconom.kz',
        'agysya.ru',
        'ahrefs.com',
        'ahrntal.verymes.xyz',
        'aibolita.com',
        'aihelen.net',
        'aimayangzhi.com',
        'air-edem.ru',
        'airlandsea.info',
        'airmaxshoes-2016.com',
        'akama.com',
        'akita.kz',
        'aksonural.ru',
        'aktivator-windows10.blogspot.com',
        'aktobe.xkaz.org',
        'akuhni.by',
        'akusherok.ru',
        'akvamaster.dp.ua',
        'alarmobninsk.ru',
        'albamargroup.com',
        'alborzan.com',
        'albumsuper.info',
        'alekseevec.ru',
        'alert-fdm.xyz',
        'alert-fjg.xyz',
        'alert-hgd.xyz',
        'alert-jdh.xyz',
        'alert.scansafe.net',
        'alessandraleone.com',
        'alf-img.com',
        'alfa-img.com',
        'alfa-medosmotr.ru',
        'alfa9.com',
        'alfabot.xyz',
        'alfapro.ru',
        'algerianembassy.co.in',
        'alibestsale.com',
        'alice.it',
        'alienwheel.es',
        'alienwheels.de',
        'aliexpress.com',
        'aliexpresscashback.club',
        'alif-ba-ta.com',
        'alive-ua.com',
        'alkoravto.ru',
        'all-number.com',
        'all-streaming-media.com',
        'all4invest.info',
        'all4invest.ru',
        'all4wap.ru',
        'allbizne.co.ua',
        'allblogroll.com',
        'allboard.xobor.de',
        'allcredits.su',
        'alldezservice.kz',
        'alldownload.pw',
        'alldubai.biz',
        'allesohnegirls.net',
        'allforminecraft.ru',
        'allknow.info',
        'allkrim.com',
        'allmarketsnewdayli.gdn',
        'allnews.md',
        'allnews24.in',
        'alloysteel.ru',
        'allpdfmags.net',
        'allsilver925.co.il',
        'allstatesugarbowl.org',
        'alltheviews.com',
        'allwidewallpapers.com',
        'allwomen.info',
        'aloofly.com',
        'alot.com',
        'alphacarolinas.com',
        'alphaforum.ru',
        'alphahoverboards.com',
        'alpharma.net',
        'alphavisions.net',
        'alpinism.ru',
        'alt-servis.ru',
        'alta-realestate.com',
        'altamayoztourism.com',
        'alveris.ru',
        'alvtank.se',
        'alyeskaresort.com',
        'am-se.com',
        'am15.net',
        'amanda-porn.ga',
        'amateurgalls.com',
        'amateurlivechat.org',
        'amateurmatch.com',
        'amazingninja.com',
        'amazingpic.net',
        'amazon-adsystem.com',
        'amazon-seo-service.com',
        'ameblo.jp',
        'amehdaily.com',
        'amigobulls.com',
        'amoi.tn',
        'amospalla.es',
        'ample-awards-today.us',
        'ampower.me',
        'amt-k.ru',
        'amung.us',
        'amyfoxfitness.com',
        'an-donut.com',
        'anabolics.shop',
        'anaksma.info',
        'anal-acrobats.com',
        'anal-acrobats.hol.es',
        'analytics-ads.xyz',
        'anapa-inns.ru',
        'andpolice.com',
        'android-style.com',
        'android-systems.ru',
        'android-vsem.org',
        'android4fun.org',
        'androids-store.com',
        'angigreene.com',
        'angkortours.vn',
        'angry-fermi-7633.arukascloud.io',
        'animal-drawings.com',
        'animal36.com',
        'animali.deagostinipassion.it',
        'animalia-life.club',
        'animalrank.com',
        'animaltoplist.com',
        'anime.dougasouko.com',
        'animebox.com.ua',
        'animenime.ru',
        'anjalika.co.in',
        'anlimebel.kiev.ua',
        'anmysite.com',
        'anniemation.com',
        'anonymizeme.pro',
        'anonymous-redirect.com',
        'anti-virus-removal.info',
        'anticrawler.org',
        'antons-transporte.de',
        'aosexkontakte.net',
        'aosheng-tech.com',
        'ap.senai.br',
        'apartamentwroclaw.eu',
        'apartment.ru',
        'apartmentbay.ru',
        'apartmentratings.com',
        'apccargo.com',
        'apelsinnik.website',
        'apessay.com',
        'api.stathat.com',
        'apiadanaknet-a.akamaihd.net',
        'apiallgeniusinfo-a.akamaihd.net',
        'apiappenableinfo-a.akamaihd.net',
        'apibatbrowsecom-a.akamaihd.net',
        'apibetweenlinesn-a.akamaihd.net',
        'apibrowsesmartne-a.akamaihd.net',
        'apidiamondatanet-a.akamaihd.net',
        'apidigidocketnet-a.akamaihd.net',
        'apifasterlightin-a.akamaihd.net',
        'apiholdingmypage-a.akamaihd.net',
        'apiitsthirteende-a.akamaihd.net',
        'apilinkswiftco-a.akamaihd.net',
        'apiluckyleapnet-a.akamaihd.net',
        'apimegabrowsebiz-a.akamaihd.net',
        'apimossnetinfo-a.akamaihd.net',
        'apimountainbikei-a.akamaihd.net',
        'apioasisspacenet-a.akamaihd.net',
        'apioutoboxnet-a.akamaihd.net',
        'apiportalmorecom-a.akamaihd.net',
        'apiqualitinknet-a.akamaihd.net',
        'apisecretsaucebi-a.akamaihd.net',
        'apishops.ru',
        'apispringsmartne-a.akamaihd.net',
        'apiwebwebgetcom-a.akamaihd.net',
        'apiwoodensealcom-a.akamaihd.net',
        'app-ready.xyz',
        'app5.letmacworkfaster.world',
        'apparel-offer.com',
        'appartement-stumm.at',
        'appearance-cool.com',
        'apper.de',
        'appfastplay.com',
        'appfixing.space',
        'appiq.mobi',
        'apple.com-cleaner.systems',
        'apple.com-webbrowsing-security.review',
        'apple.com-webbrowsing-security.science',
        'appleid-verification.com',
        'applicationg29.com',
        'applyneedy.xyz',
        'approved.su',
        'approvedlocal.co.za',
        'apps-analytics.net',
        'appsaurus.com',
        'appsecurityr.com',
        'apptester.tk',
        'aproposde.com',
        'apxeo.info',
        'aquarium-pro.ru',
        'arabgirls.adultgalls.com',
        'arabsexxxtube.com',
        'arabseyes.com',
        'aramaicmedia.org',
        'arate.ru',
        'arcadepages.com',
        'arcadeplayhouse.com',
        'architecturebest.com',
        'arclk.net',
        'arcteryxsale.online',
        'arcteryxstore.online',
        'ardimobileinfo.ml',
        'arenanews.com.ua',
        'arenda-avtoprokat-krasnodar.ru',
        'arenda-yeisk.ru',
        'arendakvartir.kz',
        'arendas.net',
        'arendatora.ru',
        'arendovalka.xyz',
        'arewater.com',
        'arius.tech',
        'arkartex.ru',
        'arkkivoltti.net',
        'arpelsreplica.xyz',
        'arquapetrarca.info',
        'arraty.altervista.org',
        'artavenuegardenstudios.com',
        'artdeko.info',
        'artdestshop.eu',
        'artefakct.com',
        'artel116.ru',
        'articlesdirectoryme.info',
        'artparquet.ru',
        'artpicso.com',
        'aruplighting.com',
        'arvut.org',
        'as5000.com',
        'asacopaco.tk',
        'ascat.porn',
        'asdfg.pro',
        'asdfz.pro',
        'asia-forum.ru',
        'asiengirls.net',
        'asmxsatadriverin.aircus.com',
        'asociatia-tipografilor-transilvania.ro',
        'asophoto.com',
        'asrv-a.akamaihd.net',
        'asrv-a.akamoihd.net',
        'asrvrep-a.akamaihd.net',
        'asrvvv-a.akamaihd.net',
        'asscenihotosidea.blogspot.co.za',
        'asscenihotosidea.blogspot.com',
        'asseenontv.ru',
        'asseenontvonline.ru',
        'astana.xxxkaz.org',
        'astrochicks.com',
        'atelielembrancaqueencanta.com.br',
        'atlant-auto.info',
        'atlasvkusov.ru',
        'atleticpharm.org',
        'atley.eu.pn',
        'atmagroup.ru',
        'atmovs.com',
        'atofilms.com',
        'atout-energie-69.com',
        'atovh.local-finders.com',
        'audiobangout.com',
        'audiofree.ru',
        'ausergrubhof.info',
        'ausmepa.org.au',
        'auspolice.com',
        'aussie-prizes.com',
        'australia-opening-times.com',
        'auto-moto-elektronika.cz',
        'auto-zapchasti.org',
        'auto.rusvile.lt',
        'auto4style.ru',
        'autoblogger24.info',
        'autobrennero.it',
        'autobudpostach.club',
        'autochoixspinelli.com',
        'autodo.info',
        'autogrep.ru',
        'autoloans.com',
        'autolombard-krasnodar.ru',
        'automatic-seo.com',
        'autonew.biz',
        'autoplate.info',
        'autorn.ru',
        'autoseo-traffic.com',
        'autotop.com.ua',
        'autotrends.today',
        'autoua.top',
        'autovideobroadcast.com',
        'autowebmarket.com.ua',
        'availit.weebly.com',
        'avek.ru',
        'aversis.net',
        'aviapanda.ru',
        'aviav.co',
        'aviav.eu',
        'aviav.org',
        'aviav.ru',
        'aviav.ru.com',
        'avirasecureserver.com',
        'avitocars.ru',
        'aviva-limoux.com',
        'avkzarabotok.com',
        'avkzarabotok.info',
        'avon-novosib.ru',
        'avon-severozapad.ru',
        'avon-ukraine.com',
        'avramstroy.ru',
        'avtoarenda.by',
        'avtochehli.by',
        'avtocredit-legko.ru',
        'avtointeres.ru',
        'avtolombard-krasnodar.com',
        'avtolombard-krasnodar.ru',
        'avtovolop.ru',
        'away.vk.com',
        'awaybird.ru',
        'awency.com',
        'axbocz.net',
        'ayakino.net',
        'ayanaspa.com',
        'ayeartoforget.com',
        'ayerbo.xhost.ro',
        'azadnegar.com',
        'azartclub.org',
        'azartmix.com',
        'azartniy-bonus.com',
        'azazaporn.com',
        'azazu.ru',
        'azbaseimages.net',
        'azbuka-mo.ru',
        'azbukadiets.ru',
        'azbukafree.com',
        'azlex.uz',
        'azte.ch',
        'b-styles.xyz',
        'b00kmarks.com',
        'b2b-lounge.com',
        'babespcs.com',
        'babieca.com',
        'bablonow.ru',
        'babs.com.ua',
        'babyfactory.fr',
        'babyguns.ru',
        'back.dog',
        'backgroundpictures.net',
        'backlink4u.net',
        'backlinkwatch.com',
        'backuperwebcam.weebly.com',
        'bad-stars.net',
        'baditri.com',
        'baersaratov.ru',
        'bag77.ru',
        'bagcionderlab.com',
        'bagsonsale.online',
        'baixar-musicas-gratis.com',
        'baksman.com',
        'bala.getenjoyment.net',
        'baladur.ru',
        'balans.shahterworld.org',
        'balitouroffice.com',
        'balkanfarma.org',
        'balkanfarma.ru',
        'balla-boo.se',
        'balois.worldbreak.com',
        'balook.com',
        'baltgem.com',
        'bambi.ck.ua',
        'bamo.xsl.pt',
        'banan.tv',
        'bang-hotties.com',
        'bangla-chat-uk-paralud.ga',
        'bank.uz',
        'bankcrediti.ru',
        'banki76.ru',
        'bankiem.pl',
        'bankmib.ru',
        'bankofthewext.com',
        'bannerads.de',
        'bannerbank.ru',
        'bannerconnect.net',
        'bannerpower.com',
        'bannerspace.com',
        'bannerswap.com',
        'bannertesting.com',
        'baoxaydung.com.vn',
        'barbourjackets.online',
        'bard-real.com.ua',
        'barnfurnituremart.com',
        'basedecor.ru',
        'bashtime.ru',
        'basisches-wasser.net',
        'batanga.net',
        'battle.net',
        'battlecarnival.su',
        'battleforupdating.site',
        'bausparen.bz.it',
        'bayareaaeroclub.org',
        'bazaronline24.ru',
        'bbsoldes.fr',
        'bbtec.net',
        'bcmp.org',
        'bdsmgalls.net',
        'beachdriveblog.com',
        'beachpics.com',
        'beachtoday.ru',
        'bear.gotcher.us',
        'beatifullandscape.co',
        'beauby.ru',
        'beauty-b0x.pl',
        'beauty-bracelet.com',
        'beauty-clinic.ru',
        'beauty-things.com',
        'beclean-nn.ru',
        'becuo.com',
        'bedandbreakfast.com',
        'bedcapdealers.com',
        'begalka.xyz',
        'beget.tech',
        'belinka.com.ua',
        'belinvestdom.by',
        'belstaffstore.online',
        'benchmarkcommunications.co.uk',
        'bensbargains.net',
        'berdasovivan.ru',
        'beremenyashka.com',
        'berlininsl.com',
        'berrymall.ru',
        'best-businessman.ru',
        'best-coupon-offer.com',
        'best-deals-products.com',
        'best-games.today',
        'best-seo-offer.com',
        'best-seo-software.xyz',
        'best-seo-solution.com',
        'best-way.men',
        'bestadbid.com',
        'bestbrainprod.win',
        'bestbuy.ca',
        'bestcalovebracelet.cn',
        'bestchoice.cf',
        'bestcoin.cc',
        'bestcurs.org',
        'bestdooz.com',
        'bestdraws.com',
        'bestempresas.es',
        'besthoro.ru',
        'bestimagecoollibrary.com',
        'bestkfiledxd.cf',
        'bestmarriages.com',
        'bestmobilityscooterstoday.com',
        'bestofferswalkmydogouteveryday.gq',
        'bestofpicture.com',
        'bestofupload.info',
        'bestplacetobuyeriacta.jw.lt',
        'bestpriceninja.com',
        'bestprofits-there.com',
        'bestserials.com',
        'bestssaker.com',
        'besttorrentknifta.weebly.com',
        'bestwaystogetpaid.us',
        'bestwebsiteawards.com',
        'bestwebsitesawards.com',
        'bestwrinklecreamnow.com',
        'bet-prognoz.com',
        'bet365.com',
        'beta.hotkeys.com',
        'betonka.pro',
        'betterhdporn.com',
        'betteroffers.review',
        'betterscooter.com',
        'betune.onlinewebshop.net',
        'betwinservice.com',
        'beyan.host.sk',
        'bezcmexa.ru',
        'bezlimitko.xyz',
        'bezsporno.ru',
        'beztuberkuleza.ru',
        'bfz.biz',
        'bharatdefencekavach.com',
        'bibys.com',
        'bidbuy.co.kr',
        'bidr.trellian.com',
        'bif-ru.info',
        'big-boards.info',
        'big-cash.net',
        'bigames.online',
        'bigcareer.info',
        'bigcities.org',
        'biglistofwebsites.com',
        'bigpenisguide.com',
        'bigpictures.club',
        'biketank.ga',
        'bikini-image.com',
        'bildsuche.ru',
        'billiard-classic.com.ua',
        'bimatoprost-careprost.com',
        'bimatoprost-careprost.com.ua',
        'binaryoptionscops.info',
        'bingo8888.com',
        'binomo.com',
        'binomo.kz',
        'bio-japan.net',
        'bio-market.kz',
        'bio-optomarket.ru',
        'bio.trade-jp.net',
        'bioca.org',
        'biographiya.com',
        'bioscorp.ru',
        'bird1.ru',
        'birzha-truda.eu',
        'bitcoinpile.com',
        'bitcoinremote.com',
        'bitcoins-live.ru',
        'biteg.xyz',
        'bitnote.co',
        'bitporno.sx',
        'bizcheapjerseyswholesalechina.com',
        'bizfly.info',
        'bizlist.com.de',
        'biznesluxe.ru',
        'biznesrealnost.ru',
        'biznesschat.net',
        'bizru.info',
        'bjanshee.ru',
        'bjetjt.com',
        'bjgugu.net.ua',
        'bjorkbacken.nu',
        'bkgr.se',
        'bkns.vn',
        'blackcurranthumidifiers.site',
        'blackhatworth.com',
        'blackle.com',
        'blackplanet.com',
        'blacktwhite.com',
        'blackwitchcraft.ru',
        'blagovest-med.ru',
        'blavia.00author.com',
        'blobar.org',
        'blockworld.ru',
        'blog-hits.com',
        'blog.axant.it',
        'blog.f00kclan.de',
        'blog.koorg.ru',
        'blog.koreadaily.com',
        'blog.remote-computer.de',
        'blog.yam.com',
        'bloggedporn.com',
        'bloggen.be',
        'bloggerads.net',
        'bloggers.nl',
        'blogig.org',
        'blogos.kz',
        'blogporn.in',
        'blogqpot.com',
        'blogrankers.com',
        'blogs.rediff.com',
        'bloke.com',
        'blpmovies.com',
        'blue-square.biz',
        'bluejays-jerseys.us',
        'bluerobot.info',
        'bluesalt.co',
        'bluesman.nu',
        'bmsco.co',
        'bmw-ark.ru',
        'bmw.afora.ru',
        'bmwhighperformers.com',
        'bnt-team.com',
        'board.f00d.de',
        'boazpower.com',
        'bobba.dzaba.com',
        'bobinoz.com',
        'boc.kz',
        'bochemit.com.ua',
        'bocoarchives.org',
        'bodybuilding-shop.biz',
        'bolegapakistan.com',
        'boleznikogi.com',
        'bolezniorganov.ru',
        'bolitgorlo.net',
        'boltalko.xyz',
        'bombla.org',
        'bonanza-fortune.men',
        'bongacams.com',
        'bongiornos.info',
        'bonkers.name',
        'bonky.biz',
        'bonux.nextview.ru',
        'bonvillan.com',
        'bonzbuddy.com',
        'bonzibuddi.com',
        'bonzybuddy.com',
        'boobsimge.com',
        'bookhome.info',
        'bookmaker-bet.com',
        'bookmark4you.com',
        'bookmark4you.com.biz',
        'boole.onlinewebshop.net',
        'boostmyppc.com',
        'bosefux.esy.es',
        'bosman.pluto.ro',
        'bouda.kvalitne.cz',
        'bpro1.top',
        'brainboosting.club',
        'brainboostingsupplements.org',
        'braindaily.xyz',
        'brains2.biz',
        'brainsandeggs.blogspot.com',
        'braintobe.win',
        'brainxs.us',
        'brainzpod.win',
        'braip.com.br',
        'brakehawk.com',
        'brandbucket.com',
        'brandedleadgeneration.com',
        'brandehk.dk',
        'brandov.ru',
        'brateg.xyz',
        'bravegirlsclub.com',
        'break-the-chains.com',
        'breastaugmentation.co.za',
        'breget74.ru',
        'brendbutik.ru',
        'brewdom.ru',
        'brg8.com',
        'brillianty.info',
        'brimstonehillfortress.org',
        'briomotor.co',
        'bristolhostel.com',
        'bristolhotel.com',
        'bristolhotel.com.ua',
        'brk-rti.ru',
        'brokergid.ru',
        'bronzeaid-a.akamaihd.net',
        'brothers-smaller.ru',
        'browsepulse-a.akamaihd.net',
        'browserprotecter.com',
        'brus-vsem.ru',
        'brus.city',
        'bryansk.zrus.org',
        'bscodecs.com',
        'btc4u.ru',
        'btnativenav.com',
        'btvn.ru',
        'buchananshardware.com',
        'buckspar.gq',
        'budilneg.xyz',
        'budpost.com.ua',
        'buehne-fuer-menschenrechte.de',
        'bugof.gq',
        'buigas.00it.com',
        'builtwith.com',
        'buketeg.xyz',
        'bukleteg.xyz',
        'bum.com.ru',
        'bumascloset.com',
        'bumble.cheapwebsitehoster.com',
        'bumskontakte.org',
        'buntube.net',
        'bupropion-sr-150-mg.us',
        'buqayy0.livejournal.com',
        'buqyxa.rincian.info',
        'burger-imperia.com',
        'burkesales.com',
        'burn-fat.ga',
        'buron.pw',
        'bus-offer.com',
        'businescoop.men',
        'businesn.men',
        'business-made-fun.com',
        'business-suggested.tk',
        'businesxxl.com',
        'butstrap.space',
        'buttons-for-website.com',
        'buttons-for-your-website.com',
        'buy-cheap-online.info',
        'buy-cheap-pills-order-online.com',
        'buy-forum.ru',
        'buy-loft.ru',
        'buy-meds24.com',
        'buyantiviralwp.com',
        'buybest1.biz',
        'buyclomidonlaine.com',
        'buydissertation.net',
        'buyessay3.blogspot.ru',
        'buyessaynow.biz',
        'buyessayonline19.blogspot.ru',
        'buyfriend.ru',
        'buyhoverboard.com',
        'buyk.host.sk',
        'buynorxx.com',
        'buypanicdisorderpill.com',
        'buyparajumpers.online',
        'buypillsorderonline.com',
        'buypuppies.ca',
        'buyscabiescream.com',
        'buytizanidineonline.blogspot.com',
        'buytizanidineonlinenoprescription.blogspot.com',
        'buyviagraa.blogspot.com',
        'buzz-porno.info',
        'buzzonclick.com',
        'buzzsumo.com',
        'buzzurl.jp',
        'buzzzg.men',
        'bvlgaribracelet.xyz',
        'bvlgariring.xyz',
        'bvlgariwallet.xyz',
        'bwlx.prepedu.cn',
        'bycontext.com',
        'byme.se',
        'bytimedance.ru',
        'bzero1jewelry.net',
        'c-english.ru',
        'c-gainsbourg.com',
        'c1.onedmp.com',
        'cablecar.us',
        'cacheimages.com',
        'cactussoft.biz',
        'cakemediahq.com.au',
        'cakesplus.com.au',
        'calc-for-credit.ru',
        'calcularpagerank.com',
        'californianews.cf',
        'call-of-duty.info',
        'callawaygolfoutlet.online',
        'callawaygolfstore.online',
        'callejondelpozo.es',
        'callmd5map.com',
        'calstaterealty.us',
        'calvet.altervista.org',
        'cam-kontakte.org',
        'camdenmemorials.com',
        'camdolls.com',
        'camel-beach.com',
        'camsex.xxx-cam.webcam',
        'canacopegdl.com',
        'cand.jp',
        'candcstuccoandstone.com',
        'candelluxsklep.pl',
        'candiceloves.us',
        'candlehandmade.com',
        'candlewooddentalcentre.com.au',
        'candy-glam-hp.com',
        'candycrushshop.com',
        'candypeople.se',
        'candytiner.com',
        'canoncdriverq3.pen.io',
        'canrioloadm.gq',
        'canrole.com',
        'canvas.gloverid.site',
        'canyougethighofftizanidine.blogspot.com',
        'canzoni.ru',
        'capacitacionyaprendizaje.com',
        'capture-room.com',
        'carabela.com.do',
        'carapics.com',
        'cardiosport.com.ua',
        'cardsdumps.com',
        'cardsharp1.ru',
        'cardul.ru',
        'carfax.com.ua',
        'carina-sy.de',
        'carloans.com',
        'carmuffler.net',
        'cars-modification.net',
        'carsdined.org',
        'carson.getenjoyment.net',
        'carsplate.com',
        'carstrends2015.com',
        'cartechnic.ru',
        'cartierbracelet.xyz',
        'cartierbraceletsreplica.pw',
        'cartierjusteunclou.xyz',
        'cartierlove.xyz',
        'cartierlove2u.com',
        'cartierlove2u.xyz',
        'cartierlovebracelet.xyz',
        'cartierlovebraceletreplica.xyz',
        'cartierloveringreplica.xyz',
        'cartierlovestore.com',
        'cartierlovestore.xyz',
        'cartierreplica.pw',
        'cartierreplica.top',
        'cartierreplica.win',
        'cartierreplica.xyz',
        'cartierring.xyz',
        'cartiertrinity.xyz',
        'cartierwatch.xyz',
        'cartujano-pre.de',
        'casablancamanor.co.za',
        'cascadelink.org',
        'cashkitten-a.akamaihd.net',
        'cashonads.com',
        'casinorewards.info',
        'casinos4dummies.co.uk',
        'casite-513049.cloudaccess.net',
        'castingbank.ru',
        'catalogs-parts.com',
        'caulderwoodkennels.com',
        'caveavins.fr',
        'cayado.snn.gr',
        'cb.iphantom.com',
        'cbb1smartlist12.click',
        'cbcseward.com',
        'cbox.ws',
        'ccbill.com',
        'cctva.tv',
        'cdn.walkme.com',
        'cdnanalytics.xyz',
        'cdncash.com',
        'cdncash.net',
        'cdncash.org',
        'cdnnetwok.xyz',
        'cejewelry.xyz',
        'celebsopics.com',
        'cellfun.mobi',
        'cementaresearch.se',
        'cenokos.ru',
        'cenoval.ru',
        'centraletermice.us',
        'centrdebut.ru',
        'centre-indigo.org.ua',
        'centrumcoachingu.com',
        'ceotrk.com',
        'cercacamion.it',
        'cete.ru',
        'cezartabac.ro',
        'cfacarrosserie74.com',
        'cfcl.co.uk',
        'cfjump.com',
        'cfsrating.sonicwall.com',
        'cgi2.nintendo.co.jp',
        'charmstroy.info',
        'chastnoeporno.com',
        'chatroulette.life',
        'chatroulette.online',
        'chatroulette.si',
        'chatroulette.video',
        'chatroulette.world',
        'chatseo.com',
        'chcu.net',
        'cheap-pills-norx.com',
        'cheap-trusted-backlinks.com',
        'cheapbarbour.online',
        'cheapbelstaff.online',
        'cheapcigarettesc.info',
        'cheapestjerseys-wholesale.com',
        'cheapestjerseysonwholesale.com',
        'cheapjerseysa.com',
        'cheapjerseysap.com',
        'cheapjerseysbizwholesale.us',
        'cheapjerseysfootballshop.com',
        'cheapmarmot.online',
        'cheapmoncler.pw',
        'cheapmoncler.win',
        'cheapmoncler.xyz',
        'cheapsergiorossi.online',
        'cheapwebsitehoster.com',
        'cheatcode-lita12.rhcloud.com',
        'check-host.net',
        'checkhit.com',
        'checkm8.com',
        'checkpagerank.net',
        'checktext.org',
        'chee-by.biz',
        'chelnytruck.ru',
        'chelyabinsk.xrus.org',
        'cherrypointplace.ca',
        'cherubinimobili.it',
        'chiblackhawks-jerseys.com',
        'chidporn.com',
        'children-learningreading.info',
        'chimiver.info',
        'chinacheapelitejerseys.com',
        'chinaelitecheapjerseys.com',
        'chinajerseyswholesalecoupons.com',
        'chinese-amezon.com',
        'chiptuninger.com',
        'chlooe.com',
        'chocolateslim-en-espana.com',
        'chocolateslim-en-france.com',
        'chocolateslim-original.com',
        'chocolateslim-u-srbiji.com',
        'chocoslim.pro',
        'choice-credit.ru',
        'choosecuisine.com',
        'chorus.terakeet.com',
        'christianlouboutinoutlet.win',
        'christianlouboutinreplica.pw',
        'christianlouboutinreplica.win',
        'christianlouboutinsaleonline.us',
        'christianlouboutinsaleoutletonline.us',
        'christianlouboutinshoes.xyz',
        'chuckguilford.com',
        'ci.ua',
        'cialis-samples.com',
        'cialisovercounteratwalmartusa.com',
        'cialiswithoutadoctor.net',
        'cibpenonptib.flu.cc',
        'cicaki.net',
        'ciekawinki.pl',
        'cienum.fr',
        'cigarpass.com',
        'cineacademy.ru',
        'cinemaenergy-hd.ru',
        'cinemaflix.website',
        'ciproandtizanidine.blogspot.com',
        'circlesl.com',
        'citetick.com',
        'citizenclsdriveri7.pen.io',
        'cityadspix.com',
        'citysecurity.nu',
        'civilwartheater.com',
        'cjmc.info',
        'cjs.com.ru',
        'cl.s7.exct.net',
        'clarithromycin500mg.com',
        'clash-clans.ru',
        'classicakuhni.ru',
        'classiquebijoux.ru',
        'claytransformations.info',
        'clayvasedesigns.tk',
        'clean-start.net',
        'clean-virus-mac.com',
        'cleanallspyware.com',
        'cleanallvirus.com',
        'cleanersoft.com',
        'cleanmypc.com',
        'cleanpcnow.com',
        'cleansearch.net',
        'clevernt.com',
        'clickaider.com',
        'clickbank.net',
        'clickbanksites.info',
        'clickcash.com',
        'clickhype.com',
        'clickintext.net',
        'clickpapa.com',
        'clickprotects.com',
        'clickso.com',
        'clicksor.com',
        'clicksor.net',
        'clicksotrk.com',
        'clickzzs.nl',
        'clipartnew.com',
        'clippingphotoindia.com',
        'clips.ua.ac.be',
        'clknsee.com',
        'clksite.com',
        'clmforexeu.com',
        'clodo.ru',
        'clothesforcash.com',
        'club-lukojl.ru',
        'club-musics.ru',
        'club-samodelkin.ru',
        'clubfashionista.com',
        'cmd.kz',
        'cmhomestayagency.com',
        'cntravelre.com',
        'co.lumb.co',
        'coaching-netz.info',
        'cobaltpro.ru',
        'cocyq.inwtrade.com',
        'coderstate.com',
        'codq.info',
        'codysbbq.com',
        'cognitiveseo.com',
        'coin-hive.com',
        'coindirect.io',
        'coinsspb.com',
        'coldfilm.ru',
        'colehaanoutlet.store',
        'collegeessay19.blogspot.ru',
        'collegerentals.com',
        'colobit.biz',
        'com-cleaner.systems',
        'com-onlinesupport.host',
        'com-onlinesupport.site',
        'com-secure.download',
        'com-supportcenter.website',
        'comeondog.info',
        'cometorussia.net',
        'comissionka.net',
        'communisave.co.za',
        'community.allhiphop.com',
        'companies-catalog.com',
        'compiko.info',
        'compliance-alex.top',
        'compliance-alex.xyz',
        'compliance-alexa.top',
        'compliance-alexa.xyz',
        'compliance-andrew.top',
        'compliance-andrew.xyz',
        'compliance-barak.top',
        'compliance-barak.xyz',
        'compliance-brian.top',
        'compliance-brian.xyz',
        'compliance-checker-7.info',
        'compliance-checker.info',
        'compliance-don.top',
        'compliance-don.xyz',
        'compliance-donald.xyz',
        'compliance-elena.top',
        'compliance-elena.xyz',
        'compliance-fred.top',
        'compliance-fred.xyz',
        'compliance-george.top',
        'compliance-george.xyz',
        'compliance-irvin.top',
        'compliance-irvin.xyz',
        'compliance-ivan.top',
        'compliance-ivan.xyz',
        'compliance-jack.top',
        'compliance-jane.top',
        'compliance-jess.top',
        'compliance-jessica.top',
        'compliance-john.top',
        'compliance-josh.top',
        'compliance-julia.top',
        'compliance-julianna.top',
        'compliance-margo.top',
        'compliance-mark.top',
        'compliance-mary.top',
        'compliance-nelson.top',
        'compliance-olga.top',
        'compliance-viktor.top',
        'compliance-walt.top',
        'compliance-walter.top',
        'compliance-willy.top',
        'compucelunlock.net',
        'computernetworksonline.com',
        'comsysnet.com',
        'conboy.us',
        'concealthyself.com',
        'conciergegroup.org',
        'concordexoticrentals.com',
        'confib.ifmo.ru',
        'connectingsingles.com',
        'connectionstrenth.com',
        'conocer-sanabria.com',
        'consorzioilmosaico.org',
        'constantaservice.net',
        'construmac.com.mx',
        'contentlook.co',
        'contentsexpress.com',
        'contextualyield.com',
        'continent-e.tv',
        'converse.ddsoldes.fr',
        'cookie-law-enforcement-aa.xyz',
        'cookie-law-enforcement-ee.xyz',
        'cookie-law-enforcement-ff.xyz',
        'cookie-law-enforcement-hh.xyz',
        'cookielawblog.wordpress.com',
        'cookingmeat.ru',
        'cool-wedding.net',
        'coolbar.pro',
        'coolgamechannel.com',
        'coolgramgoods.com',
        'coolingoods.com',
        'coolwallpapers-hd.com',
        'coolyarddecorations.com',
        'coop-gamers.ru',
        'copblock.org',
        'copenergo.ru',
        'copro.pw',
        'coprofam.org',
        'copypaste.traderzplanet.in',
        'copyrightclaims.org',
        'cordstrap.cc',
        'cornerstone-countertops.com',
        'cornomase.win',
        'corta.co',
        'coslab.club',
        'cosmetic.donna7753191.ru',
        'cosmeticswomens-womensports.rhcloud.com',
        'cottageofgrace.com',
        'cougfan.info',
        'counciltally.com',
        'countbertwistdisp26.soup.io',
        'counter.bloke.com',
        'counter.yadro.ru',
        'counterbot.com',
        'countercrazy.com',
        'country-chic.ru',
        'courtshipgift.com',
        'covadhosting.biz',
        'covetnica.com',
        'cowblog.fr',
        'cowlmash.com',
        'cpabegins.ru',
        'cpajunkies.com',
        'crackguru.tk',
        'cracksplanet.com',
        'crackzplanet.com',
        'craftburg.ru',
        'crafthubs.com',
        'craftinsta.ru',
        'cranly.net',
        'crazyboost.pro',
        'crazyprotocol.com',
        'crd.clan.su',
        'creams.makeforum.eu',
        'creativehutindia.com',
        'creatives.adbetclickin.pink',
        'credit-respect.ru',
        'creditmoney.com.ua',
        'creditnation.ru',
        'creditwell.ru',
        'crest-poloski.ru',
        'crest3d.ru',
        'crirussian.ru',
        'crynet.cc',
        'cryptoswap.biz',
        'crystalslot.com',
        'cs-passion.pl',
        'cscwtalkto.site',
        'csgo4.win',
        'cubook.supernew.org',
        'cubs-jerseys.us',
        'culad.com',
        'culturevie.info',
        'cupday.com',
        'custodieva.ru',
        'custom-electric-guitar.com',
        'custom-product-labels.com',
        'customboxes4less.com',
        'customcatchcan.com',
        'customchocolate.business-for-home.com',
        'customcollegeessays.net',
        'customergrowthsystems.com',
        'customerguru.in',
        'customerpromos-a.akamaihd.net',
        'customsua.com.ua',
        'cutalltheshit.com',
        'cv.wallhade.co',
        'cvety24.by',
        'cxpromote.com',
        'cyclobenzaprinevstizanidine.blogspot.com',
        'cymbaltaandtizanidine.blogspot.com',
        'cypernhuset.se',
        'cyprusbuyproperties.com',
        'cyse.tk',
        'czat.wp.pl',
        'd-black.bz',
        'd0t.ru',
        'd2jsp.org',
        'dafatiri.com',
        'dailyfinancefix.com',
        'dailyrank.net',
        'dailystrength.org',
        'dairyindia.in',
        'dalavia.ru',
        'dame-ns.kz',
        'damedingel.ya.ru',
        'danashop.ru',
        'danceuniverse.ru',
        'dandiyabeats.in',
        'daneshetabiat.com',
        'dangphoto.trade',
        'danschawbel.com',
        'daooda.com',
        'daptravel.com',
        'darkbooks.org',
        'darmebel.com.ua',
        'darodar.com',
        'data-mining.tk',
        'data.vtc.pw',
        'data1.scopich.com',
        'dataloading.net',
        'date-withme.com',
        'dating-app.ru',
        'dating-time-now.com',
        'datract.com',
        'datsun-do.com',
        'davebestdeals.com',
        'day-news.info',
        'daydream-studio.ru',
        'dayibiao.com',
        'daymusam.com',
        'dbmkfhqk.bloger.index.hr',
        'dcj-nn.ru',
        'ddlmega.net',
        'ddospanel.com',
        'ddpills.com',
        'ddsoldes.fr',
        'de.zapmeta.com',
        'deadlinkchecker.com',
        'dealighted.com',
        'dealitright.click',
        'dealwifi.com',
        'deanmoore.ie',
        'dear-diary.ru',
        'decenttools.com',
        'decoratinghomes.ga',
        'decorationspcs.com',
        'decorazilla.com',
        'deda-moroza-zakaz.ru',
        'defenderxtactical.com',
        'degerlund.net',
        'dekoration.us',
        'dekorkeramik.ru',
        'delayreferat.ru',
        'delfin-aqua.com.ua',
        'dellalimov.com',
        'delta-line.men',
        'deluxedumps.com',
        'demenageur.com',
        'demian.kz',
        'den-noch24.ru',
        'dengi-pod-zalog-nedvizhimosti.ru',
        'deniven.1bb.ru',
        'dentalpearls.com.au',
        'deplim.com',
        'depositfiles-porn.ga',
        'derevesendeco.com',
        'descargar-musica-gratis.net',
        'deshevo-nedorogo.ru',
        'design-ideas.info',
        'design-lands.ru',
        'designdevise.com',
        'destinationrealestate.com',
        'detalizaciya-tut.biz',
        'detective01.ru',
        'detki-opt.ru',
        'detskie-konstruktory.ru',
        'detskie-zabavi.ru',
        'detsky-nabytek.info',
        'deutschehobbyhuren.net',
        'deutschland123.de',
        'dev-seo.blog',
        'dev.citetick.com',
        'dev33.dioniqlabb.se',
        'dev78.dioniqlabb.se',
        'devochki.top',
        'dfiles.me',
        'dfwu1013.info',
        'dfwu1019.info',
        'diarioaconcagua.com',
        'dichvuvesinhhanoi.com',
        'dickssportinggoods.com',
        'diegolopezcastan.com',
        'diesel-parts28.ru',
        'dieswaene.com',
        'dieta-personalna.pl',
        'diffbot.com',
        'digest-project.ru',
        'digilander.libero.it',
        'digital-sale.su',
        'digital-video-processing.com',
        'digitalfaq.com',
        'dignitasdata.se',
        'dikqlyremy.info',
        'dikx.gdn',
        'dildofotzen.net',
        'dimaka.info',
        'diminishedvalueoforegon.com',
        'dimkino.ru',
        'dinkolove.ya.ru',
        'dipstar.org',
        'directivepub.com',
        'directrev.com',
        'discountbarbour.online',
        'discountliv.com',
        'discovertreasure-a.akamaihd.net',
        'discovertreasurenow.com',
        'dispo.de',
        'disruptingdinnerparties.com',
        'distver.ru',
        'div.as',
        'divatraffic.com',
        'dividendo.ru',
        'divisioncore.com',
        'divku.ru',
        'diy-handmade-ideas.com',
        'djekxa.ru',
        'djihispano.com',
        'djonwatch.ru',
        'djstools.com',
        'dktr.ru',
        'dkvorota.ru',
        'dlya-android.org',
        'dms-sw.ru',
        'dnepr-avtospar.com.ua',
        'dnepropetrovsk.mistr-x.org',
        'dneprsvet.com.ua',
        'dnsrsearch.com',
        'docs4all.com',
        'docsportal.net',
        'docstoc.com',
        'doctissimo.fr',
        'doctormakarova.ru',
        'documentbase.net',
        'documentsite.net',
        'dodlive.mil',
        'doeco.ru',
        'dogbreedspicture.net',
        'dogclothing.store',
        'dogoimage.com',
        'dogsrun.net',
        'dojki-hd.com',
        'dokfilms.net',
        'doktoronline.no',
        'dokumentalkino.net',
        'dollartree.info',
        'domain-submit.info',
        'domain-tracker.com',
        'domain.webkeyit.com',
        'domain2008.com',
        'domainanalyzing.xyz',
        'domaincdn.xyz',
        'domaincheck.io',
        'domaincrawler.com',
        'domaineaneblanc.com',
        'domainroam.win',
        'domainsatcost.com',
        'domainsphoto.com',
        'domashneeruporno.com',
        'domcran.net',
        'domik-derevne.ru',
        'dominateforex.ml',
        'domination.ml',
        'domini.cat',
        'dominterior.org',
        'domoysshop.ru',
        'domznaniy.ru',
        'donna7753191.ru',
        'donvito.unas.cz',
        'dorratex.tn',
        'doska-vsem.ru',
        'dostavimvdom.ru',
        'dostavka-v-krym.com',
        'dostavka-v-ukrainu.ru',
        'dosug-lux.ru',
        'dotnetdotcom.org',
        'doublepimp.com',
        'download-of-the-warez.blogspot.com',
        'download-wallpaper.net',
        'downloaddy.net',
        'downloadeer.net',
        'downloader12.ru',
        'downloadkakaotalk.com',
        'downloadmefiranaratb1972.xpg.com.br',
        'downloads-whatsapp.com',
        'downtuptv.gq',
        'downvids.net',
        'doxyporno.com',
        'doyouknowtheword-flummox.ml',
        'dpihatinh.gov.vn',
        'dprtb.com',
        'dptaughtme.com',
        'drhomes.biz',
        'drillsaw.ru',
        'driving.kiev.ua',
        'drivotracker.com',
        'droidlook.net',
        'drugs-no-rx.info',
        'drugspowerstore.com',
        'drugstoreforyou.com',
        'drunkenstepfather.com',
        'drunkmoms.net',
        'drupa.com',
        'druzhbany.ru',
        'druzhininevgeniy63.blogspot.com',
        'dstroy.su',
        'dtnlyss.com',
        'dumpsmania24.com',
        'duplicashapp.com',
        'dustyorate.com',
        'dvd-famille.com',
        'dverimegapolis.ru',
        'dvervmoskvu.ru',
        'dvr.biz.ua',
        'dvrlists.com',
        'dynainbox.com',
        'dyshagi.ru',
        'dyt.net',
        'e-avon.ru',
        'e-biznes.info',
        'e-buyeasy.com',
        'e-collantes.com',
        'e-commerce-seo.com',
        'e-commerce-seo1.com',
        'e-kwiaciarz.pl',
        'e-poker-2005.com',
        'e2click.com',
        'e705.net',
        'eachdayisagift.review',
        'eandsgallery.com',
        'eaplay.ru',
        'earl-brown.info',
        'earn-from-articles.com',
        'earncash.com.ua',
        'eas-seo.com',
        'easycommerce.cf',
        'easync.io',
        'easyshoppermac.com',
        'easytuningshop.ru',
        'easyukraine.com',
        'ec-file.info',
        'ecommerce-seo.com',
        'ecommerce-seo.org',
        'econom.co',
        'ecookna.com.ua',
        'ecxtracking.com',
        'ed-shop01.ru',
        'edelstahlschornstein-123.de',
        'edge.sharethis.com',
        'editmedios.com',
        'editors.choice6912650.hulfingtonpost.com',
        'ednorxmed.com',
        'educatemetv.com',
        'education-cz.ru',
        'educontest.net',
        'edudocs.net',
        'eduinfosite.com',
        'eduserver.net',
        'edwinkonijn.com.au',
        'ee77ee.com',
        'efkt.jp',
        'efnor-ac.com',
        'ege-russian.ru',
        'egovaleo.it',
        'egvar.net',
        'ekaterinburg.xrus.org',
        'ekn-art.se',
        'ekobata.ru',
        'ekosmetyki.net.pl',
        'ekspertmed.com',
        'ekspresihati.info',
        'ekto.ee',
        'el-nation.com',
        'eladkarako.com',
        'eladkarako.github.io',
        'eldiariodeguadalajara.com',
        'election.interferencer.ru',
        'electricwheelchairsarea.com',
        'electrik-avenue.com',
        'electro-prom.com',
        'electronicadirect.com',
        'elektir.ru',
        'elektrischezi.canalblog.com',
        'elektrischeziga.livejournal.com',
        'elektrischezigarette1.blog.pl',
        'elektrischezigarette1.onsugar.com',
        'elektrischezigarette2.devhub.com',
        'elektrischezigarette2.onsugar.com',
        'elektrischezigarettekaufen2.cowblog.fr',
        'elektrischezigaretten1.blogse.nl',
        'elektrischezigaretten2.beeplog.com',
        'elektroniksigaraankara.info',
        'elektronischezi.livejournal.com',
        'elektronischezigarette2.mex.tl',
        'elektronischezigarettekaufen1.beeplog.com',
        'elektronischezigarettekaufen1.myblog.de',
        'elektronischezigarettekaufen2.tumblr.com',
        'elektrozigarette1.dreamwidth.org',
        'elektrozigarette2.webs.com',
        'elektrozigarette2.wordpressy.pl',
        'elektrozigarettekaufen1.devhub.com',
        'elektrozigarettekaufen2.blogse.nl',
        'elektrozigaretten1.postbit.com',
        'elektrozigaretten1.tumblr.com',
        'elektrozigaretten1.webs.com',
        'elektrozigaretten2.yn.lt',
        'elidelcream.weebly.com',
        'elite-sex-finders.com',
        'elitedollars.com',
        'elitepcgames.com',
        'elitesportsadvisor.com',
        'elkacentr.ru',
        'elmacho.xyz',
        'elmifarhangi.com',
        'eloconcream.blogspot.com',
        'eloxal.ru',
        'elstal.com.pl',
        'eluxer.net',
        'elvel.com.ua',
        'elvenar.com',
        'elvenmachine.com',
        'emailaccountlogin.co',
        'embedle.com',
        'emediate.eu',
        'emergencyneeds.org',
        'emerson-rus.ru',
        'empathica.com',
        'empirepoker.com',
        'empis.magix.net',
        'en.altezza.travel',
        'en.home-task.com',
        'enbersoft.com',
        'encodable.com',
        'energy-ua.com',
        'energydiet-info.ru',
        'energydiet24.ru',
        'eng-lyrics.com',
        'enge-fotzen.info',
        'enginebay.ru',
        'engines-usa.com',
        'englate.com',
        'englishdictionaryfree.com',
        'englishgamer.com',
        'enhand.se',
        'enskedesquashclub.se',
        'enternet.ee',
        'enthuse.computernetworksonline.com',
        'envaseslotusama.com',
        'eonpal.com',
        'eorogo.top',
        'epicbrogaming.com',
        'epngo.bz',
        'eralph.tk',
        'erectile.bid',
        'eredijovon.com',
        'ereko.ru',
        'ero-advertising.com',
        'eropornosex.ru',
        'erot.co',
        'erotik-kostenlos.net',
        'erotik0049.com',
        'erotikchat-24.com',
        'erotikstories.ru',
        'erotiktreff24.info',
        'erotische-geschichten-xxl.com',
        'errorfixing.space',
        'ertelecom.ru',
        'es5.com',
        'escort-russian.com',
        'escortplius.com',
        'escortslet.net',
        'esfchat.tk',
        'eshop.md',
        'eshop4u.jp',
        'esnm.ru',
        'esopini.com',
        'espaceinventoristes.com',
        'essay-edu.biz',
        'essay-writing.work',
        'essayassist.com',
        'essaypro.com',
        'essayservicewriting.org',
        'este-line.com.ua',
        'estelight.ru',
        'estibot.com',
        'etm-consult.de',
        'etotupo.ru',
        'etur.ru',
        'eu-cookie-law.blogspot.com',
        'eu-cookie-law.info',
        'eugenevaultstorage.com',
        'eupornstar.info',
        'euromasterclass.ru',
        'euronis-free.com',
        'europages.com.ru',
        'european-torches.ru',
        'europeanwatches.ru',
        'eurosamodelki.ru',
        'euroskat.ru',
        'evaashop.ru',
        'evehemming.blogspot.com.au',
        'evening-dating-club.info',
        'event-tracking.com',
        'everflora.ru',
        'everypony.ru',
        'everytalk.tv',
        'evidencecleanergold.com',
        'evogarage.com',
        'evrotekhservis.ru',
        'ewebarticle.info',
        'excaliburfilms.com',
        'exchangeit.gq',
        'exchanges-bet.com',
        'excitacao.com',
        'excitacion.info',
        'exct.net',
        'exdocsfiles.com',
        'executehosting.com',
        'exhibitionplus.eu',
        'exmasters.com',
        'exoclick.com',
        'exoneration-project.us',
        'exonline.info',
        'expdom.com',
        'expertblog.info',
        'expertnaya-ocenka.ru',
        'exportshop.us',
        'expresstoplivo.ru',
        'extads.net',
        'extener.org',
        'extlabs.io',
        'extlinks.com',
        'extrabot.com',
        'extractorandburner.com',
        'extremal-blog.com',
        'extremepornos.net',
        'extremez.net',
        'extstat.com',
        'eyelike.com.ua',
        'eyemagination.com',
        'eyes-on-you.ga',
        'eyessurgery.ru',
        'eywords-monitoring-your-success.com',
        'ez8motelseaworldsandiego.com',
        'ezb.elvenmachine.com',
        'ezigarettekaufen.myblog.de',
        'ezigarettekaufen1.hpage.com',
        'ezigarettekaufen2.blox.pl',
        'ezigarettekaufen2.mpbloggar.se',
        'ezigarettekaufen2.yolasite.com',
        'ezigarettenkaufen1.deviantart.com',
        'ezigarettenkaufen1.pagina.gr',
        'ezigarettenkaufen2.dreamwidth.org',
        'ezigarettenshop1.yolasite.com',
        'ezigarettenshop2.myblog.de',
        'ezigarettenshop2.postbit.com',
        'ezigaretteshop.webs.com',
        'ezigaretteshop2.mywapblog.com',
        'ezigaretteshop2.vefblog.net',
        'ezofest.sk',
        'ezrvrentals.com',
        'f-loaded.de',
        'f-online.de',
        'f00kclan.de',
        'f012.de',
        'f07.de',
        'f0815.de',
        'f1nder.org',
        'f5mtrack.com',
        'fable.in.ua',
        'face.hostingx.eu',
        'facebook-mobile.xyz',
        'facecup.top',
        'factorynightclub.com',
        'failingmarriege.blogspot.com',
        'fakehandbags.xyz',
        'falcoware.com',
        'falllow.gq',
        'familienzahnaerzte.com',
        'family1st.ca',
        'familyholiday.ml',
        'familyphysician.ru',
        'famix.xyz',
        'fandlr.com',
        'fanoboi.com',
        'fanpagerobot.com',
        'fantasticpixcool.com',
        'faptitans.com',
        'faracontrol.ir',
        'farm26.ru',
        'farmingworm.com',
        'farmprofi.net',
        'fashion-mk.net',
        'fashion-stickers.ru',
        'fashionavenuegame.com',
        'fashionindeed.ml',
        'fast-wordpress-start.com',
        'fastcrawl.com',
        'fastfixing.tech',
        'fatfasts-4tmz.com',
        'fatmaelgarny.com',
        'favorcosmetics.com',
        'favoritemoney.ru',
        'favornews.com',
        'faz99.com',
        'fba-mexico.com',
        'fbdownloader.com',
        'fdzone.org',
        'fealq.com',
        'fearcrow.com',
        'feargames.ru',
        'feel-planet.com',
        'feeriaclub.ru',
        'fefo.gdn',
        'fellowshipoftheminds.com',
        'femdom.twiclub.in',
        'femmesdenudees.com',
        'fenoyl.batcave.net',
        'feorina.ru',
        'ferieboligkbh.dk',
        'fermersovet.ru',
        'ferretsoft.com',
        'ferrotodo.com',
        'fertilitetsradgivningen.se',
        'fetishinside.com',
        'fetroshok.ru',
        'fettefrauen.net',
        'ff30236ddef1465f88547e760973d70a.com',
        'fickblock18.com',
        'fickenbumsen.net',
        'fickenprivat.info',
        'fickkontakte.org',
        'fickkontaktehobbyhuren.com',
        'fickluder69.com',
        'fidelityfunding.com',
        'fifa-coins.online',
        'figuringmoneyout.com',
        'fikasound.tk',
        'fil.ru',
        'filefilter.weebly.com',
        'filerockstar298.weebly.com',
        'filesclub.net',
        'filesdatabase.net',
        'filesmonster.porn',
        'filesvine.com',
        'filkhbr.com',
        'fillmewithhappiness.com',
        'film-one.ru',
        'filmbokep69.com',
        'filmetricsasia.com',
        'filmfanatic.com',
        'filmgo.ru',
        'filmidivx.com',
        'filunika.com.ru',
        'financehint.eu',
        'financeloan.us',
        'financepoints.eu',
        'financetip.eu',
        'find1friend.com',
        'findacheaplawyers.com',
        'findanysex.com',
        'findclan.org',
        'findpik.com',
        'findsexguide.com',
        'findthe.pet',
        'finejewelryshop.ru',
        'finemanteam.com',
        'finstroy.net',
        'finteks.ru',
        'finuse.com',
        'fireads.men',
        'firesub.pl',
        'firma-legion.ru',
        'firstdrugmall.ru',
        'firstsiteguide.com',
        'fishingwholesale.us',
        'fishtauto.ru',
        'fitfloponline.store',
        'fitness-video.net',
        'fitnesspiks.com',
        'fiuxy.com',
        'fivedwld.cf',
        'fiverr.com',
        'fix-website-errors.com',
        'flagcounter.me',
        'flash4fun.com',
        'flashahead.info',
        'flashbannernow.com',
        'flashlarevista.com',
        'flavors.me',
        'flex4launch.ru',
        'flipper.top',
        'flirt4free.com',
        'floating-share-buttons.com',
        'flooringinstallation-edmonton.com',
        'florida-tourism.net',
        'floridahuntingfishingadventures.com',
        'floridamhca.org',
        'floridamobilebillboards.com',
        'flowersbazar.com',
        'flowwwers.com',
        'flprog.com',
        'flytourisme.org',
        'fm-upgrade.ru',
        'focalink.com',
        'fodelsedagspresenter.nu',
        'fok.nl',
        'folowsite.com',
        'food.dtu.dk',
        'foodcrafts.website',
        'footbalive.org',
        'footballfarrago.com',
        'fordsonmajbor.cf',
        'forensicpsychiatry.ru',
        'forex-indextop20.ru',
        'forex-procto.ru',
        'forex.osobye.ru',
        'forex21.ru',
        'forexgb.ru',
        'forexunion.net',
        'forminecrafters.ru',
        'forms-mtm.ru',
        'formseo.com',
        'formulaantiuban.com',
        'formularz-konkurs.tk',
        'forodvd.com',
        'forpackningsutveckling.se',
        'forpostlock.ru',
        'forsex.info',
        'fortevidyoze.net',
        'fortunejack.com',
        'fortwosmartcar.pw',
        'forum-engineering.ru',
        'forum.doctissimo.fr',
        'forum.poker4life.ru',
        'forum.tvmir.org',
        'forum20.smailik.org',
        'forum69.info',
        'forumprofi.de',
        'forums.d2jsp.org',
        'forums.toucharcade.com',
        'foto-basa.com',
        'foto-sisek.porngalleries.top',
        'foto-telok.net',
        'foto-weinberger.at',
        'fotopop.club',
        'fototravel.eu',
        'fotoxxxru.com',
        'fotzen-ficken.com',
        'foxinsocks.ru',
        'foxtechfpv.com',
        'foxweber.com',
        'foxydeal.com',
        'fr-bearings.ru',
        'fr.netlog.com',
        'franecki.net',
        'franklinfire.co',
        'frbizlist.com',
        'frcls.fr',
        'freakycheats.com',
        'free-deals.faith',
        'free-fb-traffic.com',
        'free-fbook-traffic.com',
        'free-floating-buttons.com',
        'free-gluten.ru',
        'free-laptop-reward.com',
        'free-share-buttons.blogspot.com',
        'free-share-buttons.com',
        'free-share-buttons.top',
        'free-social-buttons.com',
        'free-social-buttons.xyz',
        'free-stock-illustration.com',
        'free-today.com',
        'free-traffic.xyz',
        'free-video-tool.com',
        'free411games.com',
        'freecamdollars.com',
        'freegamesplay.online',
        'freejabs.com',
        'freelifetimefuckbook.com',
        'freelinkbuilding.website.tk',
        'freelotto.com',
        'freemags.cc',
        'freemaintenancesysforpcandmac.top',
        'freenode.info',
        'freenom.link',
        'freeseedsonline.com',
        'freesitetest.com',
        'freetangodownload.com',
        'freeuploader.com',
        'freeuploader.ml',
        'freewareseek.com',
        'freewebs.com',
        'freewhatsappload.com',
        'freewlan.info',
        'frequiry.com',
        'freshberry.com.ua',
        'freshdz.com',
        'freshmac.space',
        'freshsuperbloop.com',
        'freshwallpapers.info',
        'freza-sverlo.ru',
        'frighteningremain.cf',
        'frivgame250.com',
        'froggytube.com',
        'front.ru',
        'front.to',
        'frustrated-favorable.gq',
        'frvo.alptandem.ru',
        'fsakhalin.ru',
        'fsalas.com',
        'ftns.ru',
        'fuck-paid-share-buttons.xyz',
        'fuckingawesome.com',
        'fuckmill.com',
        'fuel-gas.com',
        'fugarif.ga',
        'fullfileaccess.com',
        'fullgirl.ru',
        'fun-mobi.pl',
        'fun2cell.net',
        'funcrushgames.com',
        'fungamelands.com',
        'fungirlsgames.net',
        'funnel.co.za',
        'funnymama.com',
        'funnypica.com',
        'funponsel.com',
        'funtoonez.com',
        'fusoradio.info',
        'futbolkisales.ru',
        'fx-brokers-review.com',
        'fxgallery.com',
        'fxtips.ru',
        'fyl.com.ru',
        'fym.com.ru',
        'fyxabomiw.ru',
        'fz139.ttk.ru',
        'g.starmoe.xyz',
        'g33.org',
        'g7m.pl',
        'gabeshop.ru',
        'gael-s.ru',
        'gagrasector.ru',
        'galaxy-family.ru',
        'galaxyflowers.ru',
        'galaxys6manual.info',
        'galeon.com',
        'gallerily.com',
        'gallery.rennlist.com',
        'galleryawesome.com',
        'gallerylisting.com',
        'gallictures.com',
        'gambarkatabaru.com',
        'gambarkataku.co',
        'gambarxkata.co',
        'gamblingnerd.com',
        'game-mmorpg.net',
        'game-top.su',
        'game300.ru',
        'gamebackyard.com',
        'gamedayassist.com',
        'gamedayhouse.com',
        'gameonasia.com',
        'gameplexcity.com',
        'gameprimary.com',
        'gamerextra.com',
        'gamerscorps.com',
        'games.kolossale.ru',
        'gamesprite.me',
        'gamevalue7.weebly.com',
        'gamewrath.com',
        'gamezblox.com',
        'gaming-journal.com',
        'gamingspark.com',
        'garciniaxt.us',
        'gardene.ru',
        'gate5.co.za',
        'gateway.zscalerone.net',
        'gateway.zscalertwo.net',
        'gavuer.ru',
        'gay-file.com',
        'gay.adultgalls.com',
        'gaygalls.net',
        'gaytube.com',
        'gayxperience.com',
        'gaz-voshod.ru',
        'gazobeton-p.com.ua',
        'gazoblok.net.ua',
        'gazporno.com',
        'gcup.ru',
        'gdcentre.ru',
        'gdebestkupit.ru',
        'ge0ip.com',
        'ge0ip.net',
        'ge0ip.org',
        'gearcraft.us',
        'gearsadspromo.club',
        'geckoandfly.com',
        'geile-lelly.eu',
        'geilehausfrauen.net',
        'geileweiber.tk',
        'gelezki.com',
        'gemara.com',
        'gembird.com',
        'gemgrab-a.akamaihd.net',
        'generalporn.org',
        'generic-pills-online.com',
        'genericlowlatencyasiodriverhq.aircus.com',
        'genericviagrasildenafiled.net',
        'generousdeal-a.akamaihd.net',
        'genetworx.com',
        'gentamicineyedrops.blogspot.com',
        'geoads.com',
        'germes-trans.com',
        'germetiki.com.ua',
        'get-free-social-traffic.com',
        'get-free-traffic-now.com',
        'get-seo-domain.com',
        'get-your-social-buttons.info',
        'getaclueamerica.com',
        'getdot.ru',
        'getlaid-xxxhookupdirect.com',
        'getlamborghini.ga',
        'getmiro.com',
        'getmyads24.com',
        'getoutofdebtfree.org',
        'getpopunder.com',
        'getprismatic.com',
        'getresponse.com',
        'getridofstretchmarks.org',
        'gettpromos.com',
        'gfaq.ru',
        'gg-arena.ru',
        'gg.zzyjxs.com',
        'ggiaro.com',
        'ghazel.ru',
        'ghernnqr.skyrock.com',
        'gheus.altervista.org',
        'ghostvisitor.com',
        'gifspics.com',
        'gigablast.com',
        'gigapeta.com',
        'gilbertbanda.net',
        'gilsonchiro.xyz',
        'girlgamerdaily.com',
        'girlporn.ru',
        'girls-ufa.ru',
        'girlsatgames.ru',
        'girlsfuckdick.com',
        'girlspicsa.com',
        'given2.com',
        'gk-atlant.info',
        'gk170.ru',
        'gktt.ru',
        'gkvector.ru',
        'glall.ru',
        'glasof.es',
        'glass-msk.ru',
        'glastecfilms.com.my',
        'glavprofit.ru',
        'glavtral.ru',
        'glcomputers.ru',
        'glicol.kz',
        'global-ics.co.za',
        'globalscam.ga',
        'globalsurfari.com',
        'globatur.ru',
        'globetrotting-culture.ru',
        'glogow.pl',
        'glopages.ru',
        'gloverid.site',
        'gne8.com',
        'gnuetella.com',
        'go2album.com',
        'go2jump.org',
        'go2mike.ru',
        'goatse.ru',
        'gobongo.info',
        'goforexvps.com',
        'gogalleryawesome.com',
        'gogps.me',
        'gojiberriess.apishops.ru',
        'gok-kasten.net',
        'golaya.pw',
        'goldadpremium.com',
        'goldandcard.ru',
        'golden-catalog.pro',
        'golden-praga.ru',
        'goldenggames.com',
        'goldpanningtools.com',
        'golfresa.lucania.se',
        'golmau.host.sk',
        'gomusix.com',
        'gonextmedia.com',
        'goo.ne.jp',
        'good-mummy.ru',
        'goodhousekeeping.com',
        'goodhumor24.com',
        'goodnightjournal.com',
        'goodprotein.ru',
        'goodwriterssales.com',
        'googglet.com',
        'google-liar.ru',
        'googlefeud.com',
        'googlemare.com',
        'googlepositions.com',
        'googleweblight.com',
        'googlsucks.com',
        'googst2.ru',
        'goosefishpost.bid',
        'gopixdatabase.com',
        'gopro-online.info',
        'gorabagrata.ru',
        'goroda-vsego-mira.ru',
        'gorodservis.ru',
        'gosarhivrt.ru',
        'gosmeb.ru',
        'gosreg.amchs.ru',
        'gotcher.us',
        'gotomontenegro.net',
        'gotorussia.com',
        'gotwebsite1.com',
        'gourcy.altervista.org',
        'gov.yanao.ru',
        'gowreckdiving.com',
        'gox.com.ua',
        'gpirate.com',
        'gpms.org.my',
        'gq-catalog.gq',
        'grand-chlen.ru',
        'graphics8.info',
        'graphicwe.org',
        'graphid.com',
        'gratis-sexkontakte.com',
        'gratuitbaise.com',
        'greatfind-a.akamaihd.net',
        'greatgrace.ru',
        'greatzip.com',
        'green-tea.tv',
        'greendream.com.ua',
        'greenzaim.ru',
        'gribkovye-zabolevaniya.com',
        'gribokstop.com',
        'grizzlysgrill.com',
        'groupmoney.ru',
        'growboxbl.ru',
        'growmyfunds.ca',
        'growshop.es',
        'grtyi.com',
        'grupografico-pilar.com.ar',
        'gsasearchengineranker.pw',
        'gsasearchengineranker.site',
        'gsasearchengineranker.space',
        'gsasearchengineranker.top',
        'gsasearchengineranker.xyz',
        'gsasearchenginerankerdiscount.com',
        'gsbs.com.ua',
        'gsmlab.pl',
        'gsmtlf.ru',
        'gsou.cf',
        'gstatey.net',
        'gta-club.ru',
        'gta-top.ru',
        'gtopstats.com',
        'guardlink.com',
        'guardlink.org',
        'guge.io',
        'guiadeserraazul.com',
        'guigyverpo.cf',
        'guildebzh.info',
        'guitar-master.org',
        'gungamesz.com',
        'guod.me',
        'guruofcasino.com',
        'gwagka.com',
        'gwebtools.com',
        'gwebtools.com.br',
        'gwhwpxbw.bloger.index.hr',
        'gyffu.com',
        'gz2.bbsoldes.fr',
        'h2monline.com',
        'habermetre.com',
        'hacktougroup.ru',
        'hahashka.ru',
        'haikuware.com',
        'hamacapty.com',
        'hamilton.ca',
        'hamptonoaks.ca',
        'handicapbathtubarea.com',
        'handicapvansarea.com',
        'handicapvantoday.com',
        'handsandlegs.ru',
        'hanink.biz.ly',
        'hannasolution.ru',
        'hao123.com',
        'happy.new.yeartwit.com',
        'hasfun.com',
        'hatdc.org',
        'hatedriveapart.com',
        'hauleddes.com',
        'hausfrauensex18.com',
        'haveinc.xyz',
        'havepussy.com',
        'hawaiielectriclight.com',
        'hawaiisurf.com',
        'hayate.biz',
        'hazardky.net',
        'hcate.com',
        'hccoder.info',
        'hchha.com',
        'hd-film.pl',
        'hd-filmy.net',
        'hd720kino.ru',
        'hdapp1008-a.akamaihd.net',
        'hdfreeporno.net',
        'hdimagegallery.net',
        'hdimagelib.com',
        'hdpixent.com',
        'hdpixion.com',
        'hdseriale.pl',
        'hdwallpapers-free.com',
        'hdwalls.xyz',
        'hdxnxxtube.mobi',
        'headpharmacy.com',
        'headpress.ru',
        'healbio.ru',
        'healgastro.com',
        'healing-dysplasia.ru',
        'healmytrauma.info',
        'health-medical-portal.info',
        'healthcarestore.info',
        'heartofbeijing.blogspot.com',
        'heatpower.ru',
        'hebr.myddns-flir.com',
        'helicalpile.us',
        'heliko.no',
        'help.tpu.ru',
        'helpmymacfaster.trade',
        'helvetia.com.ua',
        'hem.passagen.se',
        'hentai-manga.porn',
        'hentaiheroes.com',
        'herehloadibs.cf',
        'hermesbelts.xyz',
        'hermesbirkinhandbagoutlets.com',
        'hermesbracelets.xyz',
        'hermesreplica.pw',
        'hermesreplica.win',
        'herokuapp.com',
        'heroz.fr',
        'hesteel.pl',
        'hetmanship.xyz',
        'hexpilot.com',
        'heygidday.biz',
        'hidefiles.org',
        'hidemyass.com',
        'hifidesign.ru',
        'high-speed1.net',
        'highland-homes.com',
        'highspeed5.net',
        'highstairs-a.akamaihd.net',
        'hikesearch.net',
        'hildinghr.se',
        'histats.com',
        'histock.info',
        'historichometeam.com',
        'hit-men.men',
        'hitcpm.com',
        'hitsbox.info',
        'hiwibyh.bugs3.com',
        'hjaoopoa.top',
        'hkdiiohi.skyrock.com',
        'hkladys.com',
        'hledejvshopech.cz',
        'hmmm.cz',
        'hmywwogw.bloger.index.hr',
        'hobbyhuren-datenbank.com',
        'hobbyhuren24.net',
        'hobild.net',
        'hoholikik.club',
        'hol.es',
        'holidaypics.org',
        'hollywoodactress.info',
        'home-task.com',
        'home.myplaycity.com',
        'homeandhealth.ru',
        'homeart.space',
        'homedecoguide.info',
        'homedecorpicture.us',
        'homedo.fabpage.com',
        'homegardenlova.com',
        'homeinns.com',
        'homelygarden.com',
        'homemade.gq',
        'homemature.net',
        'honyaku.yahoofs.jp',
        'hop.clickbank.net',
        'hopeonthestreet.co.uk',
        'hoporno.com',
        'hornymatches.com',
        'horoshieokna.com',
        'host-protection.com',
        'host-tracker.com',
        'hostcritique.com',
        'hoste.octopis.com',
        'hosting-tracker.com',
        'hostingclub.lk',
        'hostnow.men',
        'hostsshop.ru',
        'hotblog.top',
        'hotchatdate.com',
        'hotdl.in',
        'hotel-mkad.ru',
        'hotelcrocenzi.sm',
        'hotenergy.ru',
        'hotgirlhdwallpaper.com',
        'hothor.se',
        'hotkeys.com',
        'hotloans.ru',
        'hotshoppymac.com',
        'hotsocialz.com',
        'hotxnights.info',
        'houdom.net',
        'house.sieraddns.com',
        'housediz.com',
        'housekuba.org',
        'housemilan.ru',
        'houseofgaga.ru',
        'houseofrose.com',
        'houston-vikings.com',
        'hoverboard360.at',
        'hoverboard360.de',
        'hoverboard360.es',
        'hoverboard360.nl',
        'hoverboard360.se',
        'hoverboardforsaledirect.com',
        'howlongdoestizanidinestayinyoursystem.blogspot.com',
        'howmuchdoestizanidinecost.blogspot.com',
        'howopen.ru',
        'howtoclean.club',
        'howtowhitenteethfast.xyz',
        'hoztorg-opt.ru',
        'hplaserjetpdriver8y.pen.io',
        'hptwaakw.blog.fc2.com',
        'hreade.com',
        'hscsscotland.com',
        'hspline.com',
        'htmlcorner.com',
        'https-legalrc.biz',
        'hubbble.com',
        'huhn.altervista.org',
        'huimin764128.com',
        'hulfingtonpost.com',
        'hully.altervista.org',
        'humanelydrew.com',
        'humanorightswatch.org',
        'hundejo.com',
        'hunterboots.online',
        'hunthillfarmtrust.org',
        'husky-shop.cz',
        'hustoon.over-blog.com',
        'hut1.ru',
        'hvd-store.com',
        'hybrid.ru',
        'hydropump.su',
        'hyhj.info',
        'hyiphunter.org',
        'hyipmanager.in',
        'hystersister.com',
        'i-hobot.ru',
        'i-midias.net.br',
        'i-service.kz',
        'i4track.net',
        'iamsport.org',
        'ibb.com.ua',
        'iboss.com',
        'icaseclub.ru',
        'iccornacircri.cf',
        'ico.re',
        'ictizanidinehcl4mg.blogspot.com',
        'id-forex.com',
        'idc.com.ua',
        'idealtits.net',
        'ideashome.id',
        'ideawheel.com',
        'idegenvezeto.eu',
        'ideibiznesa2015.ru',
        'ideoworld.org',
        'ido3.com',
        'ie.57883.net',
        'ifirestarter.ru',
        'iflycapetown.co.za',
        'ifmo.ru',
        'igadgetsworld.com',
        'igithab.com',
        'igrovyeavtomaty777.ru',
        'igru-xbox.net',
        'iinstalll-fii1leis.jus0wil.pp.ua',
        'ikearugs.xyz',
        'iklysha.ml',
        'ikritikimou.gr',
        'ilbe.club',
        'ilikevitaly.com',
        'ilmen.net',
        'ilmexico.com',
        'iloveitaly.ru',
        'ilovevitaly.com',
        'ilovevitaly.ru',
        'ilovevitaly.xyz',
        'ilte.info',
        'imabase.com',
        'imadedinner.net',
        'imagecoolpub.com',
        'imagefinder.site',
        'imagerydatabase.com',
        'images-free.net',
        'images-graphics-pics.com',
        'images.gyffu.com',
        'imediadesk.com',
        'imfamous.info',
        'img.wallpaperstock.net',
        'imgarcade.com',
        'imgata.com',
        'imicrovision.com',
        'iminent.com',
        'imitex-plus.ru',
        'imk.com.ua',
        'immobiliaremassaro.com',
        'imperia31.ru',
        'imperiafilm.ru',
        'impisr.edunsk.ru',
        'impisr.ru',
        'import-sales.com',
        'importchinacoach-teach.com',
        'impresagaia.it',
        'inbabes.sexushost.com',
        'inboundlinks.win',
        'inboxdollars.com',
        'inclk.com',
        'incolors.club',
        'incomekey.net',
        'increasewwwtraffic.info',
        'indetiske.ya.ru',
        'indiakino.net',
        'indianmedicaltourismshop.com',
        'indiasourcemart.in',
        'indo-export.ru',
        'inet-traffic.com',
        'infazavr.ru',
        'infobabki.ru',
        'infodocsportal.com',
        'infokonkurs.ru',
        'informatiecentro.be',
        'infospot.pt',
        'infostatsvc.com',
        'infowarcraft.ru',
        'inmate-locator.us',
        'innodgfdriverhm.aircus.com',
        'inome.com.ua',
        'insider.pro',
        'insomniagamingfestival.com',
        'insta-add.pro',
        'instabid.tech',
        'insurple.com',
        'int.search.mywebsearch.com',
        'int.search.tb.ask.com',
        'integritylandscapeservices.com',
        'intelhdgraphicsgtdrive6w.metroblog.com',
        'intellekt21.ru',
        'intellektmedia.at',
        'interesnie-faktu.ru',
        'interferencer.ru',
        'interfucks.net',
        'interior-stickers.ru',
        'intermesh.net',
        'internet-apteka.ru',
        'internetartfair.com',
        'internetproviderstucson.com',
        'intervsem.ru',
        'intim-uslugi.info',
        'intimshop-fantasy.ru',
        'invest-pamm.ru',
        'investingclub.ru',
        'investmac.com',
        'investpamm.ru',
        'investsuccess.org',
        'investyb.com',
        'investzalog.ru',
        'invitefashion.com',
        'invivo.hu',
        'inzn.ru',
        'io9.com',
        'iomoio.net',
        'iopeninghours.co.uk',
        'ip-guide.com',
        'ipchicken.com',
        'iphantom.com',
        'iplogger.org',
        'iplusbit.blogspot.co.za',
        'ipostroika.ru',
        'iptool.xyz',
        'iqbazar.ru',
        'iqoption-bin.com',
        'iqoption.com',
        'iqoption.pro',
        'iqs.biz.ua',
        'iqupdatetmz.win',
        'iradiology.ru',
        'irkutsk.online-podarki.com',
        'irkutsk.zrus.org',
        'irunfar.com',
        'iscblog.info',
        'isistaylorporn.info',
        'iskalko.ru',
        'islamtoday.co.za',
        'islandminingsupply.wordpress.com',
        'isotoner.com',
        'isoveti.ru',
        'ispaniya-costa-blanca.ru',
        'istanbulit.com',
        'istizanidineacontrolledsubstance.blogspot.com',
        'istizanidineanarcoticdrug.blogspot.com',
        'istizanidineanopiate.blogspot.com',
        'istizanidinelikexanax.blogspot.com',
        'istmira.ru',
        'istock-mebel.ru',
        'istripper.com',
        'it-max.com.ua',
        'itbc.kiev.ua',
        'itch.io',
        'itis4you.com',
        'itrevolution.cf',
        'itronics.ca',
        'itsdp3.com',
        'itservicesthatworkforyou.com',
        'iusstf.org',
        'ivanovo.zrus.org',
        'ivanstroi.ru',
        'ivearchenceinflu.cf',
        'ivoiretechnocom.ci',
        'iwantedmoney.com',
        'iwantmyfreecash.com',
        'iwanttodeliver.com',
        'iweblist.info',
        'ix20.ru',
        'iyasimasennka.com',
        'izhevsk.xrus.org',
        'izhevsk.zrus.org',
        'izismile.com',
        'izoll.ru',
        'j-times.ru',
        'j33x.com',
        'jacago.com',
        'jackwolfskinoutlet.online',
        'jamiembrown.com',
        'janavibekken.no',
        'janerikholst.se',
        'janettabridal.com',
        'japan-bearings.ru',
        'japfm.com',
        'jasonpartington.com',
        'javatex.co.id',
        'javitas.info',
        'javrip.net',
        'jaxcube.info',
        'jbl-charge.info',
        'je7.us',
        'jennyfire.ru',
        'jerseychinabizwholesale.com',
        'jerseychinabizwholesale.us',
        'jerseysbizwholesalecheap.com',
        'jerseyschinabizwholesale.us',
        'jerseyssportsshop.com',
        'jerseyswholesalechinalimited.com',
        'jerseywholesalebizchina.com',
        'jerseywholesalechinabiz.com',
        'jerseywholesaleelitestore.com',
        'jestr.org',
        'jetsli.de',
        'jewelryandfiligree.com',
        'jikoman.info',
        'jillepille.com',
        'jimmychoosale.online',
        'jjbabskoe.ru',
        'jmat.cn',
        'job.icivil.ir',
        'jobmarket.com.ua',
        'joessmogtestonly.com',
        'johannesburgsingles.co.za',
        'johnrobertsoninc.com',
        'joingames.org',
        'jolic2.com',
        'jongose.ninja',
        'journalhome.com',
        'journeydownthescale.info',
        'jpcycles.com',
        'jrcigars.com',
        'jrpmakati.com',
        'juliadiets.com',
        'juliaworld.net',
        'jumptap.com',
        'junglenet-a.akamaihd.net',
        'jurajskie.info',
        'jus0wil.pp.ua',
        'justbcause.com',
        'justdating.online',
        'justkillingti.me',
        'justprofit.xyz',
        'justucalling32211123456789.tk',
        'jwss.cc',
        'kaac.ru',
        'kabbalah-red-bracelets.com',
        'kadashihotel.com',
        'kaidalibor.de',
        'kalandranis.gr',
        'kalb.ru',
        'kaliningrad.zrus.org',
        'kam-dom.ru',
        'kamagragelusa.net',
        'kamalsinha.com',
        'kambasoft.com',
        'kamen-e.ru',
        'kamorel.com',
        'kandidos.com',
        'kanimage.com',
        'karachev-city.ru',
        'karadene.com',
        'karaganda.xkaz.org',
        'kareliatobacco.ru',
        'karpun-iris.ru',
        'karting196.ru',
        'kartiniresto.com',
        'karusel-market.ru',
        'kashubadesign.ru',
        'kasino-money.pw',
        'katjimej.blog.fc2.com',
        'katushka.net',
        'kaz.kz',
        'kazan.xrus.org',
        'kazan.zrus.org',
        'kazinogames.lv',
        'kazka.ru',
        'kazrent.com',
        'kchaxton.com',
        'keenoutlet.online',
        'kemerovo.zrus.org',
        'kenaba.su',
        'kerch.site',
        'kerei.ru',
        'kerwinandcariza.com',
        'ketoanhanoi.info',
        'ketrzyn.pl',
        'keyhantercume.com',
        'keyword-suggestions.com',
        'keywordblocks.com',
        'keywordhut.com',
        'keywords-monitoring-success.com',
        'keywords-monitoring-your-success.com',
        'keywordsking.com',
        'keywordsuggest.org',
        'keywordsuggests.com',
        'keywordteam.net',
        'kfon.eu',
        'khafre.us',
        'kichenaid.ru',
        'kicknights.gq',
        'kidd.reunionwatch.com',
        'kiev.ua',
        'kihi.gdn',
        'kiinomaniak.pl',
        'kimcurlrvsms.com',
        'kino-ecran.ru',
        'kino-filmi.com',
        'kino-fun.ru',
        'kino-key.info',
        'kino-rating.ru',
        'kino2018.club',
        'kinobaks.com',
        'kinobest.pl',
        'kinocccp.net',
        'kinoduh.ru',
        'kinofak.net',
        'kinoflux.net',
        'kinogolos.ru',
        'kinogonew.ru',
        'kinohall.ru',
        'kinohit1.ru',
        'kinomaniatv.pl',
        'kinoplen.ru',
        'kinopolet.net',
        'kinosed.net',
        'kinostorm.net',
        'kinotorka.ru',
        'kiprinform.com',
        'kirov.zrus.org',
        'kiskinhouse.com',
        'kit-opt.ru',
        'kiwe-analytics.com',
        'kiwi237au.tk',
        'kladrus.ru',
        'kleine-titten.biz',
        'klejonka.info',
        'kletkimehan.ru',
        'klikbonus.com',
        'kliksaya.com',
        'klin3952.ru',
        'klosetkitten.com',
        'klumba55.ru',
        'kmd-pto.ru',
        'kmgamex.cf',
        'kndxbkdx.bloger.index.hr',
        'knigonosha.net',
        'knogg.net',
        'knowsitall.info',
        'knowyournextmove.com',
        'kochanelli.com',
        'kol-energo.ru',
        'koleso24.com.ua',
        'kollekcioner.ru',
        'kollesa.ru',
        'kolotiloff.ru',
        'komp-pomosch.ru',
        'komputernaya-pomosh-moscow.ru',
        'komputers-best.ru',
        'kongoultry.net',
        'kongruan.com',
        'konkursov.net',
        'konkursowo-24.pl',
        'konoplisemena.com',
        'konpax.com',
        'konteiner24.com',
        'konturkrasoty.ru',
        'koopilka.com',
        'kopihijau.info',
        'koptims.tiu.ru',
        'koral.se',
        'koronirealestate.gr',
        'kosmetyki.tm.pl',
        'kosova.de',
        'kostenlos-sexvideos.com',
        'kostenloser-sex.com',
        'kosynka-games.ru',
        'kotaku.com',
        'kountrylife.com',
        'koversite.info',
        'kovesszucs.atw.hu',
        'kozhniebolezni.com',
        'krafte.ru',
        'kraljeva-sutjeska.com',
        'krasivoe-hd.com',
        'krasivoe-hd.net',
        'krasivye-devushki.net',
        'krasnodar-avtolombards.ru',
        'krasnodar.ru',
        'krasnodar.xrus.org',
        'krasnodar.zrus.org',
        'krassh.ru',
        'krasula.pp.ua',
        'kreativperlen.ch',
        'kredit-blog.ru',
        'kredit-pod-zalog-krasnodar.ru',
        'kriokomora.info',
        'krynica.info',
        'ks1234.com',
        'ktotut.net',
        'ku6.com',
        'kumuk.info',
        'kung-fu-ru.com',
        'kupit-adenu.ru',
        'kurbappeal.info',
        'kursy-ege.ru',
        'kurwa.win',
        'kustanay.kz',
        'kutikomi.net',
        'kuzinsp.ru',
        'kvartir-remont.biz',
        'kvartira-sutochno.com',
        'kvartiry-remont.ucoz.ru',
        'kw21.org',
        'kwzf.net',
        'la-fa.ru',
        'laapp.com',
        'labafydjxa.su',
        'labelwater.se',
        'labplus.ru',
        'labvis.host.sk',
        'lacasamorett.com',
        'lacave.ntic.fr',
        'lacloop.info',
        'ladov.ru',
        'laexotic.com',
        'lafourmiliaire.com',
        'lafriore.ru',
        'lakomka.com.ua',
        'lampokrat.ws',
        'lanadelreyfans.us',
        'lanasshop.ru',
        'lancheck.net',
        'landmania.ru',
        'landoftracking.com',
        'landreferat.ru',
        'landscaping.center',
        'languagecode.com',
        'lankarns.com',
        'laparfumotec.com',
        'lapitec.eu',
        'laptop-4-less.com',
        'laptoper.net',
        'larchik.net',
        'larger.io',
        'larose.jb2c.me',
        'larutti.ru',
        'lashstudia.ru',
        'lasvegaslockandsafe.com',
        'laudit.ru',
        'laulini.soclog.se',
        'law-check-eight.xyz',
        'law-check-nine.xyz',
        'law-check-seven.xyz',
        'law-check-two.xyz',
        'lawyers.cafe',
        'lawyersinfo.org',
        'laxdrills.com',
        'layola.biz.tc',
        'lazy-z.com',
        'lazymanyoga.com',
        'ldrtrack.com',
        'le-clos-des-alouettes.com',
        'leadn.pl',
        'leadwayau.com',
        'leboard.ru',
        'lechenie-gemorroya.com',
        'lechtaczka.net',
        'ledis.top',
        'ledpolice.ru',
        'leftofcentrist.com',
        'legalrc.biz',
        'legionalpha.com',
        'lego4x4.ru',
        'lenvred.org',
        'lernur.net',
        'lerporn.info',
        'lesbian.xyz',
        'lescinq.com',
        'letmacwork.world',
        'letmacworkfaster.site',
        'letmacworkfaster.world',
        'letolove.ru',
        'letsart.ru',
        'letslowbefast.site',
        'letslowbefast.today',
        'letsrepair.in',
        'letto.by',
        'levaquin750mg.blogspot.com',
        'lexaprogeneric.link',
        'lezbiyanki.net',
        'lflash.ru',
        'li-er.ru',
        'libertybilisim.com',
        'lida-ru.com',
        'lider-zhaluzi.kiev.ua',
        'lietaer.com',
        'life-instyle.com',
        'life.biz.ua',
        'lifebyleese.com',
        'lifehacĸer.com',
        'light.ifmo.ru',
        'lightinghomes.net',
        'lignofix.ua',
        'likesdesign.com',
        'likesuccess.com',
        'likrot.com',
        'liky.co.ua',
        'limads.men',
        'limtu.ifmo.ru',
        'lincolntheatre.com',
        'linerdrilling.com',
        'lineshops.biz',
        'link.ac',
        'linkarena.com',
        'linkbolic.com',
        'linkbuddies.com',
        'linkbux.ru',
        'linkdebrideur.xyz',
        'linkpulse.com',
        'linkredirect.biz',
        'linkrr.com',
        'linksharingt.com',
        'linkwithin.com',
        'lion.bolegapakistan.com',
        'lion.conboy.us',
        'lion.misba.us',
        'lion.playtap.us',
        'lion.snapmap.us',
        'liquimondo.com',
        'liran-locks.com',
        'lirunet.ru',
        'lisque.batcave.net',
        'littleberry.ru',
        'littlecity.ch',
        'littlesunraiser.com',
        'liupis.com',
        'live-sexcam.tk',
        'live-sexchat.ru',
        'livefixer.com',
        'liveinternet.ro',
        'liveinternet.ru',
        'livejasmin.com',
        'liver-chintai.org',
        'liverpool.gsofootball.com',
        'liveshoppersmac.com',
        'livetsomudvekslingstudent.bloggersdelight.dk',
        'liveu.infoteka.hu',
        'livingcanarias.com',
        'livingroomdecor.info',
        'lizace.com',
        'ljusihus.se',
        'lkbennettoutlet.online',
        'lkbennettstore.online',
        'llastbuy.ru',
        'lmrauction.com',
        'loadingpages.me',
        'loadopia.com',
        'lob.com.ru',
        'localflirtbuddies.com',
        'localmatchbook.com',
        'locatellicorretor.com.br',
        'locationdesaison.com',
        'lockerz.com',
        'locksmith.jp',
        'lodki-pvh.dp.ua',
        'loftdigital.eu',
        'loginduepunti.it',
        'lol-smurfs.com',
        'lollypopgaming.com',
        'lolnex.us',
        'lomb.co',
        'lombardfinder.ru',
        'lombia.co',
        'lombia.com',
        'lomza.info',
        'lonely-mature.com',
        'lonerangergames.com',
        'long-beach-air-conditioning.com',
        'longadventure.com',
        'longgreen.info',
        'lookingglassemb.com',
        'losangeles-ads.com',
        'lost-alpha.ru',
        'lostfilm-online.ru',
        'lotto6888.com',
        'lottospring.com',
        'louboutinbooties.xyz',
        'louboutinreplica.pw',
        'louboutinreplica.xyz',
        'louboutinshoes.xyz',
        'louisvuittonoutletstore.net',
        'lovasszovetseg.hu',
        'love-baby.cz',
        'lovelycraftyhome.com',
        'lovi-moment.com.ua',
        'low-format.ru',
        'lowephotos.info',
        'lsex.xyz',
        'lsp-awak-perikanan.com',
        'ltvperf.com',
        'lubetube.com',
        'luciddiagnostics.in',
        'luckyday.world',
        'luckyshop.net.ua',
        'lulea-auktionsverk.se',
        'lumb.co',
        'lutherstable.org',
        'luxmagazine.cf',
        'luxup.ru',
        'lyngdalhudterapi.no',
        'lyrics.home-task.com',
        'lyrster.com',
        'm-google.xyz',
        'm.b00kmarks.com',
        'm0r0zk0-krava.ru',
        'm1media.net',
        'm292.info',
        'm3gadownload.pl',
        'm4ever.net',
        'm5home.ru',
        'mabdoola.blogspot.com',
        'mac-shield.com',
        'macdamaged.space',
        'macdamaged.tech',
        'macfix.life',
        'machicon-akihabara.info',
        'mackeeper-center.club',
        'mackeeper-land-672695126.us-east-1.elb.amazonaws.com',
        'macnewtech.com',
        'macotool.com',
        'macresource.co.uk',
        'macrotek.ru',
        'mactechinfo.info',
        'madot.onlinewebshop.net',
        'mafa-free.com',
        'mafcards.ru',
        'magazin-pics.ru',
        'magazintiande.ru',
        'magda-gadalka.ru',
        'magento-crew.net',
        'magicalfind-a.akamaihd.net',
        'magicdiet.gq',
        'magicplayer-s.acestream.net',
        'maglid.ru',
        'magnetic-bracelets.ru',
        'magnetpress.sk',
        'mahnwachen-helfen.info',
        'mail.allnews24.in',
        'mailemedicinals.com',
        'mainlinehobby.net',
        'maju.bluesalt.co',
        'make-money-online.com',
        'makedo.ru',
        'makemoneyonline.com',
        'makis.nu',
        'maladot.com',
        'mall.uk',
        'malls.com',
        'malwareremovalcenter.com',
        'mamasuper.prom.ua',
        'managerpak204.weebly.com',
        'manifestation.betteroffers.review',
        'manipulyator-peterburg.ru',
        'mansparskats.com',
        'mantramusic.ru',
        'manualterap.roleforum.ru',
        'manuscript.su',
        'manve.info',
        'manyresultshub-a.akamaihd.net',
        'mapquestz.us',
        'maranbrinfo.com.br',
        'mararoom.ru',
        'marblestyle.ru',
        'marcogrup.com',
        'marcoislandvacations.net',
        'marcowebonyodziezowe.pl',
        'maridan.com.ua',
        'marinetraffic.com',
        'marketingtechniques.info',
        'marketingvici.com',
        'marketland.ml',
        'markjaybeefractal.com',
        'marktforschung-stuttgart.com',
        'marmitaco.cat',
        'marmotstore.online',
        'marsgatan.com',
        'martlinker.com',
        'marwer.info',
        'maslenka.kz',
        'massage-info.nl',
        'masserect.com',
        'master-muznachas.ru',
        'masterseek.com',
        'mastershef.club',
        'masthopehomes.com',
        'masturbate.co.uk',
        'matb3aa.com',
        'matchpal-a.akamaihd.net',
        'matematikus.info',
        'mathgym.com.au',
        'matrixalchemy.com',
        'matsdale.com',
        'mature.free-websites.com',
        'max-eclat.men',
        'max-p.men',
        'maximilitary.ru',
        'maximpartnerspr.com',
        'maxthon.com',
        'maxxtor.eu',
        'mazda-roadsters.com',
        'mb140.ru',
        'mbiologi.ru',
        'mcadamssupplyco.com',
        'mcar.in.ua',
        'mcnamaratech.com',
        'me-ke.com',
        'mearns-tractors.co.uk',
        'mebel-alait.ru',
        'mebel-vstroika.ru',
        'mebelcomplekt.ru',
        'mebeldekor.com.ua',
        'meble-bogart.info',
        'mecash.ru',
        'meccadumps.net',
        'med-zdorovie.com.ua',
        'medanestesia.ru',
        'meddesk.ru',
        'medi-fitt.hu',
        'mediaoffers.click',
        'mediawhirl.net',
        'medicinacom.ru',
        'medicine-4u.org',
        'medicines-choice.com',
        'medicovi.com',
        'medictube.ru',
        'medispainstitute.com.au',
        'medizinreisen.de',
        'medkletki.ru',
        'medkritika.ru',
        'medmajor.ru',
        'medosmotr-ufa.ru',
        'meds-online24.com',
        'medtherapy.ru',
        'meduza-consult.ru',
        'meendo-free-traffic.ga',
        'meetingrainstorm.bid',
        'meetlocalchicks.com',
        'mega-bony-2017.pl',
        'mega-bony2017.pl',
        'mega-polis.biz.ua',
        'megaapteka.ru',
        'megahdporno.net',
        'megaindex.ru',
        'megakino.net',
        'megavolt.net.ua',
        'meget.co.za',
        'meltwater.com',
        'member-quiz.com',
        'members.ghanaweb.com',
        'memberty.com',
        'menetie.ru',
        'menhealed.net',
        'mensandals.xyz',
        'menstennisforums.com',
        'mere.host.sk',
        'merryhouse.co.uk',
        'mesbuta.info',
        'message-warning.net',
        'mesto-x.com',
        'metabar.ru',
        'metalonly.info',
        'metarip.ru',
        'metascephe.com',
        'metaxalonevstizanidine.blogspot.com',
        'methodsmarketing.com',
        'mex-annushka.ru',
        'mexicosleevegastrectomy.com',
        'mexicotravelnet.com',
        'mezaruk.info',
        'mhi-systems.ru',
        'mhtr.be',
        'micasainvest.com',
        'michaelkorsoutlet.store',
        'michaelkorsoutletstore.net',
        'michaelkorssaleoutletonline.net',
        'microsearch.ru',
        'microsoftportal.net',
        'microstatic.pl',
        'middlerush-a.akamaihd.net',
        'midst.eu',
        'mielec.pl',
        'migente.com',
        'mikozstop.com',
        'mikrobiologies.ru',
        'mil-stak.com',
        'milblueprint.com',
        'militarysale.pro',
        'millionare.com',
        'mindbox.co.za',
        'mindeyegames.com',
        'minecraft-neo.ru',
        'minecraft-rus.org',
        'minegam.com',
        'minharevisao.com',
        'mini.7zap.com',
        'miniads.ca',
        'minneapoliscopiers.com',
        'minyetki.ru',
        'mir-betting.ru',
        'mir-business-24.ru',
        'mir-limuzinov.ru',
        'mirmedinfo.ru',
        'mirobuvi.com.ua',
        'mirtorrent.net',
        'mirzonru.net',
        'misandesign.se',
        'missclub.info',
        'missis.top',
        'missvietnam.org',
        'misswell.net',
        'mister-shop.com',
        'misterjtbarbers.com',
        'mistr-x.org',
        'mitrasound.ru',
        'mixed-wrestling.ru',
        'mixtapetorrent.com',
        'mixx.com',
        'mjchamonix.org',
        'mlf.hordo.win',
        'mlvc4zzw.space',
        'mmgq.ru',
        'mmofreegames.online',
        'mmog-play.ru',
        'mmoguider.ru',
        'mmostrike.ru',
        'mmstat.com',
        'mncrftpcs.com',
        'mnogabukaff.net',
        'mnogolok.info',
        'mobifunapp.weebly.com',
        'mobile.ok.ru',
        'mobilemedia.md',
        'mobilierland.com',
        'mobioffertrck.com',
        'mobot.site',
        'mobplayer.net',
        'mobplayer.ru',
        'mobsfun.net',
        'mobstarr.com',
        'mockupui.com',
        'modabutik.ru',
        'modenamebel.ru',
        'moesen-ficken.com',
        'moesonce.com',
        'moetomnenie.com',
        'moi-glazki.ru',
        'moivestiy.biz',
        'mojaocena.com',
        'moje-recenze.cz',
        'mojowhois.com',
        'mojpregled.com',
        'mojpreskumanie.com',
        'mokrayakiska.com',
        'mole.pluto.ro',
        'monarchfind-a.akamaihd.net',
        'monarhs.info',
        'monclerboots.xyz',
        'monclercheap.xyz',
        'monclercoats.xyz',
        'monclerjacketsoutlet.pw',
        'monclerjacketsoutlet.win',
        'moncleronline.xyz',
        'moncleroutletonline.pw',
        'moncleroutletonline.win',
        'moncleroutletonline.xyz',
        'monclervests.xyz',
        'monetizationking.net',
        'monetizer.com-01.site',
        'money-every-day.com',
        'money-for-placing-articles.com',
        'moneymaster.ru',
        'moneyteam24.com',
        'moneytop.ru',
        'moneyviking-a.akamaihd.net',
        'monitorwebsitespeed.com',
        'monsterdivx.com',
        'monsterdivx.tv',
        'montazhnic.ru',
        'monthlywinners.com',
        'montredemarque.nl',
        'moomi-daeri.com',
        'more-letom.ru',
        'morefastermac.trade',
        'morepoweronmac.trade',
        'morf.snn.gr',
        'morlat.altervista.org',
        'morocco-nomad-excursions.com',
        'moroccosurfadventures.com',
        'moscow-clining.ru',
        'moscow-region.ru',
        'moscow.online-podarki.com',
        'moscow.xrus.org',
        'mosdverka.ru',
        'moskva.nodup.ru',
        'mosrif.ru',
        'mossmesi.com',
        'most-kerch.org',
        'most.gov.iq',
        'mostantikor.ru',
        'motherboard.vice.com',
        'mototsikl.org',
        'mountainstream.ms',
        'mouselink.co',
        'moviemail-online.co.uk',
        'movies-in-theaters.net',
        'moviezbonkerssk.cf',
        'mowser.com',
        'moxo.com',
        'moyakuhnia.ru',
        'moyaterapiya.ru',
        'moz.com',
        'mp3downloadhq.com',
        'mp3films.ru',
        'mp3ringtone.info',
        'mrbitsandbytes.com',
        'mrcsa.com.au',
        'mrinsidesales.com',
        'mriyadh.com',
        'mrlmedia.net',
        'mrmoneymustache.com',
        'mrsdalloways.com',
        'mrwhite.biz',
        'msfsaar.de',
        'msk-diplomat.com',
        'msk.afora.ru',
        'mttwtrack.com',
        'mturkcontent.com',
        'muabancantho.info',
        'mug-na-chas-moscow.ru',
        'muizre.ru',
        'mulberryoutletonlineeu.com',
        'multgo.ru',
        'mundoaberrante.com',
        'muschisexbilder.com',
        'musezone.ru',
        'musezone.su',
        'musflashtv.com',
        'music.utrolive.ru',
        'music7s.me',
        'musicas.baixar-musicas-gratis.com',
        'musicdaddy.net',
        'musicktab.com',
        'musicspire.online',
        'musicstock.me',
        'musicvidz.ru',
        'musirc.com',
        'mustat.com',
        'mustwineblog.com',
        'muz-baza.net',
        'muz-shoes.ru',
        'muz-tracker.net',
        'muzaporn.com',
        'muznachas-service.ru',
        'muztops.ru',
        'mvpicton.co.uk',
        'mwtpludn.review',
        'mxgetcode.com',
        'my-bc.ru',
        'my-big-family.com',
        'my-cash-bot.co',
        'myanyone.net',
        'mybinaryoptionsrobot.com',
        'myblogregistercm.tk',
        'mycaf.it',
        'mycouponizemac.com',
        'mydeathspace.com',
        'mydirtyhobby.com',
        'mydirtystuff.com',
        'mydownloadengine.com',
        'mydownlodablefiles.com',
        'myfreecams.com',
        'myfreemp3.eu',
        'myfreetutorials.com',
        'myftpupload.com',
        'mygameplus.com',
        'mygameplus.ru',
        'myghillie.info',
        'myhealthcare.com',
        'myhitmp3.club',
        'myindospace.com',
        'myiptest.com',
        'mykings.pw',
        'mylesosibirsk.ru',
        'mylida.org',
        'myliveblog.ru',
        'mymobilemoneypages.com',
        'myonigroup.com',
        'myonlinepayday.co',
        'myperiod.club',
        'mypets.by',
        'myplaycity.com',
        'mypornfree.ru',
        'myprintscreen.com',
        'myseoconsultant.com',
        'mysexpics.ru',
        'myshopmatemac.com',
        'mystats.xyz',
        'mywallpaper.top',
        'myxdate.info',
        'myyour.eu',
        'na-telefon.biz',
        'na15.ru',
        'nac-bearings.ru',
        'nacap.ru',
        'nagdak.ru',
        'nailsimg.com',
        'naj-filmy24.pl',
        'najaden.no',
        'nakozhe.com',
        'nalogovyy-kodeks.ru',
        'nalogovyykodeks.ru',
        'namenectar.com',
        'napalm51.nut.cc',
        'naperehresti.info',
        'naphukete.ru',
        'narco24.me',
        'nardulan.com',
        'narkologiya-belgorod.ru',
        'narkologiya-orel.ru',
        'narkologiya-penza.ru',
        'narkologiya-peterburg.ru',
        'narkologiya-voronezh.ru',
        'narosty.com',
        'narutonaruto.ru',
        'nash-krym.info',
        'nastroyke.net',
        'nastydollars.com',
        'nate.com',
        'nationalbreakdown.com',
        'naturalbreakthroughsresearch.com',
        'naughtyconnect.com',
        'naval.jislaaik.com',
        'navalwiki.info',
        'nbsproject.ru',
        'needtosellmyhousefast.com',
        'negociosdasha.com',
        'negral.pluto.ro',
        'nelc.edu.eg',
        'neobux-bg.info',
        'neodownload.webcam',
        'nero-us.com',
        'nerudlogistik.ru',
        'net-profits.xyz',
        'net-radar.com',
        'netallergy.ru',
        'netanalytics.xyz',
        'netcheckcdn.xyz',
        'netfacet.net',
        'netoil.no',
        'netpics.org',
        'netvouz.com',
        'networkad.net',
        'networkcheck.xyz',
        'nevansk.ru',
        'new-apps.ru',
        'new-post.tk',
        'new7ob.com',
        'newhairstylesformen2014.com',
        'news-readers.ru',
        'newsperuse.com',
        'newstaffadsshop.club',
        'newstraveller.ru',
        'newstudio.tv',
        'newtechspb.ru',
        'newyorkhotelsmotels.info',
        'nextbackgroundcheck.gq',
        'nextconseil.com',
        'nextlnk12.com',
        'nextrent-crimea.ru',
        'nfljerseys.online',
        'nfljerseyscheapbiz.us',
        'nfljerseyscheapchinabiz.com',
        'nfljerseysforsalewholesaler.com',
        'nfvsz.com',
        'ngps1.ru',
        'nhl09.ru',
        'nhl17coins.exblog.jp',
        'nhl17coinsforps3.gratisblog.biz',
        'nibbler.silktide.com',
        'nicefloor.co.uk',
        'nicovideo.jp',
        'nightvision746.weebly.com',
        'nikhilbahl.com',
        'niki-mlt.ru',
        'nikitabuch.com',
        'nikitsyringedrivelg.pen.io',
        'nikkiewart.ru',
        'ningessaybe.me',
        'nippon-bearings.ru',
        'niroo.info',
        'njkmznnb.ru',
        'njpalletremoval.com',
        'nl.netlog.com',
        'nlfjjunb5.ru',
        'nmrk.ru',
        'no-rx.info',
        'noclegonline.info',
        'nodding-passion.tk',
        'nodup.ru',
        'nofreezingmac.click',
        'nofreezingmac.work',
        'nonews.co',
        'nootrino.com',
        'nordstar.pro',
        'nordvpn.com',
        'normalegal.ru',
        'northfacestore.online',
        'norththeface.store',
        'nosecret.com.ua',
        'notaria-desalas.com',
        'notasprensa.info',
        'notebook-pro.ru',
        'notfastfood.ru',
        'nottyu.xyz',
        'noumeda.com',
        'novatech.vn',
        'november-lax.com',
        'novgorod.xrus.org',
        'novodigs.com',
        'novosibirsk.xrus.org',
        'novosti-hi-tech.ru',
        'nowtorrents.com',
        'npoet.ru',
        'nrjmobile.fr',
        'nrv.co.za',
        'nsatc.net',
        'ntic.fr',
        'nucia.biz.ly',
        'nudepatch.net',
        'nudo.ca',
        'nufaq.com',
        'nuit-artisanale.com',
        'nuker.com',
        'nullrefer.com',
        'nuup.info',
        'nvformula.ru',
        'nvssf.com',
        'nyfinance.ml',
        'nzfilecloud.weebly.com',
        'o-dachnik.ru',
        'o-o-11-o-o.com',
        'o-o-6-o-o.com',
        'o-o-6-o-o.ru',
        'o-o-8-o-o.com',
        'o-o-8-o-o.ru',
        'o.light.d0t.ru',
        'o00.in',
        'o333o.com',
        'oakleyglassesonline.us',
        'oakridgemo.com',
        'oballergiya.ru',
        'obesidadealgarve.com',
        'obnal.org',
        'obsessionphrases.com',
        'obuv-kupit.ru',
        'ochistka-stokov.ru',
        'oconto.ru',
        'oda.as',
        'oddamzadarmo.eu',
        'odesproperty.com',
        'odoratus.net',
        'odywpjtw.bloger.index.hr',
        'oecnhs.info',
        'of-ireland.info',
        'offer.camp',
        'offer.wpsecurity.website',
        'offergroup.info',
        'offers.bycontext.com',
        'offf.info',
        'office-windows.ru',
        'office2web.com',
        'officedocuments.net',
        'offside2.5v.pl',
        'offtime.ru',
        'offtopic.biz',
        'ohmyrings.com',
        'oil-td.ru',
        'ok-ua.info',
        'ok.ru',
        'okayimage.com',
        'okel.co',
        'oklogistic.ru',
        'okmusic.jp',
        'okonich.com.ua',
        'okout.ru',
        'okroshki.ru',
        'oktube.ru',
        'okuos.com',
        'old-rock.com',
        'olgacvetmet.com',
        'olvanto.ru',
        'olympescort.com',
        'omoikiri-japan.ru',
        'omsk.xrus.org',
        'onclickpredictiv.com',
        'onclkads.com',
        'one-gear.com',
        'oneclickfiles.com',
        'onefilms.net',
        'onemactrckr.com',
        'onemantrip.com',
        'oneminutesite.it',
        'onescreen.cc',
        'oneshotdate.com',
        'onetravelguides.com',
        'onlainbesplatno.ru',
        'onlinadverts.com',
        'online-hd.pl',
        'online-hit.info',
        'online-podarki.com',
        'online-sbank.ru',
        'online-templatestore.com',
        'online-x.ru',
        'online.ktc45.ru',
        'online247.ml',
        'online7777.com',
        'onlinebay.ru',
        'onlinedomains.ru',
        'onlinefilmz.net',
        'onlineku.com',
        'onlinemeetingnow.com',
        'onlinemegax.com',
        'onlineporno.site',
        'onlineserialy.ru',
        'onlineslotmaschine.com',
        'onlinetvseries.me',
        'onlinewritingjobs17.blogspot.ru',
        'onload.pw',
        'onlyforemont.ru',
        'onlythegames.com',
        'onlywoman.org',
        'ons-add.men',
        'onstrapon.purplesphere.in',
        'ontargetseo.us',
        'ooo-gotovie.ru',
        'ooo-olni.ru',
        'ooomeru.ru',
        'oops-cinema.ru',
        'open-odyssey.org',
        'openfrost.com',
        'openfrost.net',
        'openlibrary.org',
        'openmediasoft.com',
        'openmultipleurl.com',
        'openstat.com',
        'opinionreelle.com',
        'ops.picscout.com',
        'optibuymac.com',
        'optikremont.ru',
        'optitrade24.com',
        'optom-deshevo.ru',
        'oralsexfilme.net',
        'oranga.host.sk',
        'ordernorxx.com',
        'orel-reshka.net',
        'oren-cats.ru',
        'orenburg-gsm.ru',
        'orgasmus-virtual.com',
        'orhonit.com',
        'origin-my.ru',
        'orion-code-access.net',
        'orion-v.com',
        'ororodnik.goodbb.ru',
        'orsonet.ru',
        'osagonline.ru',
        'osb.se11.ru',
        'osnova3.ru',
        'osoznanie-narkotikam.net',
        'ossmalta.com',
        'ostroike.org',
        'ostrovtaxi.ru',
        'otbelivanie-zubov.com',
        'ourtherapy.ru',
        'ourville.info',
        'outclicks.net',
        'outpersonals.com',
        'outrageousdeal-a.akamaihd.net',
        'outshop.ru',
        'ovirus.ru',
        'owathemes.com',
        'ownshop.cf',
        'ownshop.win',
        'owohho.com',
        'oxford-book.com.ua',
        'oxotl.com',
        'oynat.info',
        'oyster-green.com',
        'oz-offers.com',
        'ozas.net',
        'ozoz.it',
        'p-business.ru',
        'paceform.com',
        'pacificair.com',
        'paclitor.com',
        'page2rss.com',
        'pagesense.com',
        'paidonlinesites.com',
        'paleohub.info',
        'palocco.it',
        'palvira.com.ua',
        'pammik.ru',
        'panamaforbeginners.com',
        'panchro.co.uk',
        'panchro.xyz',
        'pandarastore.top',
        'panouri-solare-acoperis.com',
        'paparazzistudios.com.au',
        'papasdelivery.ru',
        'paperwritingservice17.blogspot.ru',
        'paphoselectricianandplumber.com',
        'par-fallen.ga',
        'paradontozanet.ru',
        'parajumpersjakkesalgnorge.info',
        'parajumpersoutlet.online',
        'parajumpersstore.online',
        'paramountmarble.co.uk',
        'parfusale.se',
        'park.above.com',
        'parlament.biz',
        'partner-cdn.men',
        'partner-high.men',
        'partner-host.men',
        'partner-pop.men',
        'partner-print.men',
        'partner-stop.men',
        'partner-trustworthy.men',
        'partnerads.men',
        'partnerline.men',
        'partners-ship.pro',
        'partnersafe.men',
        'partnerworkroom.men',
        'partybunny.ru',
        'pastaleads.com',
        'pateaswing.com',
        'pathwhelp.org',
        'patol01.pw',
        'patterntrader-en.com',
        'pattersonsweb.com',
        'pavlodar.xkaz.org',
        'pay2me.pl',
        'paydayloanslocal.com',
        'paydayonlinecom.com',
        'pb-dv.ru',
        'pc-services.ru',
        'pc-test.net',
        'pc-virus-d0l92j2.pw',
        'pc4download.co',
        'pcads.ru',
        'pcboa.se',
        'pcgroup.com.uy',
        'pcimforum.com',
        'pdamods.ru',
        'pdn-4.com',
        'pdns.cz',
        'pdns.download',
        'pearlisland.ru',
        'pechikamini.ru',
        'peekyou.com',
        'pekori.to',
        'pelfind.me',
        'pendelprognos.se',
        'penisvergrotendepillennl.ovh',
        'pensplan.com',
        'pensplan4u.com',
        'pepperstyle.ru',
        'percin.biz.ly',
        'perfection-pleasure.ru',
        'perfectpracticeweb.com',
        'perl.dp.ua',
        'perm-profnastil.ru',
        'perm.xrus.org',
        'perosan.com',
        'perso.wanadoo.es',
        'pestomou.info',
        'petedrummond.com',
        'petitions.whitehouse.gov',
        'petrovka-online.com',
        'petsblogroll.com',
        'peugeot-club.org',
        'pewit.pw',
        'pflexads.com',
        'pharmacyincity.com',
        'phobia.us',
        'phormchina.com',
        'photo-clip.ru',
        'photo.houseofgaga.ru',
        'photochki.com',
        'photokitchendesign.com',
        'photorepair.ru',
        'photostudiolightings.com',
        'phpdevops.com',
        'phuketscreen.com',
        'physfunc.ru',
        'pic2fly.com',
        'piccdata.com',
        'piccshare.com',
        'picphotos.net',
        'picquery.com',
        'pics-group.com',
        'picscout.com',
        'picsearch.com',
        'picsfair.com',
        'picsforkeywordsuggestion.com',
        'picture-group.com',
        'pictures-and-images.com',
        'pictures-and-images.net',
        'picturesfrom.com',
        'picturesify.com',
        'picturesmania.com',
        'pierrehardysale.online',
        'pigrafix.at',
        'pihl.se',
        'pijoto.net',
        'pila.pl',
        'pills24h.com',
        'pillscheap24h.com',
        'pinkduck.ga',
        'pinsdaddy.com',
        'pinstake.com',
        'pintattoos.com',
        'pinwallpaper.top',
        'pinwallpaper.xyz',
        'pio.polytopesexempt.com',
        'pipki.r.acdnpro.com',
        'piratecams.com',
        'pirateday.ru',
        'pisanieprac.info',
        'piski.top',
        'piter.xrus.org',
        'piulatte.cz',
        'piuminiita.com',
        'pix-hd.com',
        'pix24x7.com',
        'pixell.club',
        'pixelrz.com',
        'pixgood.com',
        'pixshark.com',
        'pizda.lol',
        'pizdopletka.club',
        'pizza-imperia.com',
        'pizza-tycoon.com',
        'pk-pomosch.ru',
        'pk-services.ru',
        'pkr1hand.com',
        'pl-top.pl',
        'pl-vouchers.com',
        'pl.aasoldes.fr',
        'pl.id-forex.com',
        'pladform.ru',
        'plaff-go.ru',
        'plastgran.com',
        'plastgranar.nu',
        'plastjulgranar.se',
        'plastweb.ru',
        'platesauto.com',
        'platezhka.net',
        'platinumdeals.gr',
        'play-movie.pl',
        'play-mp3.com',
        'play.leadzupc.com',
        'playboyfiles.xblog.in',
        'playlott.com',
        'playmsn.com',
        'playtap.us',
        'pliks.pl',
        'ploenjitmedia.azurewebsites.net',
        'plohaya-kreditnaya-istoriya.ru',
        'plusnetwork.com',
        'pobeiranie.pl',
        'pochemychka.net',
        'pochtovyi-index.ru',
        'podshipniki-nsk.ru',
        'podshipniki-ntn.ru',
        'poem-paying.gq',
        'poems.com.ua',
        'poffet.net',
        'pogodnyyeavarii.gq',
        'pogosh.com',
        'pogruztehnik.ru',
        'poisk-zakona.ru',
        'pojdelo.weebly.com',
        'pokemon-go-play.online',
        'pokemongooo.ml',
        'pokerniydom.ru',
        'polcin.de',
        'polybuild.ru',
        'polytopesexempt.com',
        'pomoc-drogowa.cba.pl',
        'pons-presse.com',
        'pontiacsolstice.info',
        'pony-business.com',
        'popads.net',
        'popander.mobi',
        'popcash.net',
        'popmarker.com',
        'poppen-nw.net',
        'popserve.adscpm.net',
        'poptool.net',
        'popugauka.ru',
        'popugaychiki.com',
        'popunder.net',
        'popunder.ru',
        'popup-fdm.xyz',
        'popup-hgd.xyz',
        'popup-jdh.xyz',
        'popup.matchmaker.com',
        'poquoson.org',
        'porn-w.org',
        'porn555.com',
        'porndairy.in',
        'porngalleries.top',
        'pornhub-forum.ga',
        'pornhub-ru.com',
        'pornhubforum.tk',
        'pornmania.pl',
        'porno-chaman.info',
        'porno-dojki.net',
        'porno-play.net',
        'porno-raskazy.ru',
        'porno-transsexuals.ru',
        'porno-video-chati.ru',
        'porno.simple-image.com.ua',
        'pornoblood.com',
        'pornobrazzers.biz',
        'pornodojd.ru',
        'pornoelita.info',
        'pornofiljmi.com',
        'pornoforadult.com',
        'pornogig.com',
        'pornohd1080.online',
        'pornokajf.com',
        'pornoklad.net',
        'pornoklad.ru',
        'pornokorol.com',
        'pornolook.net',
        'pornonik.com',
        'pornophoto.xyz',
        'pornosee.info',
        'pornosemki.info',
        'pornoslive.net',
        'pornosmola.info',
        'pornotubexxx.name',
        'pornpost.in',
        'pornstartits.xblog.in',
        'pornzone.tv',
        'porodasobak.net',
        'portadd.men',
        'portal-eu.ru',
        'portnoff.od.ua',
        'porto.abuilder.net',
        'portside.cc',
        'portside.xyz',
        'poshiv-chehol.ru',
        'posible.net',
        'positive2b.ru',
        'pospr.waw.pl',
        'postclass.com',
        'potoideas.us',
        'potolokelekor.ru',
        'powc.r.ca.d.sendibm2.com',
        'powenlite24.ru',
        'powitania.pl',
        'pozdravleniya-c.ru',
        'pozdrawleniya.com',
        'pozdrawleniya.ru',
        'pozvonim.com',
        'pp-budpostach.com.ua',
        'pr-ten.de',
        'pr0fit-b0x.com',
        'praisong.net',
        'pravoholding.ru',
        'prchecker.info',
        'predmety.in.ua',
        'predominant-invent.tk',
        'prefersurvey.net',
        'preg.marketingvici.com',
        'pregnant.guru',
        'preparevideosafesystem4unow.site',
        'preparevideosafesystem4unow.space',
        'presleycollectibles.com',
        'pretty-mart.com',
        'preventheadacheguide.info',
        'priceg.com',
        'pricheskaonline.ru',
        'pricheski-video.com',
        'primedice.com',
        'princeadvantagesales.com',
        'printdirectforless.com',
        'printie.com',
        'printingpeach.com',
        'priora-2.com',
        'priscilarodrigues.com.br',
        'privacyassistant.net',
        'privat-girl.net',
        'privatamateure.com',
        'privatbank46.ru',
        'privatefx-in.ru',
        'privatefx.all4invest.info',
        'privatov-zapisi.ru',
        'privetsochi.ru',
        'privhosting.com',
        'prize44.com',
        'prizeestates.cricket',
        'prizefestival.mobi',
        'prizesbook.online',
        'prizestohandle.club',
        'prlog.ru',
        'pro-okis.ru',
        'pro-tec.kz',
        'prod2016.com',
        'prodess.ru',
        'producm.ru',
        'productarium.com',
        'produkto.net',
        'prodvigator.ua',
        'proekt-gaz.ru',
        'proekt-mos.ru',
        'professionaldieselcare.com',
        'professionalwritingservices15.blogspot.ru',
        'profit-opportunity.com',
        'profitfx.online',
        'profitkode.com',
        'profitsport.club',
        'profitwithalex.info',
        'profolan.pl',
        'proftests.net',
        'progonrumarket.ru',
        'progress-upakovka.ru',
        'prohoster.info',
        'prointer.net.ua',
        'projectforte.ru',
        'projefrio.com.br',
        'prokotov.com',
        'prom23.ru',
        'promalp-universal.ru',
        'prombudpostach.com.ua',
        'promgirldresses.xyz',
        'promodj.com',
        'promoforum.ru',
        'promoheads.com',
        'promover.org',
        'pron.pro',
        'pronekut.com',
        'pronorm.fr',
        'proposal-engine.com',
        'propranolol40mg.blogspot.com',
        'proprostatit.com',
        'prosmibank.ru',
        'prospekt-st.ru',
        'prosperent.com',
        'prostitutki-almata.org',
        'prostitutki-astana.org',
        'prostitutki-belgoroda.org',
        'prostitutki-kharkova.org',
        'prostitutki-kiev.org',
        'prostitutki-novgoroda.org',
        'prostitutki-odessa.org',
        'prostitutki-rostova.org',
        'prostitutki-tolyatti.org',
        'prostitutki-tyumeni.org',
        'prostitutki-yaroslavlya.org',
        'proxyelite.biz',
        'proxyradar.com',
        'prpops.com',
        'psa48.ru',
        'pskcijdc.bloger.index.hr',
        'psoriasis-file.trade',
        'pssucai.info',
        'pst2017.onlinewebshop.net',
        'psvita.ru',
        'ptr.ruvds.com',
        'pts163.ru',
        'pufip.com',
        'pukaporn.com',
        'pulse33.ru',
        'pulseonclick.com',
        'purchasepillsnorx.com',
        'purplesphere.in',
        'purplestats.com',
        'puserving.com',
        'push-ad.com',
        'pushdata.sendpulse.com',
        'pussyfleet.com',
        'pussysaga.com',
        'puteshestvennik.com',
        'putevka24.ru',
        'putitin.me',
        'puzo2arbuza.ru',
        'puzzleweb.ru',
        'pwwysydh.com',
        'pxhdwsm.com',
        'py100.ru',
        'pyramidlitho.webs.com',
        'pyrodesigns.com.au',
        'q-moto.ru',
        'qcstrtvt.bloger.index.hr',
        'qexyfu.bugs3.com',
        'qitt.ru',
        'qld10000.net',
        'qor360.com',
        'qpypcx.com',
        'quality-traffic.com',
        'qualitymarketzone.com',
        'quangcaons.com',
        'quebec-bin.com',
        'queerspace.com',
        'quelle.ru',
        'questionmarque.ch',
        'quick-offer.com',
        'quick-seeker.com',
        'quickbuck.com',
        'quickcashlimited.com',
        'quickchange.cc',
        'quickloanbank.com',
        'quit-smoking.ga',
        'quizzitch.net',
        'qwarckoine.com',
        'qwesa.ru',
        'r-control.ru',
        'r-e-f-e-r-e-r.com',
        'raavidesigns.com',
        'rabot.host.sk',
        'rabotaetvse.ru',
        'rada.ru',
        'radiodigital.co',
        'radiogambling.com',
        'ragecash.com',
        'rainbowice.ru',
        'raisedseo.com',
        'randalljhoward.com',
        'randki-sex.com',
        'rangjued.com',
        'rank-checker.online',
        'rankexperience.com',
        'rankia.com',
        'ranking2017.ga',
        'rankingchart.de',
        'rankings-analytics.com',
        'ranksays.com',
        'rankscanner.com',
        'ranksignals.com',
        'ranksonic.com',
        'ranksonic.info',
        'ranksonic.org',
        'rapevideosmovies.com',
        'rapidgator-porn.ga',
        'rapidokbrain.com',
        'rapidsites.pro',
        'raschtextil.com.ua',
        'rasteniya-vs-zombi.ru',
        'ratemodels.net',
        'razamicroelectronics.com',
        'razorweb-a.akamaihd.net',
        'razyboard.com',
        'rcb101.ru',
        'rcpmda.ikan1080.xyz',
        'real-time-analytics.com',
        'realitykings.com',
        'realizmobi.com',
        'realmonte.net',
        'realnye-otzyvy.info',
        'realresultslist.com',
        'realting-moscow.ru',
        'realtytimes.com',
        'rebelmouse.com',
        'rebrand.ly',
        'rebuildermedical.com',
        'recinziireale.com',
        'recipedays.com',
        'recipedays.ru',
        'reckonstat.info',
        'recordpage-a.akamaihd.net',
        'redbottomheels.xyz',
        'redhotfreebies.co.uk',
        'redirect.trafficreceiver.club',
        'redirectingat.com',
        'redirectme.net',
        'redirlock.com',
        'rednise.com',
        'reelheroes.net',
        'reeyanaturopathy.com',
        'refads.pro',
        'referencemoi.com',
        'refererx.com',
        'refudiatethissarah.info',
        'regdefense.com',
        'regionshop.biz',
        'registratciya-v-moskve.ru',
        'registrationdomainsite.com',
        'registry-clean-up.net',
        'registry-cleaner.net',
        'registrydomainservices.com',
        'registrysweeper.com',
        'reimageplus.com',
        'reining.lovasszovetseg.hu',
        'reklama-i-rabota.ru',
        'reklama1.ru',
        'reklamuss.ru',
        'relax.ru',
        'remedyotc.com',
        'remmling.de',
        'remont-comp-pomosh.ru',
        'remont-fridge-tv.ru',
        'remont-komputerov-notebook.ru',
        'remont-mobile-phones.ru',
        'remont-ustanovka-tehniki.ru',
        'remontbiz.ru',
        'remontgruzovik.ru',
        'remontvsamare.su',
        'remorcicomerciale.ro',
        'remote-dba.de',
        'remybutler.fr',
        'renecaovilla.online',
        'renecaovillasale.online',
        'renewablewealth.com',
        'rennlist.com',
        'rentaremotecomputer.com',
        'rentehno.ru',
        'rep-am.com',
        'repeatlogo.co.uk',
        'replica-watch.ru',
        'replicaclub.ru',
        'replicalouboutin.xyz',
        'resant.ru',
        'research.ifmo.ru',
        'resellerclub.com',
        'responsinator.com',
        'responsive-test.net',
        'respublica-otel.ru',
        'restaurantlescampi.com',
        'restorator-msk.ru',
        'resultshub-a.akamaihd.net',
        'retailwith.com',
        'rethinkwasteni.info',
        'retreatia.com',
        'reversing.cc',
        'revistaindustria.com',
        'reward-survey.net',
        'rewardit.com',
        'rewardpoll.com',
        'reyel1985.webnode.fr',
        'rezeptiblud.ru',
        'rfd-split.hr',
        'rff-cfal.info',
        'rfid-locker.co',
        'rialp.getenjoyment.net',
        'ribieiendom.no',
        'ric.info',
        'richinvestmonitor.com',
        'ricorsogiustizia.org',
        'riders.ro',
        'rightenergysolutions.com.au',
        'rimedia.org',
        'ring4rhino.com',
        'ringporno.com',
        'ringtonepartner.com',
        'rique.host.sk',
        'risparmiocasa.bz.it',
        'ritlweb.com',
        'rixpix.ru',
        'rn-to-bsn.com',
        'robot-forex.biz',
        'rocketchange.ru',
        'rockingclicks.com',
        'rockma.se',
        'rockprogblog.com',
        'rogervivierforsale.com',
        'roleforum.ru',
        'roll123.com',
        'roma-kukareku.livejournal.com',
        'rome2rio.com',
        'roofers.org.uk',
        'rootandroid.org',
        'ros-ctm.ru',
        'rosbalt.com.ua',
        'rospromtest.ru',
        'rossanasaavedra.net',
        'rossmark.ru',
        'rostov.xrus.org',
        'royal-betting.net',
        'royal-investments.net',
        'royalads.net',
        'royalcar-ufa.ru',
        'royalvegascasino.com',
        'rozalli.com',
        'roznica.com.ua',
        'rp9.ru',
        'ru-dety.ru',
        'rubanners.com',
        'rubbed.us',
        'ruclicks.com',
        'rucrypt.com',
        'ruex.org.ua',
        'ruf777.com',
        'rukino.org',
        'rumamba.com',
        'running-line.ru',
        'runofilms.ru',
        'runstocks.com',
        'runtnc.net',
        'rus-teh.narod.ru',
        'ruscoininvest.company',
        'ruscopybook.com',
        'rusenvironmental.net',
        'rusexy.xyz',
        'rusoft-zone.ru',
        'ruspdd.com',
        'rusprostitute.com',
        'russia-tao.ru',
        'russia-today-video.ru',
        'russintv.fr',
        'russkie-gorki.ru',
        'russkoe-zdorovie.ru',
        'rustic-quiver.win',
        'rvtv.ru',
        'rvzr-a.akamaihd.net',
        'rybalka-opt.ru',
        'ryetaw.com',
        's-iwantyou.com',
        's.lollypopgaming.com',
        's8-nowy-wygraj.comli.com',
        'sa-live.com',
        'sa-rewards.co.za',
        'sabaapress.com',
        'sabizonline.com',
        'sack.net',
        'sad-torg.com.ua',
        'sadaholding.com',
        'saddiechoua.com',
        'sady-urala.ru',
        'safe-app.net',
        'saitevpatorii.com',
        'sajatvelemeny.com',
        'sakhboard.ru',
        'sale-japan.com',
        'saletool.ru',
        'salmonfishingsacramentoriver.com',
        'salutmontreal.com',
        'samara.rosfirm.ru',
        'sammlungfotos.online',
        'sammyweaver.com',
        'samo-soznanie.ru',
        'samoiedo.it',
        'samolet.fr',
        'sampleletters.net',
        'sanatorrii.ru',
        'sandhillsonline.com',
        'saneitconsulting.com',
        'saneyes.com',
        'sanidumps.com',
        'sanjosestartups.com',
        'sankt-peterburg.nodup.ru',
        'santasgift.ml',
        'santechnik.jimdo.com',
        'sanyuprojects.com',
        'sarafangel.ru',
        'saratov.xrus.org',
        'sardinie.us',
        'sarf3omlat.com',
        'sarm.tk',
        'sashagreyblog.ga',
        'satellite.maps.ilovevitaly.com',
        'saugatuck.com',
        'savefrom.com',
        'saveindex.xyz',
        'savememoney.co.za',
        'savetubevideo.com',
        'savingsslider-a.akamaihd.net',
        'sawin.beth.webd.pl',
        'sax-sex.com',
        'sayyoethe.blogspot.co.za',
        'sbdl.no',
        'sbetodiodnye-lampy.ru',
        'sbornik-zakonov.ru',
        'sbprabooks.com',
        'sbricur.com',
        'sbt-aqua.ru',
        'sbtdesign.co.uk',
        'sbwealthsolutions.ca',
        'sc-specialhost.com',
        'scalerite.co.za',
        'scanmarine.info',
        'scanmyphones.com',
        'scanner-alex.top',
        'scanner-alexa.top',
        'scanner-andrew.top',
        'scanner-barak.top',
        'scanner-brian.top',
        'scanner-don.top',
        'scanner-donald.top',
        'scanner-elena.top',
        'scanner-fred.top',
        'scanner-george.top',
        'scanner-irvin.top',
        'scanner-ivan.top',
        'scanner-jack.top',
        'scanner-jane.top',
        'scanner-jess.top',
        'scanner-jessica.top',
        'scanner-john.top',
        'scanner-josh.top',
        'scanner-julia.top',
        'scanner-julianna.top',
        'scanner-margo.top',
        'scanner-mark.top',
        'scanner-marwin.top',
        'scanner-mary.top',
        'scanner-nelson.top',
        'scanner-olga.top',
        'scanner-viktor.top',
        'scanner-walt.top',
        'scanner-walter.top',
        'scanner-willy.top',
        'scansafe.net',
        'scanspyware.net',
        'scat.porn',
        'scenarii-1-sentyabrya.uroki.org.ua',
        'scenicmissouri.us',
        'schlampen-treffen.com',
        'school-diplomat.ru',
        'schoolfiles.net',
        'scmor.ilxc.cc',
        'scoopquest.com',
        'scopich.com',
        'score-ads.men',
        'scottbywater.com',
        'scrapy.org',
        'screentoolkit.com',
        'scripted.com',
        'scrnet.biz.ua',
        'sdelai-prosto.ru',
        'sdelatmebel.ru',
        'sdi-pme.com',
        'sdrescher.net',
        'sdsjweb.com',
        'se-welding.ru',
        'se.bnt-team.com',
        'seadragonherbery.com',
        'seansonline24.pl',
        'search-error.com',
        'search-goo.com',
        'search.1and1.com',
        'search.alot.com',
        'search.pch.com',
        'search.xtconnect.com',
        'searchaddis.com',
        'searchencrypt.com',
        'searchengineranker.email',
        'searchimage.co',
        'searchimpression.com',
        'searchinquire.com',
        'searchinterneat-a.akamaihd.net',
        'searchkut.com',
        'searchlock.com',
        'searchmywindow-a.akamaihd.net',
        'searchtooknow-a.akamaihd.net',
        'searchwebknow-a.akamaihd.net',
        'seasaltwithfood.com',
        'seasonvar.ru',
        'seccioncontrabajo.com',
        'secret.xn--oogle-wmc.com',
        'secretscook.ru',
        'security60-e.com',
        'securityallianceservices.com',
        'see-your-website-here.com',
        'seeingmeerkat.com',
        'seemoreresultshu-a.akamaihd.net',
        'seeresultshub-a.akamaihd.net',
        'segol.tv',
        'sei80.com',
        'seinterface.com',
        'seksotur.ru',
        'selectads.men',
        'sell-fb-group-here.com',
        'semalt.com',
        'semaltmedia.com',
        'seminarygeorgia59.ga',
        'seminarykansas904.ml',
        'semp.net',
        'semprofile.com',
        'semrush.com',
        'sendearnings.com',
        'senger.atspace.co.uk',
        'seo-2-0.com',
        'seo-platform.com',
        'seo-smm.kz',
        'seo-tools-optimizing.com',
        'seo-traffic-ranking.info',
        'seoanalyses.com',
        'seoboxes.com',
        'seocdvig.ru',
        'seocheckupx.com',
        'seocheki.net',
        'seoexperimenty.ru',
        'seofied.com',
        'seofirmreviewsus.info',
        'seogadget.ru',
        'seoheap.com',
        'seoholding.com',
        'seojokes.net',
        'seokicks.de',
        'seomarketings.online',
        'seonetwizard.com',
        'seoprofiler.com',
        'seorank.info',
        'seorankinglinks.com',
        'seorankinglinks.us',
        'seorankinglinks.xyz',
        'seorussian.ru',
        'seotoolsagency.com',
        'serdcenebolit.com',
        'sergiorossistore.online',
        'serialsway.ucoz.ru',
        'serptehnika.ru',
        'servethis.com',
        'service-core.ru',
        'service.adtech.fr',
        'service.adtech.us',
        'servicecenter.co.ua',
        'serving.adbetclickin.pink',
        'servingnotice.com',
        'servisural.ru',
        'serw.clicksor.com',
        'seryeznie-znakomstva.ru',
        'sethrollins.net',
        'sevendays.com.ua',
        'sevenstars7.com',
        'sex-dating.co',
        'sex-foto.pw',
        'sex-pr.net',
        'sex-sex-sex5.com',
        'sex-tracker.com',
        'sex-tracker.de',
        'sex-watch.com',
        'sex.hotblog.top',
        'sexad.net',
        'sexblog.pw',
        'sexcamamateurchat.com',
        'sexflirtbook.com',
        'sexkontakte-seite.com',
        'sexkontakteao.info',
        'sexkrasivo.net',
        'sexobzor.info',
        'sexpartygirls.net',
        'sexphoto.site',
        'sexreliz.com',
        'sexsaoy.com',
        'sexsearch.com',
        'sexstream.pl',
        'sextracker.be',
        'sextracker.com',
        'sextracker.de',
        'sexvideo-sex.com',
        'sexvporno.ru',
        'sexy-pings.com',
        'sexy-screen-savers.com',
        'sexyali.com',
        'sexystrippe.info',
        'sexyteens.hol.es',
        'sexytrend.ru',
        'sfd-chess.ru',
        'sfj-ror.no',
        'shakhtar-doneck.ru',
        'shama-rc.net',
        'share-buttons-for-free.com',
        'sharebutton.net',
        'sharebutton.org',
        'sharebutton.to',
        'shariki-zuma-lines.ru',
        'sharpchallenge.com',
        'shell-pmr.ru',
        'shemale-sex.net',
        'shemalegalls.blogporn.in',
        'sherlock.se',
        'shijian.ac.cn',
        'shiksabd.com',
        'shillyourcoins.com',
        'shinikiev.com.ua',
        'ship-marvel.co.ua',
        'shisha-swag.de',
        'shitmovs.com',
        'shivafurnishings.com',
        'shlyahten.ru',
        'shmetall.com.ua',
        'shodanhq.com',
        'shoesonlinebuy.cn',
        'shoesonlinebuy.xyz',
        'shohanb.com',
        'shop-electron.ru',
        'shop.acim.org',
        'shop.xz618.com',
        'shopcheermakeup.info',
        'shoplvlv.us',
        'shopperifymac.com',
        'shoppingjequiti.com.br',
        'shoppingmiracles.co.uk',
        'shoppytoolmac.com',
        'shopsellcardsdumps.com',
        'shopvilleroyboch.com.ua',
        'shopwme.ru',
        'shtaketniki.kz',
        'shtaketniki.ru',
        'shtora66.ru',
        'shymkent.xkaz.org',
        'si-unique.com',
        'sibdevice.ru',
        'sibecoprom.ru',
        'sibtest.ru',
        'sibvitr.ru',
        'sicfor.bcu.cc',
        'sideeffectsoftizanidine.blogspot.com',
        'sientalyric.co',
        'sierraapps.com',
        'sigmund-freud.co.uk',
        'signal03.ru',
        'signoredom.com',
        'signx.info',
        'siha.de',
        'sildenafil-tadalafil.info',
        'sildenafilcitratemed.com',
        'silktide.com',
        'silverage.ru',
        'silvercash.com',
        'silvermature.net',
        'sim-service.net',
        'similardeals.net',
        'simon3.ru',
        'simple-image.com.ua',
        'simple-share-buttons.com',
        'simplepooltips.com',
        'simply.net',
        'simpoed.ufop.br',
        'sims-sims.ru',
        'simul.co',
        'sindragosa.comxa.com',
        'sinel.info',
        'sinestesia.host.sk',
        'sisiynas.ru',
        'sispe.com.br',
        'site-analyzer.com',
        'site-auditor.online',
        'site-speed-check.site',
        'site-speed-checker.site',
        'site.ru',
        'site3.free-share-buttons.com',
        'site5.com',
        'siteaero.com',
        'sitebeam.net',
        'siteexpress.co.il',
        'siteheart.net',
        'siteimprove.com',
        'siteonomy.com',
        'siteripz.net',
        'sitevaluation.com',
        'sitevaluation.org',
        'sitevalued.com',
        'sitiz.club',
        'sitopreferito.it',
        'sivs.ru',
        'sixcooler.de',
        'sizeplus.work',
        'sk.golden-praga.ru',
        'skachat-besplatno-obrazcy.ru',
        'skanninge.se',
        'skatestick.bid',
        'skincrate.net',
        'sklad-24.ru',
        'skladvaz.ru',
        'skuteczna-dieta.co.pl',
        'skutecznetabletkinaporostwlosow.pl',
        'sky-mine.ru',
        'skylta.com',
        'skytraf.xyz',
        'skyway24.ru',
        'slavia.info',
        'slavic-magic.ru',
        'slavkokacunko.de',
        'slayerlife.com',
        'sledstvie-veli.net',
        'slim.sellany.ru',
        'slimcdn.com',
        'slkrm.ru',
        'slomm.ru',
        'slonechka.ru',
        'slowmac.tech',
        'slowmacfaster.trade',
        'sluganarodu.ru',
        'slujbauborki.ru',
        'slutloadlive.com',
        'smailik.org',
        'small-game.com',
        'small-games.biz',
        'smallseotools.com',
        'smart-balancewheel.com',
        'smart-scripts.com',
        'smartadserver.com',
        'smartbalanceworld.com',
        'smartpet.ru',
        'smartshoppymac.com',
        'smichovbike.cz',
        'smokewithrabbits.com',
        'sms2x2.ru',
        'smsactivator.ru',
        'smstraf.ru',
        'sneakyboy.com',
        'snip.to',
        'snip.tw',
        'snjack.info',
        'snjatie-geroinovoy-lomki.ru',
        'snomer1.ru',
        'snow.nvr163.com',
        'snowplanes.com',
        'snsdeainavi.info',
        'snts.shell-pmr.ru',
        'snworks.com',
        'snyatie-lomki-v-stacionare.ru',
        'soaksoak.ru',
        'sobecjvuwa.com.ru',
        'soblaznu.net',
        'soc-econom-problems.ru',
        'soc-proof.su',
        'socas.pluto.ro',
        'social-button.xyz',
        'social-buttons.com',
        'social-buttons.xyz',
        'social-fun.ru',
        'social-s-ggg.xyz',
        'social-s-hhh.xyz',
        'social-s-iii.xyz',
        'social-search.me',
        'social-vestnik.ru',
        'socialbookmarksubmission.org',
        'socialbutton.xyz',
        'socialbuttons.xyz',
        'socialmadesimple.com',
        'socialmediasuggest.com',
        'socialmonkee.com',
        'socialseet.ru',
        'socialtrade.biz',
        'sockshare.net',
        'soda.media',
        'sodexo.com',
        'sofit-dmd.ru',
        'soft-program.com',
        'soft-terminal.ru',
        'soft1.ru',
        'softlinesolutions.me',
        'softomix.com',
        'softomix.net',
        'softonicads.com',
        'softtor.com',
        'softwaretrend.net',
        'softxaker.ru',
        'soheavyblog.com',
        'sohoindia.net',
        'solicita.info',
        'solitaire-game.ru',
        'solmarket.by',
        'solnplast.ru',
        'solution4u.com',
        'sonata-arctica.wz.cz',
        'songoo.wz.cz',
        'songplanet.ru',
        'sonnikforme.ru',
        'sophang8.com',
        'sortthemesitesby.com',
        'sosdepotdebilan.com',
        'soserfis.com',
        'sotkal.lark.ru',
        'soundfrost.org',
        'souvenir.cc',
        'souvenirua.com',
        'sovetogorod.ru',
        'soviet-portal.do.am',
        'sovinsteel.ru',
        'spacash.com',
        'space-worry.ml',
        'space4update.pw',
        'space4updating.win',
        'spaceshipad.com',
        'spammen.de',
        'spamnuker.com',
        'spasswelt.net',
        'spasswelt.xyz',
        'spb-plitka.ru',
        'spb.afora.ru',
        'spb.ru',
        'spbchampionat.ru',
        'special-porn.com',
        'specialfinanceoffers.com',
        'speechfoodie.com',
        'speedup-my.site',
        'spidtest.org',
        'spidtest.space',
        'spin2016.cf',
        'spinnerco.ca',
        'spitfiremusic.com',
        'splendorsearch-a.akamaihd.net',
        'sport-video-obzor.ru',
        'sport7777.net',
        'sportbetfair.com',
        'sports-supplements.us',
        'spravka-medosmotr.ru',
        'spravka130.ru',
        'sprttrack.com',
        'sps-shop.com',
        'sptslmtrafms.com',
        'spy-app.info',
        'spy-sts.com',
        'spyfu.com',
        'spylog.com',
        'spymac.net',
        'spywarebegone.com',
        'spywareit.com',
        'spywarenuker.com',
        'spywarespy.com',
        'squidoo.com',
        'sr-rekneskap.no',
        'srdrvp.com',
        'srecorder.com',
        'srgwebmail.nl',
        'sribno.net',
        'sstroy44.ru',
        'stackthatbucks.com',
        'staff.prairiesouth.ca',
        'stair.registrydomainservices.com',
        'stairliftsarea.com',
        'stairliftstrue.com',
        'stal-rulon.ru',
        'standardchartered-forex.com',
        'stanthonyscatholicchurch.org',
        'star61.de',
        'stardevine.com',
        'stariy-baku.com',
        'starpages.net',
        'start.myplaycity.com',
        'startufa.ru',
        'startwp.org',
        'starwars.wikia.com',
        'stathat.com',
        'staticfs.host',
        'statistici.ro',
        'statoutlook.info',
        'stats-collector.org',
        'stats-public.grammarly.io',
        'statustroll.com',
        'stauga.altervista.org',
        'staynplay.net',
        'steame.ru',
        'steelmaster.lv',
        'stefanbakosab.se',
        'sterva.cc',
        'stevemonsen.com',
        'stickers-market.ru',
        'stillmiracle.com',
        'stjamesschool.info',
        'stmassage.ru',
        'stockquotes.wooeb.com',
        'stockspmb.info',
        'stoki.ru',
        'stop-gepatit.te.ua',
        'store-rx.com',
        'storehouse.ua',
        'stpicks.com',
        'stpolice.com',
        'strag-invest.ru',
        'strana-krasoty.ru',
        'strana-solnca.ru',
        'strangeduckfilms.com',
        'streetfire.net',
        'streetfooduncovered.com',
        'streha-metalko.si',
        'stretchingabuckblog.com',
        'stretchmate.net',
        'strfls.com',
        'strigkaomsk.ru',
        'stroicol.net',
        'stroilka.info',
        'stroimajor.ru',
        'stroiminsk.com',
        'stroiminsk.org',
        'stromerrealty.com',
        'strongholdsb.ru',
        'strongsignal-a.akamaihd.net',
        'stroy-portal22.ru',
        'stroydetali.ru',
        'stroyhelp-dv.ru',
        'stroymonolit.su',
        'stroyplus.ru',
        'strv.se',
        'studiofaca.com',
        'stuff-about-money.com',
        'styro.ru',
        'success-seo.com',
        'suchenindeutschland.com',
        'sudexpert66.ru',
        'sugarkun.com',
        'suggest-keywords.com',
        'sugvant.ru',
        'suhanpacktech.com',
        'sukarame.net',
        'sukirgenk.dvrlists.com',
        'summerlinhomes411.info',
        'sumo.com',
        'sundrugstore.com',
        'superfish.com',
        'superiends.org',
        'superinterstitial.com',
        'superkanpo.com',
        'superlist.biz',
        'supermama.top',
        'supermesta.ru',
        'supernew.org',
        'superoboi.com.ua',
        'supers.com.ua',
        'superstats.com',
        'supervesti.ru',
        'support.nopeas.sk',
        'suralink.com',
        'surcentro.com',
        'sureone.pro',
        'surfbuyermac.com',
        'surffoundation.nl',
        'surflinksmedical.com',
        'surgut.zrus.org',
        'surintech.ac.th',
        'survival.betteroffers.review',
        'susanholtphotography.com',
        'svarbit.com',
        'svarkagid.com',
        'svbur.ru',
        'svetlotorg.ru',
        'svetodiodoff.ru',
        'svnuppsalaorebro.se',
        'svolze.com',
        'svtrd.com',
        'swagbucks.com',
        'sweepstakes.rewardit.com',
        'swimpool.ca',
        'swinger-mobil.net',
        'swingerseiten.com',
        'swinginwithme.ru',
        'swinon.site',
        'swiped.su',
        'swsociety.se',
        'sygraem.com',
        'symbaloo.com',
        'symphonyintegratedhealthcare.com',
        'syvertsen-da.no',
        'szamponrevita.pl',
        'szucs.ru',
        't-bygg.com',
        't3chtonic.com',
        'taaaak.com',
        'tabakur77.com',
        'tabletkinaodchudzanie.com.pl',
        'taboola.com',
        'tacbelarus.ru',
        'tagil.zrus.org',
        'taihouse.ru',
        'takeflyte.com',
        'takeprofitsystem.com',
        'takethatad.com',
        'tako3.com',
        'talant-factory.ru',
        'tam-gde-more.ru',
        'tampabaywatch.org',
        'tandvardshuset.net',
        'tanieaukcje.com.pl',
        'taqplayer.info',
        'taqywu51.soup.io',
        'tarad.com',
        'taraz.xkaz.org',
        'tasteidea.com',
        'tastyfoodideas.com',
        'tattomedia.com',
        'tattoo33.ru',
        'tattooha.com',
        'tattooreligion.ru',
        'taxi-v-eisk.ru',
        'taximytishi.ru',
        'td-33.ru',
        'td-l-market.ru',
        'tds-advert005.info',
        'tdsing.ru',
        'teastory.co',
        'tech4master.com',
        'techart24.com',
        'technika-remont.ru',
        'technopellet.gr',
        'tecspb.ru',
        'tedxrj.com',
        'tedy.su',
        'teenbbw.yopoint.in',
        'teesdaleflyballclub.co.uk',
        'teguh.info',
        'tehngr.ru',
        'telefonsex-ohne0900.net',
        'telefonsexi.com',
        'telefonsexkostenlos.tk',
        'telefonsexsofort.tk',
        'telegraf.by',
        'telegramdownload10.com',
        'telemetryverification.net',
        'telesvoboda.ru',
        'telsis.com',
        'template-kid.com',
        'templates.franklinfire.co',
        'templates.radiodigital.co',
        'tengohydar.tk',
        'terraclicks.com',
        'terrafootwear.us',
        'teslathemes.com',
        'testingads.pro',
        'tetracsaudi.com',
        'texbaza.by',
        'textads.men',
        'tfxiq.com',
        'tgtclick.com',
        'thaisamkok.com',
        'the-torrent-tracker.blogspot.com',
        'the-trader.net',
        'the-usa-games.blogspot.com',
        'theallgirlarcade.com',
        'theautoprofit.ml',
        'thebestweightlosspills.ovh',
        'thebitcoincode.com',
        'thebluenoodle.com',
        'thebluffs.com',
        'thecoolimages.net',
        'thecoral.com.br',
        'thecounter.com',
        'thedownloadfreeonlinegames.blogspot.com',
        'thedownloadfromwarez.blogspot.com',
        'thefarmergame.com',
        'thefds.net',
        'thegameriders.com',
        'thegamerznetwork.com',
        'thegioixekhach.com',
        'theguardlan.com',
        'theheroes.ru',
        'thejournal.ru',
        'thelottosecrets.com',
        'themeforest.net',
        'themestotal.com',
        'thenetinfo.com',
        'thenews-today.info',
        'theplacetoupdating.pw',
        'thepokertimer.com',
        'theprofitsmaker.net',
        'thesmartsearch.net',
        'thetardistimes.ovh',
        'thetattoohut.com',
        'thetoiletpaper.com',
        'thewebsitetemplate.info',
        'thewomenlife.com',
        'thfox.com',
        'thiegs.reco.ws',
        'thin.me.pn',
        'thruport.com',
        'tiandeural.ru',
        'ticketsys.inetwd.com',
        'tiens2010.ru',
        'tilido.com',
        'timdreby.com',
        'time-japan.ru',
        'timeallnews.ru',
        'timecrimea.ru',
        'timer4web.com',
        'timetorelax.biz',
        'timhost.ru',
        'titan-ads.life',
        'titan-cloud.life',
        'titangel-vietnam.com',
        'titelhelden.eu',
        'titslove.yopoint.in',
        'tizanidine4mg.blogspot.com',
        'tizanidine4mgprice.blogspot.com',
        'tizanidine4mgstreetprice.blogspot.com',
        'tizanidine4mgstreetvalue.blogspot.com',
        'tizanidine4mgtablets.blogspot.com',
        'tizanidine4mguses.blogspot.com',
        'tizanidine6mg.blogspot.com',
        'tizanidineandcipro.blogspot.com',
        'tizanidineandgabapentin.blogspot.com',
        'tizanidineandhydrocodone.blogspot.com',
        'tizanidinecapsules.blogspot.com',
        'tizanidinecost.blogspot.com',
        'tizanidinedosage.blogspot.com',
        'tizanidinedosageforsleep.blogspot.com',
        'tizanidinedruginteractions.blogspot.com',
        'tizanidinedrugtest.blogspot.com',
        'tizanidineduringpregnancy.blogspot.com',
        'tizanidinefibromyalgia.blogspot.com',
        'tizanidineformigraines.blogspot.com',
        'tizanidineforopiatewithdrawal.blogspot.com',
        'tizanidinehcl2mg.blogspot.com',
        'tizanidinehcl2mgsideeffects.blogspot.com',
        'tizanidinehcl2mgtablet.blogspot.com',
        'tizanidinehcl4mgisitanarcotic.blogspot.com',
        'tizanidinehcl4mgtab.blogspot.com',
        'tizanidinehcl4mgtabinfo.blogspot.com',
        'tizanidinehcl4mgtablet.blogspot.com',
        'tizanidinehclsideeffects.blogspot.com',
        'tizanidinehydrochloride2mg.blogspot.com',
        'tizanidinehydrochloride4mgstreetvalue.blogspot.com',
        'tizanidineinfo.blogspot.com',
        'tizanidineingredients.blogspot.com',
        'tizanidineinteractions.blogspot.com',
        'tizanidinemusclerelaxant.blogspot.com',
        'tizanidinenarcotic.blogspot.com',
        'tizanidineonline.blogspot.com',
        'tizanidineoral.blogspot.com',
        'tizanidineorflexeril.blogspot.com',
        'tizanidinepain.blogspot.com',
        'tizanidinepills.blogspot.com',
        'tizanidinerecreationaluse.blogspot.com',
        'tizanidinerestlesslegsyndrome.blogspot.com',
        'tizanidineshowupondrugtest.blogspot.com',
        'tizanidinesideeffects.blogspot.com',
        'tizanidinesideeffectsweightloss.blogspot.com',
        'tizanidinesleepaid.blogspot.com',
        'tizanidinestreetprice.blogspot.com',
        'tizanidinestreetvalue.blogspot.com',
        'tizanidineusedfor.blogspot.com',
        'tizanidinevscyclobenzaprine.blogspot.com',
        'tizanidinevssoma.blogspot.com',
        'tizanidinevsvalium.blogspot.com',
        'tizanidinewithdrawal.blogspot.com',
        'tizanidinewithdrawalsymptoms.blogspot.com',
        'tizanidinezanaflex.blogspot.com',
        'tjkckpytpnje.com',
        'tk-assortiment.ru',
        'tkanorganizma.ru',
        'tksn.ru',
        'tmearegion26.com',
        'tmm-kurs.ru',
        'tmtrck.com',
        'tn811.us',
        'tnaionline.org',
        'tnctrx.com',
        'tobeyouday.win',
        'todohr.com',
        'toloka.hurtom.com',
        'tomatis.gospartner.com',
        'tomck.com',
        'tongkatmadura.info',
        'toolsky.com',
        'toon-families.com',
        'toondinsey.com',
        'toonfamilies.net',
        'tooplay.com',
        'tootoo.to',
        'top-deal.com.pl',
        'top-karkas.ru',
        'top-study.work',
        'top1-seo-service.com',
        'top10-way.com',
        'top10registrycleaners.com',
        'top250movies.ru',
        'topads.men',
        'topappspro.com',
        'topbestgames.com',
        'topcar-krasnodar.ru',
        'topclickguru.com',
        'topdownloads.ru',
        'topkarkas.com',
        'topmira.com',
        'topquality.cf',
        'toproadrunner5.info',
        'topshef.ru',
        'topsiteminecraft.com',
        'topsy.com',
        'topvidos.ru',
        'torontoplumbinggroup.com',
        'torrent-newgames.com',
        'torrent-to-magnet.com',
        'torrents-tracker.com',
        'torrents.cd',
        'torrnada.ru',
        'torture.ml',
        'totu.info',
        'totu.us',
        'touchmods.fr',
        'tour-line.net',
        'tourcroatia.co.uk',
        'tourismvictoria.com',
        'toursmaps.com',
        'tovaroboom.vast.ru',
        'toxicwap.com',
        'toy-shop.top',
        'toyota.7zap.com',
        'toys.erolove.in',
        'tozup.com',
        'tpu.ru',
        'tracfone.com',
        'track-rankings.online',
        'track112.site',
        'track2.shop',
        'tracklead.net',
        'trackmedia101.com',
        'tracksurf.daooda.com',
        'tracksz.co',
        'trackzapper.com',
        'tracxn.com',
        'tradedeals.biz',
        'traderzplanet.in',
        'tradgardspartner.se',
        'trafaret74.ru',
        'traffic100.com',
        'traffic2cash.org',
        'traffic2money.com',
        'trafficfactory.biz',
        'trafficgenius.xyz',
        'trafficjunky.com',
        'trafficjunky.net',
        'trafficmania.com',
        'trafficmonetize.org',
        'trafficmp.com',
        'trafficnetzwerk.de',
        'trafficreceiver.club',
        'trafficstars.com',
        'traffictrade.life',
        'traffique.net',
        'traffixer.com',
        'traffmonster.info',
        'traffpartners.com',
        'trahic.ru',
        'trahvid.com',
        'trailer.cinemaflix.website',
        'trainoffend.ml',
        'tramadolandtizanidine.blogspot.com',
        'traxdom.ru',
        'treasuretrack-a.akamaihd.net',
        'tri-slona.org',
        'trichizobswiv.agddns.net',
        'trion.od.ua',
        'tripper.de',
        'triumf-realty.ru',
        'trk-4.net',
        'trkdf.com',
        'trkur.com',
        'trubywriting.com',
        'truck-addzilla.life',
        'truck-land.life',
        'truck-rece.life',
        'trucri.me',
        'trudogolik.net',
        'truebeauty.cc',
        'truemfilelj.gq',
        'trumpetedextremes.com',
        'trustaffs.com',
        'trustedhealthtips.com',
        'trustedmaccleaner.com',
        'trustl.life',
        'try-rx.com',
        'tsan.net',
        'tsstcorpcddvdwshbbdriverfb.aircus.com',
        'tsyndicate.com',
        'ttrraacckkrr.com',
        'ttsq.fr',
        'tube8.com',
        'tubeline.biz',
        'tubeoffline.com',
        'tuberkulezanet.ru',
        'tuberkuleznik.ru',
        'tubo360.com',
        'tuckermktg.com',
        'tuckpointingmasonrysystems.com',
        'tula.howotorg.ru',
        'tula.mdverey.ru',
        'tupper-posuda.ru',
        'tupper-shop.ru',
        'turbabitload.weebly.com',
        'turbo-suslik.org',
        'turbodsp.com',
        'turist-strani.ru',
        'turizm.bz',
        'turizmus.us',
        'turkeyreport.tk',
        'turn-up-life.life',
        'turvgori.ru',
        'tv-spoty.info',
        'tvand.ru',
        'tversvet.ru',
        'tvorozhnaja-zapekanka-recept.ru',
        'tvoystartup.ru',
        'tvteleport.ru',
        'twelvevisionspartyofcolorado.com',
        'twiclub.in',
        'twincitiescarservice.com',
        'twinderbella.com',
        'twitlinks.com',
        'twittrading.com',
        'twittruth.com',
        'twodollarshows.com',
        'twojebook.pl',
        'twu.com.ua',
        'tx41tclega.ru',
        'txxx.com',
        'typer.one',
        'tytoona.com',
        'tyumen.xrus.org',
        'tzritel.tk',
        'u-cheats.ru',
        'u17795.netangels.ru',
        'u555u.info',
        'ua-company.ru',
        'ua.tc',
        'uac.net.au',
        'uamtrk.com',
        'uasb.ru',
        'ublaze.ru',
        'uchebavchehii.ru',
        'uchetunet.su',
        'uchil.net',
        'ucoz.ru',
        'ucsol.ru',
        'udayavani.com',
        'udsgame.online',
        'ufa.xrus.org',
        'uggbootsoutletsale.us',
        'uggsale.online',
        'ugguk.online',
        'ugogo.info',
        'uhdtv.website',
        'uhod-za-sobakoj.ru',
        'uhodzalijami.ru',
        'uk-zheu20.ru',
        'ukkelberg.no',
        'ukrobstep.com',
        'ukrup.com',
        'ultimateclassicrock.com',
        'ultimatesetnewfreeallsoftupgradesystems.pw',
        'ultramart.biz',
        'um-razum.ru',
        'umaseh.com',
        'umekana.ru',
        'umg-stroy.ru',
        'umityangin.net',
        'umnovocaminho.com',
        'unacittaconte.org',
        'unblocksit.es',
        'undergroundcityphoto.com',
        'underthesite.com',
        'unece.org',
        'uni.me',
        'unimodemhalfduplefw.pen.io',
        'unionmarkt.de',
        'unisexjewelry.org',
        'unitexindia.com',
        'unitygame3d.com',
        'univerfiles.com',
        'universals.com.ua',
        'unlimitdocs.net',
        'unmaroll.ya.ru',
        'unpredictable.ga',
        'unrealcommander.biz',
        'unrealcommander.com',
        'unrealcommander.org',
        'uogonline.com',
        'upproar.com',
        'uprour.com',
        'upstore.me',
        'uptime-alpha.net',
        'uptime-as.net',
        'uptime-delta.net',
        'uptime-gamma.net',
        'uptime.com',
        'uptimebot.net',
        'uptimechecker.com',
        'upupa.net',
        'ural-buldozer.ru',
        'urccvfmc.bloger.index.hr',
        'urdoot.win',
        'urengoy.pro',
        'url-img.link',
        'url2image.com',
        'urlcut.ru',
        'urldelivery.com',
        'urll.eu',
        'urlopener.blogspot.com.au',
        'urlopener.com',
        'uroffer.link',
        'uroki.net',
        'urzedowski.eu',
        'us-america.ru',
        'usacasino.com',
        'usadacha.net',
        'usbggettwku.ga',
        'usdx.us',
        'userequip.com',
        'usiad.net',
        'ussearche.cf',
        'usswrite.com',
        'ustion.ru',
        'utiblog.fr',
        'utrolive.ru',
        'uvozdeckych.info',
        'uytmaster.ru',
        'uzungil.com',
        'v-doc.co',
        'v24s.net',
        'v720hd.ru',
        'vabasa.inwtrade.com',
        'vacances-voyages.info',
        'vacuumscleaner.com',
        'vadimkravtcov.ru',
        'validccseller.com',
        'validdomain.xyz',
        'valkiria-tk.ru',
        'valmetrundan.se',
        'valoresito.com',
        'valsalud.com',
        'valuado.com',
        'valueclick.com',
        'vancleefreplica.pw',
        'vandrie-ict.nl',
        'vapeface.club',
        'vapsy.com',
        'varbergsvind.se',
        'varikoz24.com',
        'varikozdok.ru',
        'vashsvet.com',
        'vasileostrovsky-rayon.ru',
        'vavilone.com',
        'vbabule.net',
        'vclicks.net',
        'vduplo.ru',
        'vedomstvo.net',
        'veerotech.com',
        'vegan-foods.us',
        'vegascosmetics.ru',
        'vektorpress.ru',
        'vekzdorov.ru',
        'vellings.info',
        'velobikestock.com',
        'venerologiya.com',
        'venta-prom.ru',
        'ventelnos.com',
        'vepad.com',
        'vereo.eu',
        'versaut.xxx-cam.webcam',
        'vertaform.com',
        'verymes.xyz',
        'veselokloun.ru',
        'vesnatehno.com',
        'vesnatehno.ru',
        'vezuviy.su',
        'vgoloveboli.net',
        'via-energy-acquistare.com',
        'via-energy-cumpara.com',
        'via-energy-order.com',
        'via-gra.webstarts.com',
        'viagra.pp.ua',
        'viagroid.ru',
        'viandpet.com',
        'viberdownload10.com',
        'viddyoze.com',
        'video--production.com',
        'video-chat.cn',
        'video-chat.in',
        'video-chat.love',
        'video-hollywood.ru',
        'video-production.com',
        'video-woman.com',
        'videochat.bz',
        'videochat.cafe',
        'videochat.life',
        'videochat.mx',
        'videochat.ph',
        'videochat.tv.br',
        'videochat.world',
        'videochaty.ru',
        'videogamesecrets.com',
        'videojam.tv',
        'videokrik.net',
        'videooko.weebly.com',
        'videos-for-your-business.com',
        'videosbox.ru',
        'videositename.com',
        'videotuber.ru',
        'videtubs.pl',
        'viel.su',
        'vielporno.net',
        'vigrx-original.ru',
        'vikistars.com',
        'viktoria-center.ru',
        'vilingstore.net',
        'villacoloniale.com',
        'villakohlanta.nu',
        'vinsit.ru',
        'vintontech.info',
        'vinylvault.co.uk',
        'vip-dom.in',
        'vip-file.com',
        'vip-parfumeria.ru',
        'vip.51.la',
        'vip2ch.com',
        'vipms.ru',
        'vipps.com.my',
        'vipromoffers.com',
        'vipsexfinders.com',
        'vipsiterip.org',
        'virtuagirl.com',
        'visa-china.ru',
        'visa-pasport.ru',
        'visionwell.com.cn',
        'visitcambridge.org',
        'vita.com.hr',
        'vitalads.net',
        'vitanail.ru',
        'viteonlusarezzo.it',
        'vitoriacabos.com',
        'viven.host.sk',
        'vizag.kharkov.ua',
        'vizitki.net',
        'vk-mus.ru',
        'vkak.ru',
        'vkgaleria.com',
        'vkonche.com',
        'vkontaktemusic.ru',
        'vkontarkte.com',
        'vksaver-all.ru',
        'vladhistory.com',
        'vladimir.xrus.org',
        'vladimir.zrus.org',
        'vltai.com',
        'vmnmvzsmn.over-blog.com',
        'vod.com.ua',
        'vodaodessa.com',
        'voditeltrezviy.ru',
        'vodkoved.ru',
        'volgograd.xrus.org',
        'voloo.ru',
        'voloomoney.com',
        'voltrknc1.com',
        'volume-pills.biz',
        'voluumtracker1.com',
        'voluumtrk.com',
        'vonradio.com',
        'voprosotvet24.ru',
        'voronezh.xrus.org',
        'vostoktrade.info',
        'vote-up.ru',
        'vozbujdenie.com',
        'vpnhowto.info',
        'vpnmouse.com',
        'vremya.eu',
        'vriel.batcave.net',
        'vrnelectro.ru',
        'vrotike.ru',
        'vsdshnik.com',
        'vsesubwaysurfers.com',
        'vseuznaem.com',
        'vsexkontakte.net',
        'vtc.pw',
        'vucms.com',
        'vut.com.ru',
        'vvon.co.uk',
        'vvpg.ru',
        'vykup-avto-krasnodar.ru',
        'vykupavto-krasnodar.ru',
        'vysigy.su',
        'vzglyadriv.kg',
        'vzlom-na-zakaz.com',
        'vzube.com',
        'w-journal.ru',
        'w3data.co',
        'w3javascript.com',
        'w7s.ru',
        'wahicbefa31.soup.io',
        'wait3sec.org',
        'walkme.com',
        'wallpapers-best.com',
        'wallpapersdesk.info',
        'wallpapersist.com',
        'wallpaperstock.net',
        'wanker.us',
        'wapsite.me',
        'wareseeker.com',
        'warezaccess.com',
        'warezkeeper.com',
        'warning.or.kr',
        'warningwar.ru',
        'warningzscaler.heraeus.com',
        'watch-movies.ru',
        'watchdogs-2.ru',
        'watchinf.com',
        'watchmyfb.pl',
        'watchmygf.net',
        'waterpurifier.club',
        'watsonrealtycorp.com',
        'waycash.net',
        'waysbetter.cn',
        'wcb.su',
        'wdfdocando.com',
        'wdrake.com',
        'we-are-gamers.com',
        'web-betting.ru',
        'web.cvut.cz',
        'webads.co.nz',
        'webadvance.club',
        'webalan.ru',
        'webcamdevochka.com',
        'webenlace.com.ar',
        'webextract.profound.net',
        'webinstantservice.com',
        'webix.biz',
        'webix.me',
        'webjam.com',
        'webkeyit.com',
        'weblo.com',
        'webmasterhome.cn',
        'webmasters.stackexchange.com',
        'webmonetizer.net',
        'webnode.me',
        'weboptimizes.com',
        'webpromotion.ae',
        'webradiology.ru',
        'webs.com',
        'webscouter.net',
        'webshoppermac.com',
        'website-analytics.online',
        'website-analyzer.info',
        'website-audit.com.ua',
        'website-datenbank.de',
        'website-speed-check.site',
        'website-speed-checker.site',
        'website-speed-up.site',
        'website-speed-up.top',
        'website-stealer.nufaq.com',
        'websiteaccountant.de',
        'websiteexplorer.info',
        'websites-reviews.com',
        'websitevaluebot.com',
        'webstatsdomain.org',
        'webtherapy.ru',
        'weburlopener.com',
        'weburok.com',
        'wechatdownload10.com',
        'weclipart.com',
        'wedding-salon.net',
        'wedding0venues.tk',
        'weddingdresses.xyz',
        'weekes.biz.tc',
        'weightatraining.com',
        'wejdz-tu.pl',
        'welck.octopis.com',
        'welcomeauto.ru',
        'wellcome2slovenia.ru',
        'wemarketing.se',
        'wemedinc.com',
        'weprik.ru',
        'wesharepics.com',
        'wesharepics.info',
        'wesharepics.site',
        'westen-v.life',
        'westen-z.life',
        'westermarkanjou.se',
        'westsextube.com',
        'westum.se',
        'westvilletowingservices.co.za',
        'wetgames.ru',
        'wfb.hatedriveapart.com',
        'whatistizanidine2mg.blogspot.com',
        'whatistizanidinehclusedfor.blogspot.com',
        'whatsappdownload10.com',
        'whatsupinfoley.com',
        'whatzmyip.net',
        'wheelchairliftsarea.com',
        'whengirlsgowild.com',
        'where-toget.com',
        'whereiskentoday.com',
        'whereverdesperate.gq',
        'while.cheapwebsitehoster.com',
        'whipme.yopoint.in',
        'white-truck.life',
        'whiteelephantwellington.com',
        'whiteproduct.com',
        'wholesalecheapjerseysfree.com',
        'wholesalejerseychinaoutlet.com',
        'wholesalejerseychinashop.com',
        'wholesalejerseys-cheapest.com',
        'wholesalejerseyscheapjerseys.us.com',
        'wholesalejerseysgaa.com',
        'wholesalenfljerseys.us.com',
        'wholinkstome.com',
        'whos.amung.us',
        'whosonmyserver.com',
        'wieseversa.no',
        'wikes.20fr.com',
        'wildcattube.com',
        'wildnatureimages.com',
        'wildworld.site',
        'williamrobsonproperty.com',
        'win-spy.com',
        'windowssearch-exp.com',
        'wineitudes.wordpress.com',
        'wineration.com',
        'wingsoffury2.com',
        'wingsofrefuge.net',
        'winner7777.net',
        'winterclassichockeyjerseys.com',
        'winwotgold.pl',
        'winx-play.ru',
        'wiosenny-bon-1500.pl',
        'witherrom55.eklablog.fr',
        'withstandingheartwarming.com',
        'wjgony.com',
        'wladimirpayen.com',
        'wleuaprpxuvr.ga',
        'wma-x.com',
        'wnhjavlhezp.gq',
        'wnoz.de',
        'womama.ru',
        'woman-h.ru',
        'woman-orgasm.ru',
        'woman-tampon.ru',
        'womens-journal.net',
        'womensplay.net',
        'womensterritory.ru',
        'wonderfulflowers.biz',
        'woodyguthrie.se',
        'word-vorlagen.net',
        'word-vorlagen.xyz',
        'wordkeyhelper.com',
        'wordpress-crew.net',
        'wordpresscore.com',
        'workle.website',
        'works.if.ua',
        'world-mmo.com',
        'worldhistory.biz',
        'worldinternetauthority.com',
        'worldis.me',
        'worldlovers.ru',
        'worldmusicfests.com',
        'worldoffiles.ru',
        'worldtraveler.world',
        'wormix-cheats.ru',
        'wosik-dach.service-for-web.de',
        'wowas31.ucoz.ru',
        'woweb.com.ua',
        'wpsecurity.website',
        'wpthemedetector.co.uk',
        'writersgroup580.web.fc2.com',
        'writingservices17.blogspot.ru',
        'wrona.it',
        'ws.ampower.me',
        'wsgames.ru',
        'wstroika.ru',
        'wtsindia.in',
        'wttavern.com',
        'wufak.com',
        'wurr.voila.net',
        'ww1943.ru',
        'ww2awards.info',
        'www.888.com',
        'www.arenda-yeisk.ru',
        'www.event-tracking.com',
        'www.get-free-traffic-now.com',
        'www.kabbalah-red-bracelets.com',
        'www.timer4web.com',
        'wwwadultcheck.com',
        'wygraj-skiny.win',
        'wygraj-teraz.com',
        'wyniki-lista.pl',
        'wzgyyq.com',
        'x-diesel.biz',
        'x-diesel.com',
        'x-diesel.info',
        'x-diesel.org',
        'x-lime.net',
        'x-musics.com',
        'x-porno.video',
        'x-rates.ru',
        'x-stars.ru',
        'x-true.info',
        'x69ty.ru',
        'xaijo.com',
        'xaylapdiendanang.com',
        'xbaboon.com',
        'xblog.in',
        'xboxster.ru',
        'xcc24.pl',
        'xchangetrak.com',
        'xchat26.myfreecams.com',
        'xclicks.net',
        'xcombear.ru',
        'xdoza.com',
        'xedserver.com',
        'xep.info',
        'xerox-douglas.cf',
        'xev.ru',
        'xfire.com',
        'xfluro.com',
        'xgames-04.com',
        'xgftnlrt.bloger.index.hr',
        'xingzi-vision.com',
        'xitjw.info',
        'xjlottery.com',
        'xjrul.com',
        'xkaz.org',
        'xlolitka.com',
        'xlovecam.com',
        'xmladserver.com',
        'xmlinde.com',
        'xmronta.com',
        'xn------7cdbapdecfd4ak1bn0amjffj7afu3y.xn--p1ai',
        'xn-----6kcaacnblni5c5bicdpcmficy.xn--p1ai',
        'xn-----6kccaibs5cb8afhjrfmix2n.xn--p1ai',
        'xn-----7kcabaipgeakzcss7bjdqdwpfnhv.xn--p1ai',
        'xn-----7kceclhb4abre1b4a0ccl2fxch1a.xn--p1ai',
        'xn-----8kcatubaocd1bneepefojs1h2e.xn--p1ai',
        'xn----7sbaaabaei0cc8aj5bj0bncejx.xn--p1ai',
        'xn----7sbahjd3btneuw1joc.xn--p1ai',
        'xn----7sbaphztdjeboffeiof6c.xn--p1ai',
        'xn----7sbbagbq7bd5aheftfllo4m.xn--p1ai',
        'xn----7sbbahaq9bb5afgiqfliv4m.xn--p1ai',
        'xn----7sbho2agebbhlivy.xn--p1ai',
        'xn----7sbifcamovvfggw9d.xn--p1ai',
        'xn----8sbdbjgb1ap7a9c4czbh.xn--p1acf',
        'xn----8sbhefaln6acifdaon5c6f4axh.xn--p1ai',
        'xn----9sbebi2bvzr7h.xn--p1ai',
        'xn----9sbubg3ambdfl1j.xn--p1ai',
        'xn----dtbndd4ae7eub.top',
        'xn----itbeirbjbi7bc6bh2d.xn--p1ai',
        'xn----itbkqkfiq.xn--p1ai',
        'xn--1-8sbcpb0bdm8k6a.xn--p1ai',
        'xn--24-glceagatoq7c2a6ioc.xn--p1ai',
        'xn--80aaafbn2bc2ahdfrfkln6l.xn--p1ai',
        'xn--80aaagvmjabrs1aoc9luc.xn--p1ai',
        'xn--80aaajbdbddwj2alwjieei2afr3v.xn--p1ai',
        'xn--80aaaks3bbhabgbigamdr2h.xn--p1ai',
        'xn--80aafb2a.xn--p1ai',
        'xn--80aagddcgkbcqbad7amllnejg6dya.xn--p1ai',
        'xn--80aanaardaperhcem4a6i.com',
        'xn--80ab4aa2g.xn--p1ai',
        'xn--80abgj3a5acid6ghs.top',
        'xn--80adaggc5bdhlfamsfdij4p7b.xn--p1ai',
        'xn--80aeahghtf8ac5i.xn--p1ai',
        'xn--80aebbcbcdemfkhba4byaehoejh8dza3v.xn--p1ai',
        'xn--80ahdheogk5l.xn--p1ai',
        'xn--80ahvj9e.xn--p1ai',
        'xn--80aikhbrhr.net',
        'xn--80ajbshivpvn2i.xn--p1ai',
        'xn--80ajjbdhgmudixfjc8c5a9df8b.xn--p1ai',
        'xn--80ak6aa92e.com',
        'xn--80aodinpgi.xn--p1ai',
        'xn--90acenikpebbdd4f6d.xn--p1ai',
        'xn--b1adccaf1bzj.xn--p1ai',
        'xn--b1ag5cfn.xn--p1ai',
        'xn--b1agm2d.net',
        'xn--c1acygb.xn--p1ai',
        'xn--d1abj0abs9d.in.ua',
        'xn--d1aifoe0a9a.top',
        'xn--e1afanlbnfckd7c3d.xn--p1ai',
        'xn--e1aggki3c.xn--80adxhks',
        'xn--h1aakne2ba.xn--p1ai',
        'xn--h1ahbi.com.ua',
        'xn--hxazdsfy.blogspot.com',
        'xn--l1aengat.xn--p1ai',
        'xn--lifehacer-1rb.com',
        'xn--oogle-wmc.com',
        'xn--q1a.xn--b1aube0e.xn--c1acygb.xn--p1ai',
        'xnxx-n.com',
        'xnxxandxvideos.com',
        'xolodremont.ru',
        'xportvusbdriver8i.snack.ws',
        'xpresscare.ru',
        'xrus.org',
        'xsion.net',
        'xtrafficplus.com',
        'xtremeeagles.net',
        'xtube.com',
        'xtubeporno.net',
        'xuki.us',
        'xvideosbay.com',
        'xvideosporn.biz',
        'xwatt.ru',
        'xxart.ru',
        'xxlargepop.com',
        'xxx-cam.webcam',
        'xxx-treker.ru',
        'xxxdatinglocal.us',
        'xxxguitars.com',
        'xxxkaz.org',
        'xxxnatelefon.ru',
        'xxxrus.org',
        'xxxtube69.com',
        'xxxtubesafari.com',
        'xz618.com',
        'xzlive.com',
        'y8games-free.com',
        'yaaknaa.info',
        'yachts-cruise.info',
        'yaderenergy.ru',
        'yadro.ru',
        'yaminecraft.ru',
        'yaoguangdj.com',
        'yatrk.xyz',
        'yeartwit.com',
        'yebocasino.co.za',
        'yebocasino.com',
        'yellocloud.be',
        'yellowads.men',
        'yellowfootprints.com',
        'yellowstonesafaritours.com',
        'yellowstonevisitortours.com',
        'yes-com.com',
        'yhit.press',
        'ynymnwbm.bloger.index.hr',
        'yogamatsexpert.com',
        'yoluxuryevents.com',
        'yoopsie.com',
        'yopoint.in',
        'yorkshire.com',
        'yorkshireccc.com',
        'yoshkarola.zrus.org',
        'yottos.com',
        'you-shall-not-pass.is74.ru',
        'youandcredit.ru',
        'youbloodyripper.com',
        'youbrainboost.asia',
        'youdao.com',
        'youdesigner.kz',
        'yougame.biz',
        'yougetsignal.com',
        'youghbould.wordpress.com',
        'yougotanewdomain.com',
        'youjizz.com',
        'youjizz.vc',
        'youporn-forum.ga',
        'youporn-ru.com',
        'your-bearings.com',
        'youradexchange.com',
        'yourads.website',
        'youradulthosting.com',
        'youraticles.pl',
        'yourdesires.ru',
        'youresponsive.com',
        'yourmovies.pl',
        'yourothersite.com',
        'yourporn.com',
        'yourporngay.com',
        'yoursearch.me',
        'yourserverisdown.com',
        'yoursite.com',
        'yourtemplatefinder.com',
        'youthreaders.com',
        'youtoner.it',
        'youtube-downloader.savetubevideo.com',
        'youtubedownload.org',
        'youtuhe.com',
        'ypmuseum.ru',
        'ytmnd.com',
        'yuarra.pluto.ro',
        'yubikk.info',
        'yugk.net',
        'yugo-star.ru',
        'yun56.co',
        'yunque.pluto.ro',
        'yur-p.ru',
        'yurgorod.ru',
        'z-master.ru',
        'za-fun-offer.com',
        'za-music.mymobiplanet.com',
        'zaapplesales.blogspot.com',
        'zacreditom.ru',
        'zahvat.ru',
        'zaidia.xhost.ro',
        'zaim-pod-zalog-krasnodar.ru',
        'zaimhelp.ru',
        'zaimite.ru',
        'zajm-pod-zalog-nedvizhimosti.ru',
        'zajm-zalog-krasnodar.ru',
        'zakazfutbolki.com',
        'zakazvzloma.com',
        'zakon-ob-obrazovanii.ru',
        'zakonobosago.ru',
        'zaloadi.ru',
        'zaloro.com',
        'zambini.ru',
        'zaobao.com.sg',
        'zapiszto.pl',
        'zarabiaj-dzis.pl',
        'zarabotat-na-sajte.ru',
        'zarabotok--doma.ru',
        'zarajbuilders.com',
        'zarenica.net',
        'zarepta.com',
        'zastenchivosti.net',
        'zastroyka.org',
        'zatjmuzu.info',
        'zawyna.ua',
        'zazagames.org',
        'zdesformula.ru',
        'zdesoboi.com',
        'zebradudka.com',
        'zebramart.ru',
        'zed21.net',
        'zeg-distribution.com',
        'zeikopay.com',
        'zeleznobeton.ru',
        'zero1.it',
        'zerocash.msk.ru',
        'zeroredirect.com',
        'zeroredirect1.com',
        'zeroredirect10.com',
        'zeroredirect11.com',
        'zeroredirect12.com',
        'zeroredirect2.com',
        'zeroredirect5.com',
        'zeroredirect6.com',
        'zeroredirect7.com',
        'zeroredirect8.com',
        'zeroredirect9.com',
        'zetgie.com.pl',
        'zetmaster.ru',
        'zhacker.net',
        'zhongwenlink.com',
        'zhorapankratov7.blogspot.com',
        'zhuravlev.info',
        'zigarettenonl.canalblog.com',
        'zigarettenonlinekaufen.tumblr.com',
        'zigarettenonlinekaufen1.bloog.pl',
        'zigarettenonlinekaufen1.blox.pl',
        'zigarettenonlinekaufen2.bloog.pl',
        'zigarettenonlinekaufen2.drupalgardens.com',
        'zigzog.ru',
        'zionstar.net',
        'zixizop.net.ru',
        'zkjovpdgxivg.ga',
        'zlatnajesen.com',
        'zmoda.hostreo.com',
        'znakom.sibtest.ru',
        'znakomstva-moskva77.ru',
        'znakomstva-piter78.ru',
        'znakomstvaonlain.ru',
        'znaniyapolza.ru',
        'znaturaloriginal.com',
        'zocaparj.kz',
        'zog.link',
        'zojirushi-products.ru',
        'zolotoy-lis.ru',
        'zona-aqua.ru',
        'zone-kev717.info',
        'zoodrawings.com',
        'zoogdiesney.com',
        'zoogdinsney.com',
        'zoogdisany.com',
        'zooggames.com',
        'zoolubimets.ru',
        'zoominfo.com',
        'zoomovies.org',
        'zoompegs.com',
        'zoosexart.com',
        'zootoplist.com',
        'zootravel.com',
        'zophim.me',
        'zrelaya.pw',
        'zrizvtrnpale.tk',
        'zrus.org',
        'zryydi.com',
        'zs2vm.top',
        'zscaler.net',
        'zscalerone.net',
        'zscalertwo.net',
        'zverokruh-shop.cz',
        'zvetki.ru',
        'zvezdagedon.ru',
        'zx6.ru',
        'zynax.ua',
        'zytpirwai.net',
        'zzbroya.com.ua',
        'zzlgxh.com',///YOCHI ANTIBOT Startin below
		'urlscan.io',
		'safebrowsing.google.com',
		'virustotal.com',
		'spamhaus.org',
		'spamhaus.com'
    );
$compiledrefString = implode(' ', $bannedREF);
if(isset($_SERVER['HTTP_REFERER'])){
	$referrer = strtolower(trim($_SERVER['HTTP_REFERER']));$reft = true;
	if (strlen($referrer) == 0) {$reft = false;};
	if ($reft != false && strpos($compiledrefString, $referrer) !== false){
        logger($compiledrefString, "BANNED REFERRER");
        die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
		};
};

$br = getBrowser();
$os = getOS();
$v_agent = ParseUA();
if ($v_agent == "Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)" || $v_agent == "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/600.2.5 (KHTML, like Gecko) Version/8.0.2 Safari/600.2.5 (Applebot/0.1; +http://www.apple.com/go/applebot)") {
    logger($v_agent, "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($v_agent == "CheckMarkNetwork/1.0 (+http://www.checkmarknetwork.com/spider.html)") {
    logger($v_agent, "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($v_agent == "Mozilla/5.0 (compatible; TTD-Content; +https://www.thetradedesk.com/general/ttd-content)") {
    logger($v_agent, "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($v_agent == "Baiduspider+(+http://www.baidu.com/search/spider.htm)") {
    logger($v_agent, "BAIDU BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($v_agent == "Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.8.1) VoilaBot BETA 1.2 (support.voilabot@orange-ftgroup.com)") {
    logger($v_agent, "ORANGE BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($v_agent == "Mozilla/5.0 (compatible; adscanner/)") {
    logger($v_agent, "ADS BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($v_agent == "BUbiNG (+http://law.di.unimi.it/BUbiNG.html#wc)") {
    logger($v_agent, "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($v_agent == "Mozilla/5.0 (compatible; AhrefsBot/6.1; +http://ahrefs.com/robot/)") {
    logger($v_agent, "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($br == "Internet Explorer" && stripos(ParseUA(), $word2) !== false) {
    logger($word2, "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if (getIp() == "92.23.57.168" or getIp() == "96.31.1.4" or getIp() == "207.96.148.8") {
    logger(getIp(), "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($os == "Windows Server 2003/XP x64" and $br == "Firefox") {
    logger("{$os} | {$br}", "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($os == "Windows 7" and $br == "Firefox") {
    logger("{$os} | {$br}", "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($os == "Windows XP" and $br == "Firefox") {
    logger("{$os} | {$br}", "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($os == "Windows XP" and $br == "Internet Explorer") {
    logger("{$os} | {$br}", "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($os == "Windows XP" and $br == "Chrome") {
    logger("{$os} | {$br}", "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($os == "Windows Vista" and $br == "Internet Explorer") {
    logger("{$os} | {$br}", "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($os == "Windows Vista" or $os == "Ubuntu" or $os == "Chrome OS" or $os == "BlackBerry" or $os == "Linux"
    && stripos(ParseUA(), $word2) !== false) {
    logger("{$br} | {$word2}", "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($br == "Unknown Browser") {
    logger($br, "UNKNOWN BROWSER");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($os == "Windows 2000") {
    logger($os, "BOT AGENT");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
if ($os == "Unknown OS") {
    logger($br, "UNKNOWN OS");
    die(header("Location: Cloudfare.php?id=".md5(uniqid(rand(), true))));
}
